/**
 * #fetch_domain_request.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
import { Redditor } from "../reddit/redditor.js";
/** The status of the domain request, eg 'PENDING', 'APPROVED', 'DENIED' */
export declare enum FetchDomainRequestStatus {
    PENDING = 0,
    APPROVED = 1,
    DENIED = 2,
    UNRECOGNIZED = -1
}
export declare function fetchDomainRequestStatusFromJSON(object: any): FetchDomainRequestStatus;
export declare function fetchDomainRequestStatusToJSON(object: FetchDomainRequestStatus): number;
/** Represents information about a domain request. */
export interface FetchDomainRequestInfo {
    /** The UUID of the request, eg '19ecb14b-db3c-4757-9793-4d58893ba449' */
    id: string;
    /** The timestamp when the request was created, eg '2025-06-04T17:14:38.029Z' */
    createdAt?: Date | undefined;
    /** The timestamp when the request was last updated, eg '2025-06-04T17:14:38.029Z' */
    updatedAt?: Date | undefined;
    /** The domain that is being requesting, eg 'hello-world.org' */
    domain: string;
    /** The status of the request, eg 'PENDING', 'APPROVED', 'DENIED' */
    status: FetchDomainRequestStatus;
    /** The t2_ id of the user who reviewed the request, eg 't2_1a2b' */
    reviewerId?: string | undefined;
    /** The slug of the app that the request is for, eg 'wsb-app'. */
    appSlug?: string | undefined;
    /** The account of the app owner who requested the domain, eg 't2_3c4d' */
    appOwnerAccount?: Redditor | undefined;
    /** The account of the reviewer who reviewed the request, eg 't2_1a2b' */
    reviewerAccount?: Redditor | undefined;
    /** The formatted time representing how long a request has been pending, eg '2 days', '5 hours', '23 seconds'. */
    timeInQueue?: string | undefined;
}
export interface GetPendingRequest {
    /** How many pending requests to return in a single page. */
    pageSize: number;
    /** The page number of pending requests to return. The page number should start at 1. */
    pageNumber: number;
}
export interface GetResponse {
    /** The list of fetch domain request information. */
    fetchDomainRequests: FetchDomainRequestInfo[];
    /** Indicates whether or not there is a next page of fetch domain requests. */
    hasNextPage?: boolean | undefined;
}
export interface UpdateStatusForAppRequest {
    /** The ID of the FetchDomainRequest to be updated. */
    id: string;
    /** The slug of the app that the request is for, eg 'wsb-app'. */
    appSlug: string;
    /** The domain on the request, eg 'api.hello-world.net'. */
    domain: string;
    /** The new status of the FetchDomainRequest. Can be one of PENDING, APPROVED, or DENIED. */
    status: FetchDomainRequestStatus;
}
export declare const FetchDomainRequestInfo: {
    $type: "devvit.dev_portal.fetch_domain_request.FetchDomainRequestInfo";
    encode(message: FetchDomainRequestInfo, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): FetchDomainRequestInfo;
    fromJSON(object: any): FetchDomainRequestInfo;
    toJSON(message: FetchDomainRequestInfo): unknown;
    create(base?: DeepPartial<FetchDomainRequestInfo>): FetchDomainRequestInfo;
    fromPartial(object: DeepPartial<FetchDomainRequestInfo>): FetchDomainRequestInfo;
};
export declare const GetPendingRequest: {
    $type: "devvit.dev_portal.fetch_domain_request.GetPendingRequest";
    encode(message: GetPendingRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetPendingRequest;
    fromJSON(object: any): GetPendingRequest;
    toJSON(message: GetPendingRequest): unknown;
    create(base?: DeepPartial<GetPendingRequest>): GetPendingRequest;
    fromPartial(object: DeepPartial<GetPendingRequest>): GetPendingRequest;
};
export declare const GetResponse: {
    $type: "devvit.dev_portal.fetch_domain_request.GetResponse";
    encode(message: GetResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetResponse;
    fromJSON(object: any): GetResponse;
    toJSON(message: GetResponse): unknown;
    create(base?: DeepPartial<GetResponse>): GetResponse;
    fromPartial(object: DeepPartial<GetResponse>): GetResponse;
};
export declare const UpdateStatusForAppRequest: {
    $type: "devvit.dev_portal.fetch_domain_request.UpdateStatusForAppRequest";
    encode(message: UpdateStatusForAppRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): UpdateStatusForAppRequest;
    fromJSON(object: any): UpdateStatusForAppRequest;
    toJSON(message: UpdateStatusForAppRequest): unknown;
    create(base?: DeepPartial<UpdateStatusForAppRequest>): UpdateStatusForAppRequest;
    fromPartial(object: DeepPartial<UpdateStatusForAppRequest>): UpdateStatusForAppRequest;
};
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
//# sourceMappingURL=fetch_domain_request.d.ts.map