/**
 * #authorization.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
import { Metadata } from "../../../../../../lib/Types.js";
import { RemoteLogType } from "../../../../remote_logger/remote_logger.js";
/** An application version installed to a specific location */
export interface DevPortalAuthInstalledAppResource {
    app?: DevPortalAuthAppVersionResource | undefined;
    location?: DevPortalAuthLocationResource | undefined;
}
/** Represents a specific application version */
export interface DevPortalAuthAppVersionResource {
    /** The short app name (slug) */
    name: string;
    /** Semver of the application */
    version: string;
}
/** Represents a specific subreddit */
export interface DevPortalAuthLocationResource {
    /** t5_ for the subreddit or t2_ for user */
    id: string;
}
export interface DevPortalAuthCanViewLogsRequest {
    userId: string;
    /** Installation Id UUID */
    id?: string | undefined;
    /** An app version + location combo */
    app?: DevPortalAuthInstalledAppResource | undefined;
    /**
     * The log stream type that will be read from. Admins may have access to more
     * types than other types of users.
     */
    type: RemoteLogType;
}
export interface DevPortalAuthorizationResponse {
    /** true if the requested action is allowed */
    allowed: boolean;
    /** a reason for the allow/deny. This is more likely present for the deny case. */
    reason: string;
}
export declare const DevPortalAuthInstalledAppResource: {
    $type: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthInstalledAppResource";
    encode(message: DevPortalAuthInstalledAppResource, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DevPortalAuthInstalledAppResource;
    fromJSON(object: any): DevPortalAuthInstalledAppResource;
    toJSON(message: DevPortalAuthInstalledAppResource): unknown;
    create(base?: DeepPartial<DevPortalAuthInstalledAppResource>): DevPortalAuthInstalledAppResource;
    fromPartial(object: DeepPartial<DevPortalAuthInstalledAppResource>): DevPortalAuthInstalledAppResource;
};
export declare const DevPortalAuthAppVersionResource: {
    $type: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthAppVersionResource";
    encode(message: DevPortalAuthAppVersionResource, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DevPortalAuthAppVersionResource;
    fromJSON(object: any): DevPortalAuthAppVersionResource;
    toJSON(message: DevPortalAuthAppVersionResource): unknown;
    create(base?: DeepPartial<DevPortalAuthAppVersionResource>): DevPortalAuthAppVersionResource;
    fromPartial(object: DeepPartial<DevPortalAuthAppVersionResource>): DevPortalAuthAppVersionResource;
};
export declare const DevPortalAuthLocationResource: {
    $type: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthLocationResource";
    encode(message: DevPortalAuthLocationResource, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DevPortalAuthLocationResource;
    fromJSON(object: any): DevPortalAuthLocationResource;
    toJSON(message: DevPortalAuthLocationResource): unknown;
    create(base?: DeepPartial<DevPortalAuthLocationResource>): DevPortalAuthLocationResource;
    fromPartial(object: DeepPartial<DevPortalAuthLocationResource>): DevPortalAuthLocationResource;
};
export declare const DevPortalAuthCanViewLogsRequest: {
    $type: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthCanViewLogsRequest";
    encode(message: DevPortalAuthCanViewLogsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DevPortalAuthCanViewLogsRequest;
    fromJSON(object: any): DevPortalAuthCanViewLogsRequest;
    toJSON(message: DevPortalAuthCanViewLogsRequest): unknown;
    create(base?: DeepPartial<DevPortalAuthCanViewLogsRequest>): DevPortalAuthCanViewLogsRequest;
    fromPartial(object: DeepPartial<DevPortalAuthCanViewLogsRequest>): DevPortalAuthCanViewLogsRequest;
};
export declare const DevPortalAuthorizationResponse: {
    $type: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthorizationResponse";
    encode(message: DevPortalAuthorizationResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DevPortalAuthorizationResponse;
    fromJSON(object: any): DevPortalAuthorizationResponse;
    toJSON(message: DevPortalAuthorizationResponse): unknown;
    create(base?: DeepPartial<DevPortalAuthorizationResponse>): DevPortalAuthorizationResponse;
    fromPartial(object: DeepPartial<DevPortalAuthorizationResponse>): DevPortalAuthorizationResponse;
};
export interface DevPortalAuthorization {
    /** Check if a user is allowed view logs */
    CanViewLogs(request: DevPortalAuthCanViewLogsRequest, metadata?: Metadata): Promise<DevPortalAuthorizationResponse>;
}
export declare const DevPortalAuthorizationServiceName = "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthorization";
export declare class DevPortalAuthorizationClientImpl implements DevPortalAuthorization {
    private readonly rpc;
    private readonly service;
    constructor(rpc: Rpc, opts?: {
        service?: string;
    });
    CanViewLogs(request: DevPortalAuthCanViewLogsRequest, metadata?: Metadata): Promise<DevPortalAuthorizationResponse>;
}
export type DevPortalAuthorizationDefinition = typeof DevPortalAuthorizationDefinition;
export declare const DevPortalAuthorizationDefinition: {
    readonly name: "DevPortalAuthorization";
    readonly fullName: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthorization";
    readonly methods: {
        /** Check if a user is allowed view logs */
        readonly canViewLogs: {
            readonly name: "CanViewLogs";
            readonly requestType: {
                $type: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthCanViewLogsRequest";
                encode(message: DevPortalAuthCanViewLogsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): DevPortalAuthCanViewLogsRequest;
                fromJSON(object: any): DevPortalAuthCanViewLogsRequest;
                toJSON(message: DevPortalAuthCanViewLogsRequest): unknown;
                create(base?: DeepPartial<DevPortalAuthCanViewLogsRequest>): DevPortalAuthCanViewLogsRequest;
                fromPartial(object: DeepPartial<DevPortalAuthCanViewLogsRequest>): DevPortalAuthCanViewLogsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.dev_portal.internal.authorization.v1alpha.DevPortalAuthorizationResponse";
                encode(message: DevPortalAuthorizationResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): DevPortalAuthorizationResponse;
                fromJSON(object: any): DevPortalAuthorizationResponse;
                toJSON(message: DevPortalAuthorizationResponse): unknown;
                create(base?: DeepPartial<DevPortalAuthorizationResponse>): DevPortalAuthorizationResponse;
                fromPartial(object: DeepPartial<DevPortalAuthorizationResponse>): DevPortalAuthorizationResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
    };
};
interface Rpc {
    request(service: string, method: string, data: Uint8Array, metadata?: Metadata): Promise<Uint8Array>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
//# sourceMappingURL=authorization.d.ts.map