/**
 * #nutrition.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
/**
 * Abstract plugin capabilities required by an app. Plugin usage is bucketed
 * coarsely by Definition.fullName and may change. This enumeration is to power
 * informative permission UI, not make platform security decisions. See the
 * nutritionCategoriesFromBundle() implementation for the current behavior.
 *
 * "Use" and "provides" terminology is loose. An app that _uses_ a scheduler
 * callback OR _provides_ the scheduler plugin is still categorized as
 * "SCHEDULER".
 *
 * See ActorType in packages/protos/src/index.ts. Beware: many of these
 * Defintions should never be Devvit apps.
 */
export declare enum NutritionCategory {
    /** UNCATEGORIZED - App may use uncategorized permissions. */
    UNCATEGORIZED = 0,
    /** APP_TRIGGERS - App may execute when installed or upgraded. */
    APP_TRIGGERS = 1,
    /** ASSETS - App may present predefined audio-visual media. */
    ASSETS = 2,
    /** DATA - App may read and write _app_ data to Reddit servers. */
    DATA = 3,
    /** HTTP - App may read and write _any_ data to and from the internet. */
    HTTP = 4,
    /**
     * MODLOG - App may read and write data to Reddit moderator logs. Does not imply Reddit
     * API.
     */
    MODLOG = 5,
    /** REDDIT_API - App may read and write _any_ Reddit data. Does not imply HTTP. */
    REDDIT_API = 6,
    /**
     * REDDIT_TRIGGERS - App may observe Reddit events such as post creation, comment deletion, and
     * many more. Does not imply REDDIT_API.
     */
    REDDIT_TRIGGERS = 7,
    /** SCHEDULER - App may schedule itself for later execution. */
    SCHEDULER = 8,
    /**
     * UI - App may appear in subreddit, post, and comment menu entries, and custom posts.
     * Note: CUSTOM_POST is a subset of UI: if CUSTOM_POST is set then UI is set also.
     */
    UI = 9,
    /** MODERATOR - App may appear and act as a moderator on subreddits where it's installed. */
    MODERATOR = 10,
    /** WEBVIEW - App may embed a webview to enable more web functionality in their app. */
    WEBVIEW = 11,
    /** PAYMENTS - App may sell digital goods or services. */
    PAYMENTS = 12,
    /**
     * CUSTOM_POST - App can create a custom experience.
     * Note: CUSTOM_POST is a subset of UI: if CUSTOM_POST is set then UI is set also.
     */
    CUSTOM_POST = 13,
    /** USER_ACTIONS - App may call Reddit APIs on behalf of the User. */
    USER_ACTIONS = 14,
    UNRECOGNIZED = -1
}
export declare function nutritionCategoryFromJSON(object: any): NutritionCategory;
export declare function nutritionCategoryToJSON(object: NutritionCategory): number;
export interface GetNutritionByNameVersionRequest {
    /** App slug / ID. Eg, comment-nuke. */
    name: string;
    /** App version. Eg, 1.2.3 or 1.2.3.4. Defaults to latest. */
    version?: string | undefined;
}
export interface MultipleNutritionCategories {
    categories: NutritionCategory[];
}
export declare const GetNutritionByNameVersionRequest: {
    $type: "devvit.dev_portal.nutrition.GetNutritionByNameVersionRequest";
    encode(message: GetNutritionByNameVersionRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetNutritionByNameVersionRequest;
    fromJSON(object: any): GetNutritionByNameVersionRequest;
    toJSON(message: GetNutritionByNameVersionRequest): unknown;
    create(base?: DeepPartial<GetNutritionByNameVersionRequest>): GetNutritionByNameVersionRequest;
    fromPartial(object: DeepPartial<GetNutritionByNameVersionRequest>): GetNutritionByNameVersionRequest;
};
export declare const MultipleNutritionCategories: {
    $type: "devvit.dev_portal.nutrition.MultipleNutritionCategories";
    encode(message: MultipleNutritionCategories, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MultipleNutritionCategories;
    fromJSON(object: any): MultipleNutritionCategories;
    toJSON(message: MultipleNutritionCategories): unknown;
    create(base?: DeepPartial<MultipleNutritionCategories>): MultipleNutritionCategories;
    fromPartial(object: DeepPartial<MultipleNutritionCategories>): MultipleNutritionCategories;
};
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
//# sourceMappingURL=nutrition.d.ts.map