/**
 * #waitlist.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
import { Metadata } from "../../../../lib/Types.js";
import { Empty } from "../../../google/protobuf/empty.js";
import { WaitlistStatus } from "../admin/waitlist_admin.js";
export declare enum ProgrammingExperienceLevel {
    BEGINNER = 0,
    PROFICIENT = 1,
    EXPERT = 2,
    UNRECOGNIZED = -1
}
export declare function programmingExperienceLevelFromJSON(object: any): ProgrammingExperienceLevel;
export declare function programmingExperienceLevelToJSON(object: ProgrammingExperienceLevel): number;
export interface IsCurrentUserRegisteredResponse {
    isRegistered: boolean;
    /**
     * Original response returned here to future-proof
     * in case we want to allow the user to change their response
     */
    response?: WaitlistRegisterUserRequest | undefined;
    waitlistStatus: WaitlistStatus;
}
export interface WaitlistRegisterUserRequest {
    /** Thing ID */
    userId: string;
    /** Username */
    userName: string;
    /** "What apps, bots, or experiences would you like to build?" */
    whatToBuild: string;
    /** "What types of bots have you created?" (only available if above is true) */
    botsBuilt?: string | undefined;
    /** "What languages can you work with, and how proficient are you with them?" */
    programmingExperience: {
        [key: string]: ProgrammingExperienceLevel;
    };
    appsWanted: string;
    /** "What apps or customizations would you like to see in your subreddit(s)?" */
    doesConsentToEmail: boolean;
}
export interface WaitlistRegisterUserRequest_ProgrammingExperienceEntry {
    key: string;
    value: ProgrammingExperienceLevel;
}
export interface WaitlistRegisterUserResponse {
    success: boolean;
    /** Optional message, for errors, etc. */
    message?: string | undefined;
}
export interface GetCurrentUserStatusResponse {
    waitlistStatus: WaitlistStatus;
    acceptedTermsVersion: number;
    currentTermsVersion: number;
    hasVerifiedEmail: boolean;
    doesConsentToEmail: boolean;
}
export declare const IsCurrentUserRegisteredResponse: {
    $type: "devvit.dev_portal.waitlist.IsCurrentUserRegisteredResponse";
    encode(message: IsCurrentUserRegisteredResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): IsCurrentUserRegisteredResponse;
    fromJSON(object: any): IsCurrentUserRegisteredResponse;
    toJSON(message: IsCurrentUserRegisteredResponse): unknown;
    create(base?: DeepPartial<IsCurrentUserRegisteredResponse>): IsCurrentUserRegisteredResponse;
    fromPartial(object: DeepPartial<IsCurrentUserRegisteredResponse>): IsCurrentUserRegisteredResponse;
};
export declare const WaitlistRegisterUserRequest: {
    $type: "devvit.dev_portal.waitlist.WaitlistRegisterUserRequest";
    encode(message: WaitlistRegisterUserRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WaitlistRegisterUserRequest;
    fromJSON(object: any): WaitlistRegisterUserRequest;
    toJSON(message: WaitlistRegisterUserRequest): unknown;
    create(base?: DeepPartial<WaitlistRegisterUserRequest>): WaitlistRegisterUserRequest;
    fromPartial(object: DeepPartial<WaitlistRegisterUserRequest>): WaitlistRegisterUserRequest;
};
export declare const WaitlistRegisterUserRequest_ProgrammingExperienceEntry: {
    $type: "devvit.dev_portal.waitlist.WaitlistRegisterUserRequest.ProgrammingExperienceEntry";
    encode(message: WaitlistRegisterUserRequest_ProgrammingExperienceEntry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WaitlistRegisterUserRequest_ProgrammingExperienceEntry;
    fromJSON(object: any): WaitlistRegisterUserRequest_ProgrammingExperienceEntry;
    toJSON(message: WaitlistRegisterUserRequest_ProgrammingExperienceEntry): unknown;
    create(base?: DeepPartial<WaitlistRegisterUserRequest_ProgrammingExperienceEntry>): WaitlistRegisterUserRequest_ProgrammingExperienceEntry;
    fromPartial(object: DeepPartial<WaitlistRegisterUserRequest_ProgrammingExperienceEntry>): WaitlistRegisterUserRequest_ProgrammingExperienceEntry;
};
export declare const WaitlistRegisterUserResponse: {
    $type: "devvit.dev_portal.waitlist.WaitlistRegisterUserResponse";
    encode(message: WaitlistRegisterUserResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WaitlistRegisterUserResponse;
    fromJSON(object: any): WaitlistRegisterUserResponse;
    toJSON(message: WaitlistRegisterUserResponse): unknown;
    create(base?: DeepPartial<WaitlistRegisterUserResponse>): WaitlistRegisterUserResponse;
    fromPartial(object: DeepPartial<WaitlistRegisterUserResponse>): WaitlistRegisterUserResponse;
};
export declare const GetCurrentUserStatusResponse: {
    $type: "devvit.dev_portal.waitlist.GetCurrentUserStatusResponse";
    encode(message: GetCurrentUserStatusResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetCurrentUserStatusResponse;
    fromJSON(object: any): GetCurrentUserStatusResponse;
    toJSON(message: GetCurrentUserStatusResponse): unknown;
    create(base?: DeepPartial<GetCurrentUserStatusResponse>): GetCurrentUserStatusResponse;
    fromPartial(object: DeepPartial<GetCurrentUserStatusResponse>): GetCurrentUserStatusResponse;
};
export interface Waitlist {
    IsCurrentUserRegistered(request: Empty, metadata?: Metadata): Promise<IsCurrentUserRegisteredResponse>;
    RegisterUser(request: WaitlistRegisterUserRequest, metadata?: Metadata): Promise<WaitlistRegisterUserResponse>;
    GetCurrentUserStatus(request: Empty, metadata?: Metadata): Promise<GetCurrentUserStatusResponse>;
    AcceptTermsAndConditions(request: Empty, metadata?: Metadata): Promise<Empty>;
    EnsureDeveloperAccountExists(request: Empty, metadata?: Metadata): Promise<WaitlistRegisterUserResponse>;
}
export declare const WaitlistServiceName = "devvit.dev_portal.waitlist.Waitlist";
export declare class WaitlistClientImpl implements Waitlist {
    private readonly rpc;
    private readonly service;
    constructor(rpc: Rpc, opts?: {
        service?: string;
    });
    IsCurrentUserRegistered(request: Empty, metadata?: Metadata): Promise<IsCurrentUserRegisteredResponse>;
    RegisterUser(request: WaitlistRegisterUserRequest, metadata?: Metadata): Promise<WaitlistRegisterUserResponse>;
    GetCurrentUserStatus(request: Empty, metadata?: Metadata): Promise<GetCurrentUserStatusResponse>;
    AcceptTermsAndConditions(request: Empty, metadata?: Metadata): Promise<Empty>;
    EnsureDeveloperAccountExists(request: Empty, metadata?: Metadata): Promise<WaitlistRegisterUserResponse>;
}
export type WaitlistDefinition = typeof WaitlistDefinition;
export declare const WaitlistDefinition: {
    readonly name: "Waitlist";
    readonly fullName: "devvit.dev_portal.waitlist.Waitlist";
    readonly methods: {
        readonly isCurrentUserRegistered: {
            readonly name: "IsCurrentUserRegistered";
            readonly requestType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.dev_portal.waitlist.IsCurrentUserRegisteredResponse";
                encode(message: IsCurrentUserRegisteredResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): IsCurrentUserRegisteredResponse;
                fromJSON(object: any): IsCurrentUserRegisteredResponse;
                toJSON(message: IsCurrentUserRegisteredResponse): unknown;
                create(base?: DeepPartial<IsCurrentUserRegisteredResponse>): IsCurrentUserRegisteredResponse;
                fromPartial(object: DeepPartial<IsCurrentUserRegisteredResponse>): IsCurrentUserRegisteredResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly registerUser: {
            readonly name: "RegisterUser";
            readonly requestType: {
                $type: "devvit.dev_portal.waitlist.WaitlistRegisterUserRequest";
                encode(message: WaitlistRegisterUserRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WaitlistRegisterUserRequest;
                fromJSON(object: any): WaitlistRegisterUserRequest;
                toJSON(message: WaitlistRegisterUserRequest): unknown;
                create(base?: DeepPartial<WaitlistRegisterUserRequest>): WaitlistRegisterUserRequest;
                fromPartial(object: DeepPartial<WaitlistRegisterUserRequest>): WaitlistRegisterUserRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.dev_portal.waitlist.WaitlistRegisterUserResponse";
                encode(message: WaitlistRegisterUserResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WaitlistRegisterUserResponse;
                fromJSON(object: any): WaitlistRegisterUserResponse;
                toJSON(message: WaitlistRegisterUserResponse): unknown;
                create(base?: DeepPartial<WaitlistRegisterUserResponse>): WaitlistRegisterUserResponse;
                fromPartial(object: DeepPartial<WaitlistRegisterUserResponse>): WaitlistRegisterUserResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly getCurrentUserStatus: {
            readonly name: "GetCurrentUserStatus";
            readonly requestType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.dev_portal.waitlist.GetCurrentUserStatusResponse";
                encode(message: GetCurrentUserStatusResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetCurrentUserStatusResponse;
                fromJSON(object: any): GetCurrentUserStatusResponse;
                toJSON(message: GetCurrentUserStatusResponse): unknown;
                create(base?: DeepPartial<GetCurrentUserStatusResponse>): GetCurrentUserStatusResponse;
                fromPartial(object: DeepPartial<GetCurrentUserStatusResponse>): GetCurrentUserStatusResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly acceptTermsAndConditions: {
            readonly name: "AcceptTermsAndConditions";
            readonly requestType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly ensureDeveloperAccountExists: {
            readonly name: "EnsureDeveloperAccountExists";
            readonly requestType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.dev_portal.waitlist.WaitlistRegisterUserResponse";
                encode(message: WaitlistRegisterUserResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WaitlistRegisterUserResponse;
                fromJSON(object: any): WaitlistRegisterUserResponse;
                toJSON(message: WaitlistRegisterUserResponse): unknown;
                create(base?: DeepPartial<WaitlistRegisterUserResponse>): WaitlistRegisterUserResponse;
                fromPartial(object: DeepPartial<WaitlistRegisterUserResponse>): WaitlistRegisterUserResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
    };
};
interface Rpc {
    request(service: string, method: string, data: Uint8Array, metadata?: Metadata): Promise<Uint8Array>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
//# sourceMappingURL=waitlist.d.ts.map