/**
 * #linksandcomments_svc.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
import { Metadata } from "../../../../../lib/Types.js";
import { Empty } from "../../../../google/protobuf/empty.js";
import { JsonRedditObjects, JsonStatus, Listing } from "../common/common_msg.js";
import { BasicIdRequest, CommentRequest, EditCustomPostRequest, FollowPostRequest, InfoRequest, JsonWrappedComment, MoreChildrenRequest, ReportAwardRequest, ReportRequest, SaveRequest, SendRepliesRequest, SetContestModeRequest, SetCustomPostPreviewRequest, SetSubredditStickyRequest, SetSuggestedSortRequest, SubmitRequest, SubmitResponse, VoteRequest } from "./linksandcomments_msg.js";
/**
 * LINKS & COMMENTS - https://www.reddit.com/dev/api#section_links_and_comments
 * Note: all endpoints require oauth
 */
export interface LinksAndComments {
    /**
     * Submit a new Comment
     * Note: `thing_id` refers to the Post or Comment this comment is replying to
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_comment}
     */
    Comment(request: CommentRequest, metadata?: Metadata): Promise<JsonWrappedComment>;
    /**
     * Delete a Post or Comment
     * Note: `id` must be a single thing ID for a Post or Comment
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_del}
     */
    Del(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Edit the body text of a Comment or Post
     * Note: `thing_id` refers to the Post or Comment being edited
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_editusertext}
     */
    EditUserText(request: CommentRequest, metadata?: Metadata): Promise<JsonWrappedComment>;
    /**
     * Follow or unfollow a Post
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_follow_post}
     */
    FollowPost(request: FollowPostRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Hide one or more Posts for the user
     * Note: `id` must be one or more comma-separated Post thing IDs
     *
     * @see {@link Unhide}
     * @see {@link https://www.reddit.com/dev/api#POST_api_hide}
     */
    Hide(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Get one or more things by ID, Subreddit name, or Link Post URL
     *
     * @see {@link https://www.reddit.com/dev/api#GET_api_info}
     */
    Info(request: InfoRequest, metadata?: Metadata): Promise<Listing>;
    /**
     * Disable comments for a Post or Comment
     * Note: `id` must be a single thing ID for a Post or Comment
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_lock}
     */
    Lock(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Marks a Post as Not-Safe-For-Work
     *
     * @see {@link UnmarkNSFW}
     * @see {@link https://www.reddit.com/dev/api#POST_api_marknsfw}
     */
    MarkNSFW(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Get more comments from a truncated Comment tree
     *
     * A comment tree has been truncated if it ends with an entry of kind "more"
     * instead of "t1".  Use this API to fetch the additional comments listed in
     * the "children" array of the "more" entry.
     *
     * @see {@link https://www.reddit.com/dev/api#GET_api_morechildren}
     */
    MoreChildren(request: MoreChildrenRequest, metadata?: Metadata): Promise<JsonWrappedComment>;
    /**
     * Report a Post, Comment, or Private Message
     *
     * If reporting a Post or Comment the report is sent to the moderators of the subreddit for review.
     * If reporting a Private Message the report is sent to Reddit for review.
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_report}
     */
    Report(request: ReportRequest, metadata?: Metadata): Promise<JsonStatus>;
    /**
     * Report an award to Reddit for review
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_report_award}
     */
    ReportAward(request: ReportAwardRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Save a Post or Comment to the user's Saved list
     *
     * @see {@link Unsave}
     * @see {@link https://www.reddit.com/dev/api#POST_api_save}
     */
    Save(request: SaveRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Enable or disable reply notifications for a Post or Comment
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_sendreplies}
     */
    SendReplies(request: SendRepliesRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Toggle Contest Mode for a Post's comments
     *
     * Contest Mode randomizes the sort order and hides the vote score for comments
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_set_contest_mode}
     */
    SetContestMode(request: SetContestModeRequest, metadata?: Metadata): Promise<JsonStatus>;
    /** Edit or set fields unique to developer platform custom posts */
    EditCustomPost(request: EditCustomPostRequest, metadata?: Metadata): Promise<JsonRedditObjects>;
    /** Update the custom post preview content for a Custom Post. */
    SetCustomPostPreview(request: SetCustomPostPreviewRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Set the "sticky" or "pinned" status of a Post
     *
     * If the post was created by the current user they can pin the post
     * to the top of their user profile.  Otherwise they must be a moderator
     * of the subreddit to stick it to the top of the subreddit it was posted in.
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_set_subreddit_sticky}
     */
    SetSubredditSticky(request: SetSubredditStickyRequest, metadata?: Metadata): Promise<JsonStatus>;
    /**
     * Set the default sort order for comments in the given Post
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_set_suggested_sort}
     */
    SetSuggestedSort(request: SetSuggestedSortRequest, metadata?: Metadata): Promise<JsonStatus>;
    /**
     * Sets the spoiler tag on a given Post to hide its contents by default
     * Note: `id` must be a single thing ID for a Post
     *
     * @see {@link Unspoiler}
     * @see {@link https://www.reddit.com/dev/api#POST_api_spoiler}
     */
    Spoiler(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Create a new Post
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_submit}
     *
     * Note: not specifying ApiClientConfig to avoid automatic generation.
     * Submit has extra logic that needs to be manually implemented.
     */
    Submit(request: SubmitRequest, metadata?: Metadata): Promise<SubmitResponse>;
    /** Create a new Custom Post */
    SubmitCustomPost(request: SubmitRequest, metadata?: Metadata): Promise<SubmitResponse>;
    /**
     * Unhide one or more Posts for the user
     * Note: `id` must be one or more comma-separated Post thing IDs
     *
     * @see {@link Hide}
     * @see {@link https://www.reddit.com/dev/api#POST_api_unhide}
     */
    Unhide(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Enable comments for a Post or Comment
     * Note: `id` must be a single thing ID for a Post or Comment
     *
     * @see {@link Lock}
     * @see {@link https://www.reddit.com/dev/api#POST_api_unlock}
     */
    Unlock(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Clears the Not-Safe-For-Work status from a Post
     *
     * @see {@link MarkNSFW}
     * @see {@link https://www.reddit.com/dev/api#POST_api_unmarknsfw}
     */
    UnmarkNSFW(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Remove a Post or Comment from the user's Saved list
     *
     * @see {@link Save}
     * @see {@link https://www.reddit.com/dev/api#POST_api_unsave}
     */
    Unsave(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Clears the spoiler tag on a given Post
     *
     * @see {@link Spoiler}
     * @see {@link https://www.reddit.com/dev/api#POST_api_unspoiler}
     */
    Unspoiler(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Vote or clear a vote on a Post or Comment
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_vote}
     */
    Vote(request: VoteRequest, metadata?: Metadata): Promise<Empty>;
}
export declare const LinksAndCommentsServiceName = "devvit.plugin.redditapi.linksandcomments.LinksAndComments";
export declare class LinksAndCommentsClientImpl implements LinksAndComments {
    private readonly rpc;
    private readonly service;
    constructor(rpc: Rpc, opts?: {
        service?: string;
    });
    Comment(request: CommentRequest, metadata?: Metadata): Promise<JsonWrappedComment>;
    Del(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    EditUserText(request: CommentRequest, metadata?: Metadata): Promise<JsonWrappedComment>;
    FollowPost(request: FollowPostRequest, metadata?: Metadata): Promise<Empty>;
    Hide(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    Info(request: InfoRequest, metadata?: Metadata): Promise<Listing>;
    Lock(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    MarkNSFW(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    MoreChildren(request: MoreChildrenRequest, metadata?: Metadata): Promise<JsonWrappedComment>;
    Report(request: ReportRequest, metadata?: Metadata): Promise<JsonStatus>;
    ReportAward(request: ReportAwardRequest, metadata?: Metadata): Promise<Empty>;
    Save(request: SaveRequest, metadata?: Metadata): Promise<Empty>;
    SendReplies(request: SendRepliesRequest, metadata?: Metadata): Promise<Empty>;
    SetContestMode(request: SetContestModeRequest, metadata?: Metadata): Promise<JsonStatus>;
    EditCustomPost(request: EditCustomPostRequest, metadata?: Metadata): Promise<JsonRedditObjects>;
    SetCustomPostPreview(request: SetCustomPostPreviewRequest, metadata?: Metadata): Promise<Empty>;
    SetSubredditSticky(request: SetSubredditStickyRequest, metadata?: Metadata): Promise<JsonStatus>;
    SetSuggestedSort(request: SetSuggestedSortRequest, metadata?: Metadata): Promise<JsonStatus>;
    Spoiler(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    Submit(request: SubmitRequest, metadata?: Metadata): Promise<SubmitResponse>;
    SubmitCustomPost(request: SubmitRequest, metadata?: Metadata): Promise<SubmitResponse>;
    Unhide(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    Unlock(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    UnmarkNSFW(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    Unsave(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    Unspoiler(request: BasicIdRequest, metadata?: Metadata): Promise<Empty>;
    Vote(request: VoteRequest, metadata?: Metadata): Promise<Empty>;
}
/**
 * LINKS & COMMENTS - https://www.reddit.com/dev/api#section_links_and_comments
 * Note: all endpoints require oauth
 */
export type LinksAndCommentsDefinition = typeof LinksAndCommentsDefinition;
export declare const LinksAndCommentsDefinition: {
    readonly name: "LinksAndComments";
    readonly fullName: "devvit.plugin.redditapi.linksandcomments.LinksAndComments";
    readonly methods: {
        /**
         * Submit a new Comment
         * Note: `thing_id` refers to the Post or Comment this comment is replying to
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_comment}
         */
        readonly comment: {
            readonly name: "Comment";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.CommentRequest";
                encode(message: CommentRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): CommentRequest;
                fromJSON(object: any): CommentRequest;
                toJSON(message: CommentRequest): unknown;
                create(base?: {
                    richtextJson?: string | undefined | undefined;
                    text?: string;
                    thingId?: string;
                    runAs?: import("../common/common_msg.js").RunAs;
                }): CommentRequest;
                fromPartial(object: {
                    richtextJson?: string | undefined | undefined;
                    text?: string;
                    thingId?: string;
                    runAs?: import("../common/common_msg.js").RunAs;
                }): CommentRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.linksandcomments.JsonWrappedComment";
                encode(message: JsonWrappedComment, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonWrappedComment;
                fromJSON(object: any): JsonWrappedComment;
                toJSON(message: JsonWrappedComment): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        awardSubType?: string | undefined | undefined;
                                        awardType?: string | undefined | undefined;
                                        awardingsRequiredToGrantBenefits?: number | undefined | undefined;
                                        coinPrice?: number | undefined | undefined;
                                        coinReward?: number | undefined | undefined;
                                        count?: number | undefined | undefined;
                                        daysOfDripExtension?: number | undefined | undefined;
                                        daysOfPremium?: number | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        endDate?: string | undefined | undefined;
                                        giverCoinReward?: number | undefined | undefined;
                                        iconFormat?: string | undefined | undefined;
                                        iconHeight?: number | undefined | undefined;
                                        iconUrl?: string | undefined | undefined;
                                        iconWidth?: number | undefined | undefined;
                                        id?: string | undefined | undefined;
                                        isEnabled?: boolean | undefined | undefined;
                                        isNew?: boolean | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        pennyDonate?: number | undefined | undefined;
                                        pennyPrice?: number | undefined | undefined;
                                        resizedIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        resizedStaticIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        startDate?: string | undefined | undefined;
                                        staticIconHeight?: number | undefined | undefined;
                                        staticIconUrl?: string | undefined | undefined;
                                        staticIconWidth?: number | undefined | undefined;
                                        stickyDurationSeconds?: number | undefined | undefined;
                                        subredditCoinReward?: number | undefined | undefined;
                                        subredditId?: string | undefined | undefined;
                                        tiersByRequiredAwardings?: string | undefined | undefined;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        gid1?: number | undefined | undefined;
                                        gid2?: number | undefined | undefined;
                                        gid3?: number | undefined | undefined;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    modReports?: any[][];
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: string[];
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: string[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    userReports?: any[][];
                                    count?: number | undefined | undefined;
                                    children?: string[];
                                    banInfo?: {
                                        auto?: boolean | undefined | undefined;
                                        bannedAt?: number | undefined | undefined;
                                        banner?: string | undefined | undefined;
                                        moderatorBanned?: boolean | undefined | undefined;
                                        note?: string | undefined | undefined;
                                        unbanner?: string | undefined | undefined;
                                        unbannedAt?: number | undefined | undefined;
                                        resetUsed?: boolean | undefined | undefined;
                                        reasonId?: string | undefined | undefined;
                                        reasonTitle?: string | undefined | undefined;
                                        reasonMessage?: string | undefined | undefined;
                                        reasonBy?: string | undefined | undefined;
                                        modNote?: string | undefined | undefined;
                                        banAllTriggered?: boolean | undefined | undefined;
                                        subredditMessage?: string | undefined | undefined;
                                        removeAction?: import("../../../reddit/common.js").BanInfo_BanInfoAction;
                                    } | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    verdict?: string | undefined | undefined;
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonWrappedComment;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        awardSubType?: string | undefined | undefined;
                                        awardType?: string | undefined | undefined;
                                        awardingsRequiredToGrantBenefits?: number | undefined | undefined;
                                        coinPrice?: number | undefined | undefined;
                                        coinReward?: number | undefined | undefined;
                                        count?: number | undefined | undefined;
                                        daysOfDripExtension?: number | undefined | undefined;
                                        daysOfPremium?: number | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        endDate?: string | undefined | undefined;
                                        giverCoinReward?: number | undefined | undefined;
                                        iconFormat?: string | undefined | undefined;
                                        iconHeight?: number | undefined | undefined;
                                        iconUrl?: string | undefined | undefined;
                                        iconWidth?: number | undefined | undefined;
                                        id?: string | undefined | undefined;
                                        isEnabled?: boolean | undefined | undefined;
                                        isNew?: boolean | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        pennyDonate?: number | undefined | undefined;
                                        pennyPrice?: number | undefined | undefined;
                                        resizedIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        resizedStaticIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        startDate?: string | undefined | undefined;
                                        staticIconHeight?: number | undefined | undefined;
                                        staticIconUrl?: string | undefined | undefined;
                                        staticIconWidth?: number | undefined | undefined;
                                        stickyDurationSeconds?: number | undefined | undefined;
                                        subredditCoinReward?: number | undefined | undefined;
                                        subredditId?: string | undefined | undefined;
                                        tiersByRequiredAwardings?: string | undefined | undefined;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        gid1?: number | undefined | undefined;
                                        gid2?: number | undefined | undefined;
                                        gid3?: number | undefined | undefined;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    modReports?: any[][];
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: string[];
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: string[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    userReports?: any[][];
                                    count?: number | undefined | undefined;
                                    children?: string[];
                                    banInfo?: {
                                        auto?: boolean | undefined | undefined;
                                        bannedAt?: number | undefined | undefined;
                                        banner?: string | undefined | undefined;
                                        moderatorBanned?: boolean | undefined | undefined;
                                        note?: string | undefined | undefined;
                                        unbanner?: string | undefined | undefined;
                                        unbannedAt?: number | undefined | undefined;
                                        resetUsed?: boolean | undefined | undefined;
                                        reasonId?: string | undefined | undefined;
                                        reasonTitle?: string | undefined | undefined;
                                        reasonMessage?: string | undefined | undefined;
                                        reasonBy?: string | undefined | undefined;
                                        modNote?: string | undefined | undefined;
                                        banAllTriggered?: boolean | undefined | undefined;
                                        subredditMessage?: string | undefined | undefined;
                                        removeAction?: import("../../../reddit/common.js").BanInfo_BanInfoAction;
                                    } | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    verdict?: string | undefined | undefined;
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonWrappedComment;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Delete a Post or Comment
         * Note: `id` must be a single thing ID for a Post or Comment
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_del}
         */
        readonly del: {
            readonly name: "Del";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Edit the body text of a Comment or Post
         * Note: `thing_id` refers to the Post or Comment being edited
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_editusertext}
         */
        readonly editUserText: {
            readonly name: "EditUserText";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.CommentRequest";
                encode(message: CommentRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): CommentRequest;
                fromJSON(object: any): CommentRequest;
                toJSON(message: CommentRequest): unknown;
                create(base?: {
                    richtextJson?: string | undefined | undefined;
                    text?: string;
                    thingId?: string;
                    runAs?: import("../common/common_msg.js").RunAs;
                }): CommentRequest;
                fromPartial(object: {
                    richtextJson?: string | undefined | undefined;
                    text?: string;
                    thingId?: string;
                    runAs?: import("../common/common_msg.js").RunAs;
                }): CommentRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.linksandcomments.JsonWrappedComment";
                encode(message: JsonWrappedComment, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonWrappedComment;
                fromJSON(object: any): JsonWrappedComment;
                toJSON(message: JsonWrappedComment): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        awardSubType?: string | undefined | undefined;
                                        awardType?: string | undefined | undefined;
                                        awardingsRequiredToGrantBenefits?: number | undefined | undefined;
                                        coinPrice?: number | undefined | undefined;
                                        coinReward?: number | undefined | undefined;
                                        count?: number | undefined | undefined;
                                        daysOfDripExtension?: number | undefined | undefined;
                                        daysOfPremium?: number | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        endDate?: string | undefined | undefined;
                                        giverCoinReward?: number | undefined | undefined;
                                        iconFormat?: string | undefined | undefined;
                                        iconHeight?: number | undefined | undefined;
                                        iconUrl?: string | undefined | undefined;
                                        iconWidth?: number | undefined | undefined;
                                        id?: string | undefined | undefined;
                                        isEnabled?: boolean | undefined | undefined;
                                        isNew?: boolean | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        pennyDonate?: number | undefined | undefined;
                                        pennyPrice?: number | undefined | undefined;
                                        resizedIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        resizedStaticIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        startDate?: string | undefined | undefined;
                                        staticIconHeight?: number | undefined | undefined;
                                        staticIconUrl?: string | undefined | undefined;
                                        staticIconWidth?: number | undefined | undefined;
                                        stickyDurationSeconds?: number | undefined | undefined;
                                        subredditCoinReward?: number | undefined | undefined;
                                        subredditId?: string | undefined | undefined;
                                        tiersByRequiredAwardings?: string | undefined | undefined;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        gid1?: number | undefined | undefined;
                                        gid2?: number | undefined | undefined;
                                        gid3?: number | undefined | undefined;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    modReports?: any[][];
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: string[];
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: string[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    userReports?: any[][];
                                    count?: number | undefined | undefined;
                                    children?: string[];
                                    banInfo?: {
                                        auto?: boolean | undefined | undefined;
                                        bannedAt?: number | undefined | undefined;
                                        banner?: string | undefined | undefined;
                                        moderatorBanned?: boolean | undefined | undefined;
                                        note?: string | undefined | undefined;
                                        unbanner?: string | undefined | undefined;
                                        unbannedAt?: number | undefined | undefined;
                                        resetUsed?: boolean | undefined | undefined;
                                        reasonId?: string | undefined | undefined;
                                        reasonTitle?: string | undefined | undefined;
                                        reasonMessage?: string | undefined | undefined;
                                        reasonBy?: string | undefined | undefined;
                                        modNote?: string | undefined | undefined;
                                        banAllTriggered?: boolean | undefined | undefined;
                                        subredditMessage?: string | undefined | undefined;
                                        removeAction?: import("../../../reddit/common.js").BanInfo_BanInfoAction;
                                    } | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    verdict?: string | undefined | undefined;
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonWrappedComment;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        awardSubType?: string | undefined | undefined;
                                        awardType?: string | undefined | undefined;
                                        awardingsRequiredToGrantBenefits?: number | undefined | undefined;
                                        coinPrice?: number | undefined | undefined;
                                        coinReward?: number | undefined | undefined;
                                        count?: number | undefined | undefined;
                                        daysOfDripExtension?: number | undefined | undefined;
                                        daysOfPremium?: number | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        endDate?: string | undefined | undefined;
                                        giverCoinReward?: number | undefined | undefined;
                                        iconFormat?: string | undefined | undefined;
                                        iconHeight?: number | undefined | undefined;
                                        iconUrl?: string | undefined | undefined;
                                        iconWidth?: number | undefined | undefined;
                                        id?: string | undefined | undefined;
                                        isEnabled?: boolean | undefined | undefined;
                                        isNew?: boolean | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        pennyDonate?: number | undefined | undefined;
                                        pennyPrice?: number | undefined | undefined;
                                        resizedIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        resizedStaticIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        startDate?: string | undefined | undefined;
                                        staticIconHeight?: number | undefined | undefined;
                                        staticIconUrl?: string | undefined | undefined;
                                        staticIconWidth?: number | undefined | undefined;
                                        stickyDurationSeconds?: number | undefined | undefined;
                                        subredditCoinReward?: number | undefined | undefined;
                                        subredditId?: string | undefined | undefined;
                                        tiersByRequiredAwardings?: string | undefined | undefined;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        gid1?: number | undefined | undefined;
                                        gid2?: number | undefined | undefined;
                                        gid3?: number | undefined | undefined;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    modReports?: any[][];
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: string[];
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: string[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    userReports?: any[][];
                                    count?: number | undefined | undefined;
                                    children?: string[];
                                    banInfo?: {
                                        auto?: boolean | undefined | undefined;
                                        bannedAt?: number | undefined | undefined;
                                        banner?: string | undefined | undefined;
                                        moderatorBanned?: boolean | undefined | undefined;
                                        note?: string | undefined | undefined;
                                        unbanner?: string | undefined | undefined;
                                        unbannedAt?: number | undefined | undefined;
                                        resetUsed?: boolean | undefined | undefined;
                                        reasonId?: string | undefined | undefined;
                                        reasonTitle?: string | undefined | undefined;
                                        reasonMessage?: string | undefined | undefined;
                                        reasonBy?: string | undefined | undefined;
                                        modNote?: string | undefined | undefined;
                                        banAllTriggered?: boolean | undefined | undefined;
                                        subredditMessage?: string | undefined | undefined;
                                        removeAction?: import("../../../reddit/common.js").BanInfo_BanInfoAction;
                                    } | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    verdict?: string | undefined | undefined;
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonWrappedComment;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Follow or unfollow a Post
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_follow_post}
         */
        readonly followPost: {
            readonly name: "FollowPost";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.FollowPostRequest";
                encode(message: FollowPostRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): FollowPostRequest;
                fromJSON(object: any): FollowPostRequest;
                toJSON(message: FollowPostRequest): unknown;
                create(base?: {
                    follow?: boolean;
                    fullname?: string;
                }): FollowPostRequest;
                fromPartial(object: {
                    follow?: boolean;
                    fullname?: string;
                }): FollowPostRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Hide one or more Posts for the user
         * Note: `id` must be one or more comma-separated Post thing IDs
         *
         * @see {@link Unhide}
         * @see {@link https://www.reddit.com/dev/api#POST_api_hide}
         */
        readonly hide: {
            readonly name: "Hide";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Get one or more things by ID, Subreddit name, or Link Post URL
         *
         * @see {@link https://www.reddit.com/dev/api#GET_api_info}
         */
        readonly info: {
            readonly name: "Info";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.InfoRequest";
                encode(message: InfoRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): InfoRequest;
                fromJSON(object: any): InfoRequest;
                toJSON(message: InfoRequest): unknown;
                create(base?: {
                    subreddits?: string[];
                    thingIds?: string[];
                    url?: string | undefined | undefined;
                }): InfoRequest;
                fromPartial(object: {
                    subreddits?: string[];
                    thingIds?: string[];
                    url?: string | undefined | undefined;
                }): InfoRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.Listing";
                encode(message: Listing, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Listing;
                fromJSON(object: any): Listing;
                toJSON(message: Listing): unknown;
                create(base?: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            kind?: string;
                            data?: {
                                allAwardings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                approved?: boolean | undefined | undefined;
                                approvedAtUtc?: number | undefined | undefined;
                                approvedBy?: string | undefined | undefined;
                                archived?: boolean | undefined | undefined;
                                associatedAward?: string | undefined | undefined;
                                author?: string | undefined | undefined;
                                authorFlairBackgroundColor?: string | undefined | undefined;
                                authorFlairCssClass?: string | undefined | undefined;
                                authorFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                authorFlairTemplateId?: string | undefined | undefined;
                                authorFlairText?: string | undefined | undefined;
                                authorFlairTextColor?: string | undefined | undefined;
                                authorFlairType?: string | undefined | undefined;
                                authorFullname?: string | undefined | undefined;
                                authorIsBlocked?: boolean | undefined | undefined;
                                authorPatreonFlair?: boolean | undefined | undefined;
                                authorPremium?: boolean | undefined | undefined;
                                awarders?: string[];
                                bannedAtUtc?: number | undefined | undefined;
                                bannedBy?: string | undefined | undefined;
                                body?: string | undefined | undefined;
                                bodyHtml?: string | undefined | undefined;
                                canGild?: boolean | undefined | undefined;
                                canModPost?: boolean | undefined | undefined;
                                collapsed?: boolean | undefined | undefined;
                                collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                collapsedReason?: string | undefined | undefined;
                                collapsedReasonCode?: string | undefined | undefined;
                                commentType?: string | undefined | undefined;
                                controversiality?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                distinguished?: string | undefined | undefined;
                                downs?: number | undefined | undefined;
                                edited?: boolean | undefined | undefined;
                                gilded?: number | undefined | undefined;
                                gildings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                } | undefined;
                                id?: string | undefined | undefined;
                                ignoreReports?: boolean | undefined | undefined;
                                isSubmitter?: boolean | undefined | undefined;
                                likes?: boolean | undefined | undefined;
                                linkId?: string | undefined | undefined;
                                locked?: boolean | undefined | undefined;
                                modNote?: string | undefined | undefined;
                                modReasonBy?: string | undefined | undefined;
                                modReasonTitle?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                noFollow?: boolean | undefined | undefined;
                                numReports?: number | undefined | undefined;
                                parentId?: string | undefined | undefined;
                                permalink?: string | undefined | undefined;
                                removalReason?: string | undefined | undefined;
                                removed?: boolean | undefined | undefined;
                                replies?: string | undefined | undefined;
                                reportReasons?: any[] | undefined;
                                rteMode?: string | undefined | undefined;
                                saved?: boolean | undefined | undefined;
                                score?: number | undefined | undefined;
                                scoreHidden?: boolean | undefined | undefined;
                                sendReplies?: boolean | undefined | undefined;
                                spam?: boolean | undefined | undefined;
                                stickied?: boolean | undefined | undefined;
                                subreddit?: string | undefined | undefined;
                                subredditId?: string | undefined | undefined;
                                subredditNamePrefixed?: string | undefined | undefined;
                                subredditType?: string | undefined | undefined;
                                topAwardedType?: string | undefined | undefined;
                                totalAwardsReceived?: number | undefined | undefined;
                                treatmentTags?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                unrepliableReason?: string | undefined | undefined;
                                ups?: number | undefined | undefined;
                                depth?: number | undefined | undefined;
                                linkTitle?: string | undefined | undefined;
                                linkAuthor?: string | undefined | undefined;
                                numComments?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                linkPermalink?: string | undefined | undefined;
                                quarantine?: boolean | undefined | undefined;
                                linkUrl?: string | undefined | undefined;
                                selftext?: string | undefined | undefined;
                                selftextHtml?: string | undefined | undefined;
                                thumbnail?: string | undefined | undefined;
                                thumbnailWidth?: number | undefined | undefined;
                                thumbnailHeight?: number | undefined | undefined;
                                title?: string | undefined | undefined;
                                url?: string | undefined | undefined;
                                displayName?: string | undefined | undefined;
                                modPermissions?: string[];
                                count?: number | undefined | undefined;
                                children?: any[] | undefined;
                                replyList?: /*elided*/ any | undefined;
                                hidden?: boolean | undefined | undefined;
                                linkFlairBackgroundColor?: string | undefined | undefined;
                                linkFlairCssClass?: string | undefined | undefined;
                                linkFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                linkFlairTemplateId?: string | undefined | undefined;
                                linkFlairText?: string | undefined | undefined;
                                linkFlairTextColor?: string | undefined | undefined;
                                linkFlairType?: string | undefined | undefined;
                                secureMedia?: {
                                    type?: string;
                                    oembed?: {
                                        type?: string;
                                        title?: string | undefined | undefined;
                                        providerName?: string | undefined | undefined;
                                        providerUrl?: string | undefined | undefined;
                                        version?: string;
                                        thumbnailWidth?: number | undefined | undefined;
                                        thumbnailHeight?: number | undefined | undefined;
                                        thumbnailUrl?: string | undefined | undefined;
                                        html?: string;
                                        height?: number | undefined | undefined;
                                        width?: number | undefined | undefined;
                                        authorUrl?: string | undefined | undefined;
                                        authorName?: string | undefined | undefined;
                                    } | undefined;
                                    redditVideo?: {
                                        bitrateKbps?: number | undefined | undefined;
                                        dashUrl?: string | undefined | undefined;
                                        duration?: number | undefined | undefined;
                                        fallbackUrl?: string | undefined | undefined;
                                        height?: number | undefined | undefined;
                                        hlsUrl?: string | undefined | undefined;
                                        isGif?: boolean | undefined | undefined;
                                        scrubberMediaUrl?: string | undefined | undefined;
                                        transcodingStatus?: string | undefined | undefined;
                                        width?: number | undefined | undefined;
                                    } | undefined;
                                } | undefined;
                                spoiler?: boolean;
                                modReports?: any[][];
                                userReports?: any[][];
                                removedBy?: string | undefined | undefined;
                                removedByCategory?: string | undefined | undefined;
                                gallery?: {
                                    url?: string;
                                    width?: number;
                                    height?: number;
                                    status?: import("../common/common_msg.js").GalleryMediaStatus;
                                }[];
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): Listing;
                fromPartial(object: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            kind?: string;
                            data?: {
                                allAwardings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                approved?: boolean | undefined | undefined;
                                approvedAtUtc?: number | undefined | undefined;
                                approvedBy?: string | undefined | undefined;
                                archived?: boolean | undefined | undefined;
                                associatedAward?: string | undefined | undefined;
                                author?: string | undefined | undefined;
                                authorFlairBackgroundColor?: string | undefined | undefined;
                                authorFlairCssClass?: string | undefined | undefined;
                                authorFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                authorFlairTemplateId?: string | undefined | undefined;
                                authorFlairText?: string | undefined | undefined;
                                authorFlairTextColor?: string | undefined | undefined;
                                authorFlairType?: string | undefined | undefined;
                                authorFullname?: string | undefined | undefined;
                                authorIsBlocked?: boolean | undefined | undefined;
                                authorPatreonFlair?: boolean | undefined | undefined;
                                authorPremium?: boolean | undefined | undefined;
                                awarders?: string[];
                                bannedAtUtc?: number | undefined | undefined;
                                bannedBy?: string | undefined | undefined;
                                body?: string | undefined | undefined;
                                bodyHtml?: string | undefined | undefined;
                                canGild?: boolean | undefined | undefined;
                                canModPost?: boolean | undefined | undefined;
                                collapsed?: boolean | undefined | undefined;
                                collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                collapsedReason?: string | undefined | undefined;
                                collapsedReasonCode?: string | undefined | undefined;
                                commentType?: string | undefined | undefined;
                                controversiality?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                distinguished?: string | undefined | undefined;
                                downs?: number | undefined | undefined;
                                edited?: boolean | undefined | undefined;
                                gilded?: number | undefined | undefined;
                                gildings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                } | undefined;
                                id?: string | undefined | undefined;
                                ignoreReports?: boolean | undefined | undefined;
                                isSubmitter?: boolean | undefined | undefined;
                                likes?: boolean | undefined | undefined;
                                linkId?: string | undefined | undefined;
                                locked?: boolean | undefined | undefined;
                                modNote?: string | undefined | undefined;
                                modReasonBy?: string | undefined | undefined;
                                modReasonTitle?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                noFollow?: boolean | undefined | undefined;
                                numReports?: number | undefined | undefined;
                                parentId?: string | undefined | undefined;
                                permalink?: string | undefined | undefined;
                                removalReason?: string | undefined | undefined;
                                removed?: boolean | undefined | undefined;
                                replies?: string | undefined | undefined;
                                reportReasons?: any[] | undefined;
                                rteMode?: string | undefined | undefined;
                                saved?: boolean | undefined | undefined;
                                score?: number | undefined | undefined;
                                scoreHidden?: boolean | undefined | undefined;
                                sendReplies?: boolean | undefined | undefined;
                                spam?: boolean | undefined | undefined;
                                stickied?: boolean | undefined | undefined;
                                subreddit?: string | undefined | undefined;
                                subredditId?: string | undefined | undefined;
                                subredditNamePrefixed?: string | undefined | undefined;
                                subredditType?: string | undefined | undefined;
                                topAwardedType?: string | undefined | undefined;
                                totalAwardsReceived?: number | undefined | undefined;
                                treatmentTags?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                unrepliableReason?: string | undefined | undefined;
                                ups?: number | undefined | undefined;
                                depth?: number | undefined | undefined;
                                linkTitle?: string | undefined | undefined;
                                linkAuthor?: string | undefined | undefined;
                                numComments?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                linkPermalink?: string | undefined | undefined;
                                quarantine?: boolean | undefined | undefined;
                                linkUrl?: string | undefined | undefined;
                                selftext?: string | undefined | undefined;
                                selftextHtml?: string | undefined | undefined;
                                thumbnail?: string | undefined | undefined;
                                thumbnailWidth?: number | undefined | undefined;
                                thumbnailHeight?: number | undefined | undefined;
                                title?: string | undefined | undefined;
                                url?: string | undefined | undefined;
                                displayName?: string | undefined | undefined;
                                modPermissions?: string[];
                                count?: number | undefined | undefined;
                                children?: any[] | undefined;
                                replyList?: /*elided*/ any | undefined;
                                hidden?: boolean | undefined | undefined;
                                linkFlairBackgroundColor?: string | undefined | undefined;
                                linkFlairCssClass?: string | undefined | undefined;
                                linkFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                linkFlairTemplateId?: string | undefined | undefined;
                                linkFlairText?: string | undefined | undefined;
                                linkFlairTextColor?: string | undefined | undefined;
                                linkFlairType?: string | undefined | undefined;
                                secureMedia?: {
                                    type?: string;
                                    oembed?: {
                                        type?: string;
                                        title?: string | undefined | undefined;
                                        providerName?: string | undefined | undefined;
                                        providerUrl?: string | undefined | undefined;
                                        version?: string;
                                        thumbnailWidth?: number | undefined | undefined;
                                        thumbnailHeight?: number | undefined | undefined;
                                        thumbnailUrl?: string | undefined | undefined;
                                        html?: string;
                                        height?: number | undefined | undefined;
                                        width?: number | undefined | undefined;
                                        authorUrl?: string | undefined | undefined;
                                        authorName?: string | undefined | undefined;
                                    } | undefined;
                                    redditVideo?: {
                                        bitrateKbps?: number | undefined | undefined;
                                        dashUrl?: string | undefined | undefined;
                                        duration?: number | undefined | undefined;
                                        fallbackUrl?: string | undefined | undefined;
                                        height?: number | undefined | undefined;
                                        hlsUrl?: string | undefined | undefined;
                                        isGif?: boolean | undefined | undefined;
                                        scrubberMediaUrl?: string | undefined | undefined;
                                        transcodingStatus?: string | undefined | undefined;
                                        width?: number | undefined | undefined;
                                    } | undefined;
                                } | undefined;
                                spoiler?: boolean;
                                modReports?: any[][];
                                userReports?: any[][];
                                removedBy?: string | undefined | undefined;
                                removedByCategory?: string | undefined | undefined;
                                gallery?: {
                                    url?: string;
                                    width?: number;
                                    height?: number;
                                    status?: import("../common/common_msg.js").GalleryMediaStatus;
                                }[];
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): Listing;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Disable comments for a Post or Comment
         * Note: `id` must be a single thing ID for a Post or Comment
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_lock}
         */
        readonly lock: {
            readonly name: "Lock";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Marks a Post as Not-Safe-For-Work
         *
         * @see {@link UnmarkNSFW}
         * @see {@link https://www.reddit.com/dev/api#POST_api_marknsfw}
         */
        readonly markNSFW: {
            readonly name: "MarkNSFW";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Get more comments from a truncated Comment tree
         *
         * A comment tree has been truncated if it ends with an entry of kind "more"
         * instead of "t1".  Use this API to fetch the additional comments listed in
         * the "children" array of the "more" entry.
         *
         * @see {@link https://www.reddit.com/dev/api#GET_api_morechildren}
         */
        readonly moreChildren: {
            readonly name: "MoreChildren";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.MoreChildrenRequest";
                encode(message: MoreChildrenRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): MoreChildrenRequest;
                fromJSON(object: any): MoreChildrenRequest;
                toJSON(message: MoreChildrenRequest): unknown;
                create(base?: {
                    children?: string[];
                    depth?: number | undefined | undefined;
                    limitChildren?: boolean | undefined | undefined;
                    linkId?: string;
                    sort?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                }): MoreChildrenRequest;
                fromPartial(object: {
                    children?: string[];
                    depth?: number | undefined | undefined;
                    limitChildren?: boolean | undefined | undefined;
                    linkId?: string;
                    sort?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                }): MoreChildrenRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.linksandcomments.JsonWrappedComment";
                encode(message: JsonWrappedComment, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonWrappedComment;
                fromJSON(object: any): JsonWrappedComment;
                toJSON(message: JsonWrappedComment): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        awardSubType?: string | undefined | undefined;
                                        awardType?: string | undefined | undefined;
                                        awardingsRequiredToGrantBenefits?: number | undefined | undefined;
                                        coinPrice?: number | undefined | undefined;
                                        coinReward?: number | undefined | undefined;
                                        count?: number | undefined | undefined;
                                        daysOfDripExtension?: number | undefined | undefined;
                                        daysOfPremium?: number | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        endDate?: string | undefined | undefined;
                                        giverCoinReward?: number | undefined | undefined;
                                        iconFormat?: string | undefined | undefined;
                                        iconHeight?: number | undefined | undefined;
                                        iconUrl?: string | undefined | undefined;
                                        iconWidth?: number | undefined | undefined;
                                        id?: string | undefined | undefined;
                                        isEnabled?: boolean | undefined | undefined;
                                        isNew?: boolean | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        pennyDonate?: number | undefined | undefined;
                                        pennyPrice?: number | undefined | undefined;
                                        resizedIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        resizedStaticIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        startDate?: string | undefined | undefined;
                                        staticIconHeight?: number | undefined | undefined;
                                        staticIconUrl?: string | undefined | undefined;
                                        staticIconWidth?: number | undefined | undefined;
                                        stickyDurationSeconds?: number | undefined | undefined;
                                        subredditCoinReward?: number | undefined | undefined;
                                        subredditId?: string | undefined | undefined;
                                        tiersByRequiredAwardings?: string | undefined | undefined;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        gid1?: number | undefined | undefined;
                                        gid2?: number | undefined | undefined;
                                        gid3?: number | undefined | undefined;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    modReports?: any[][];
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: string[];
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: string[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    userReports?: any[][];
                                    count?: number | undefined | undefined;
                                    children?: string[];
                                    banInfo?: {
                                        auto?: boolean | undefined | undefined;
                                        bannedAt?: number | undefined | undefined;
                                        banner?: string | undefined | undefined;
                                        moderatorBanned?: boolean | undefined | undefined;
                                        note?: string | undefined | undefined;
                                        unbanner?: string | undefined | undefined;
                                        unbannedAt?: number | undefined | undefined;
                                        resetUsed?: boolean | undefined | undefined;
                                        reasonId?: string | undefined | undefined;
                                        reasonTitle?: string | undefined | undefined;
                                        reasonMessage?: string | undefined | undefined;
                                        reasonBy?: string | undefined | undefined;
                                        modNote?: string | undefined | undefined;
                                        banAllTriggered?: boolean | undefined | undefined;
                                        subredditMessage?: string | undefined | undefined;
                                        removeAction?: import("../../../reddit/common.js").BanInfo_BanInfoAction;
                                    } | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    verdict?: string | undefined | undefined;
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonWrappedComment;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        awardSubType?: string | undefined | undefined;
                                        awardType?: string | undefined | undefined;
                                        awardingsRequiredToGrantBenefits?: number | undefined | undefined;
                                        coinPrice?: number | undefined | undefined;
                                        coinReward?: number | undefined | undefined;
                                        count?: number | undefined | undefined;
                                        daysOfDripExtension?: number | undefined | undefined;
                                        daysOfPremium?: number | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        endDate?: string | undefined | undefined;
                                        giverCoinReward?: number | undefined | undefined;
                                        iconFormat?: string | undefined | undefined;
                                        iconHeight?: number | undefined | undefined;
                                        iconUrl?: string | undefined | undefined;
                                        iconWidth?: number | undefined | undefined;
                                        id?: string | undefined | undefined;
                                        isEnabled?: boolean | undefined | undefined;
                                        isNew?: boolean | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        pennyDonate?: number | undefined | undefined;
                                        pennyPrice?: number | undefined | undefined;
                                        resizedIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        resizedStaticIcons?: {
                                            height?: number | undefined | undefined;
                                            url?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        }[];
                                        startDate?: string | undefined | undefined;
                                        staticIconHeight?: number | undefined | undefined;
                                        staticIconUrl?: string | undefined | undefined;
                                        staticIconWidth?: number | undefined | undefined;
                                        stickyDurationSeconds?: number | undefined | undefined;
                                        subredditCoinReward?: number | undefined | undefined;
                                        subredditId?: string | undefined | undefined;
                                        tiersByRequiredAwardings?: string | undefined | undefined;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        gid1?: number | undefined | undefined;
                                        gid2?: number | undefined | undefined;
                                        gid3?: number | undefined | undefined;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    modReports?: any[][];
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: string[];
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: string[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    userReports?: any[][];
                                    count?: number | undefined | undefined;
                                    children?: string[];
                                    banInfo?: {
                                        auto?: boolean | undefined | undefined;
                                        bannedAt?: number | undefined | undefined;
                                        banner?: string | undefined | undefined;
                                        moderatorBanned?: boolean | undefined | undefined;
                                        note?: string | undefined | undefined;
                                        unbanner?: string | undefined | undefined;
                                        unbannedAt?: number | undefined | undefined;
                                        resetUsed?: boolean | undefined | undefined;
                                        reasonId?: string | undefined | undefined;
                                        reasonTitle?: string | undefined | undefined;
                                        reasonMessage?: string | undefined | undefined;
                                        reasonBy?: string | undefined | undefined;
                                        modNote?: string | undefined | undefined;
                                        banAllTriggered?: boolean | undefined | undefined;
                                        subredditMessage?: string | undefined | undefined;
                                        removeAction?: import("../../../reddit/common.js").BanInfo_BanInfoAction;
                                    } | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    verdict?: string | undefined | undefined;
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonWrappedComment;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Report a Post, Comment, or Private Message
         *
         * If reporting a Post or Comment the report is sent to the moderators of the subreddit for review.
         * If reporting a Private Message the report is sent to Reddit for review.
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_report}
         */
        readonly report: {
            readonly name: "Report";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.ReportRequest";
                encode(message: ReportRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ReportRequest;
                fromJSON(object: any): ReportRequest;
                toJSON(message: ReportRequest): unknown;
                create(base?: {
                    additionalInfo?: string | undefined | undefined;
                    customText?: string | undefined | undefined;
                    modmailConvId?: string | undefined | undefined;
                    otherReason?: string | undefined | undefined;
                    reason?: string;
                    ruleReason?: string | undefined | undefined;
                    siteReason?: string | undefined | undefined;
                    srName?: string | undefined | undefined;
                    thingId?: string;
                    usernames?: string | undefined | undefined;
                }): ReportRequest;
                fromPartial(object: {
                    additionalInfo?: string | undefined | undefined;
                    customText?: string | undefined | undefined;
                    modmailConvId?: string | undefined | undefined;
                    otherReason?: string | undefined | undefined;
                    reason?: string;
                    ruleReason?: string | undefined | undefined;
                    siteReason?: string | undefined | undefined;
                    srName?: string | undefined | undefined;
                    thingId?: string;
                    usernames?: string | undefined | undefined;
                }): ReportRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.JsonStatus";
                encode(message: JsonStatus, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonStatus;
                fromJSON(object: any): JsonStatus;
                toJSON(message: JsonStatus): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Report an award to Reddit for review
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_report_award}
         */
        readonly reportAward: {
            readonly name: "ReportAward";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.ReportAwardRequest";
                encode(message: ReportAwardRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ReportAwardRequest;
                fromJSON(object: any): ReportAwardRequest;
                toJSON(message: ReportAwardRequest): unknown;
                create(base?: {
                    awardId?: string;
                    reason?: string | undefined | undefined;
                }): ReportAwardRequest;
                fromPartial(object: {
                    awardId?: string;
                    reason?: string | undefined | undefined;
                }): ReportAwardRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Save a Post or Comment to the user's Saved list
         *
         * @see {@link Unsave}
         * @see {@link https://www.reddit.com/dev/api#POST_api_save}
         */
        readonly save: {
            readonly name: "Save";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SaveRequest";
                encode(message: SaveRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SaveRequest;
                fromJSON(object: any): SaveRequest;
                toJSON(message: SaveRequest): unknown;
                create(base?: {
                    id?: string;
                }): SaveRequest;
                fromPartial(object: {
                    id?: string;
                }): SaveRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Enable or disable reply notifications for a Post or Comment
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_sendreplies}
         */
        readonly sendReplies: {
            readonly name: "SendReplies";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SendRepliesRequest";
                encode(message: SendRepliesRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SendRepliesRequest;
                fromJSON(object: any): SendRepliesRequest;
                toJSON(message: SendRepliesRequest): unknown;
                create(base?: {
                    id?: string;
                    state?: boolean;
                }): SendRepliesRequest;
                fromPartial(object: {
                    id?: string;
                    state?: boolean;
                }): SendRepliesRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Toggle Contest Mode for a Post's comments
         *
         * Contest Mode randomizes the sort order and hides the vote score for comments
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_set_contest_mode}
         */
        readonly setContestMode: {
            readonly name: "SetContestMode";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SetContestModeRequest";
                encode(message: SetContestModeRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SetContestModeRequest;
                fromJSON(object: any): SetContestModeRequest;
                toJSON(message: SetContestModeRequest): unknown;
                create(base?: {
                    id?: string;
                    state?: boolean;
                }): SetContestModeRequest;
                fromPartial(object: {
                    id?: string;
                    state?: boolean;
                }): SetContestModeRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.JsonStatus";
                encode(message: JsonStatus, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonStatus;
                fromJSON(object: any): JsonStatus;
                toJSON(message: JsonStatus): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** Edit or set fields unique to developer platform custom posts */
        readonly editCustomPost: {
            readonly name: "EditCustomPost";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.EditCustomPostRequest";
                encode(message: EditCustomPostRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): EditCustomPostRequest;
                fromJSON(object: any): EditCustomPostRequest;
                toJSON(message: EditCustomPostRequest): unknown;
                create(base?: {
                    thingId?: string;
                    richtextFallback?: string | undefined | undefined;
                }): EditCustomPostRequest;
                fromPartial(object: {
                    thingId?: string;
                    richtextFallback?: string | undefined | undefined;
                }): EditCustomPostRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.JsonRedditObjects";
                encode(message: JsonRedditObjects, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonRedditObjects;
                fromJSON(object: any): JsonRedditObjects;
                toJSON(message: JsonRedditObjects): unknown;
                create(base?: {
                    json?: {
                        errors?: {
                            typeUrl?: string;
                            value?: Uint8Array;
                        }[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        typeUrl?: string;
                                        value?: Uint8Array;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                        a?: string | undefined | undefined;
                                        u?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        typeUrl?: string;
                                        value?: Uint8Array;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: any[] | undefined;
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: {
                                        typeUrl?: string;
                                        value?: Uint8Array;
                                    }[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    linkTitle?: string | undefined | undefined;
                                    linkAuthor?: string | undefined | undefined;
                                    numComments?: number | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    linkPermalink?: string | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    linkUrl?: string | undefined | undefined;
                                    selftext?: string | undefined | undefined;
                                    selftextHtml?: string | undefined | undefined;
                                    thumbnail?: string | undefined | undefined;
                                    thumbnailWidth?: number | undefined | undefined;
                                    thumbnailHeight?: number | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    modPermissions?: string[];
                                    count?: number | undefined | undefined;
                                    children?: any[] | undefined;
                                    replyList?: {
                                        kind?: string;
                                        data?: {
                                            after?: string | undefined | undefined;
                                            before?: string | undefined | undefined;
                                            children?: /*elided*/ any[];
                                            dist?: number | undefined | undefined;
                                        } | undefined;
                                    } | undefined;
                                    hidden?: boolean | undefined | undefined;
                                    linkFlairBackgroundColor?: string | undefined | undefined;
                                    linkFlairCssClass?: string | undefined | undefined;
                                    linkFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                        a?: string | undefined | undefined;
                                        u?: string | undefined | undefined;
                                    }[];
                                    linkFlairTemplateId?: string | undefined | undefined;
                                    linkFlairText?: string | undefined | undefined;
                                    linkFlairTextColor?: string | undefined | undefined;
                                    linkFlairType?: string | undefined | undefined;
                                    secureMedia?: {
                                        type?: string;
                                        oembed?: {
                                            type?: string;
                                            title?: string | undefined | undefined;
                                            providerName?: string | undefined | undefined;
                                            providerUrl?: string | undefined | undefined;
                                            version?: string;
                                            thumbnailWidth?: number | undefined | undefined;
                                            thumbnailHeight?: number | undefined | undefined;
                                            thumbnailUrl?: string | undefined | undefined;
                                            html?: string;
                                            height?: number | undefined | undefined;
                                            width?: number | undefined | undefined;
                                            authorUrl?: string | undefined | undefined;
                                            authorName?: string | undefined | undefined;
                                        } | undefined;
                                        redditVideo?: {
                                            bitrateKbps?: number | undefined | undefined;
                                            dashUrl?: string | undefined | undefined;
                                            duration?: number | undefined | undefined;
                                            fallbackUrl?: string | undefined | undefined;
                                            height?: number | undefined | undefined;
                                            hlsUrl?: string | undefined | undefined;
                                            isGif?: boolean | undefined | undefined;
                                            scrubberMediaUrl?: string | undefined | undefined;
                                            transcodingStatus?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        } | undefined;
                                    } | undefined;
                                    spoiler?: boolean;
                                    modReports?: any[][];
                                    userReports?: any[][];
                                    removedBy?: string | undefined | undefined;
                                    removedByCategory?: string | undefined | undefined;
                                    gallery?: {
                                        url?: string;
                                        width?: number;
                                        height?: number;
                                        status?: import("../common/common_msg.js").GalleryMediaStatus;
                                    }[];
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonRedditObjects;
                fromPartial(object: {
                    json?: {
                        errors?: {
                            typeUrl?: string;
                            value?: Uint8Array;
                        }[];
                        data?: {
                            things?: {
                                kind?: string;
                                data?: {
                                    allAwardings?: {
                                        typeUrl?: string;
                                        value?: Uint8Array;
                                    }[];
                                    approved?: boolean | undefined | undefined;
                                    approvedAtUtc?: number | undefined | undefined;
                                    approvedBy?: string | undefined | undefined;
                                    archived?: boolean | undefined | undefined;
                                    associatedAward?: string | undefined | undefined;
                                    author?: string | undefined | undefined;
                                    authorFlairBackgroundColor?: string | undefined | undefined;
                                    authorFlairCssClass?: string | undefined | undefined;
                                    authorFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                        a?: string | undefined | undefined;
                                        u?: string | undefined | undefined;
                                    }[];
                                    authorFlairTemplateId?: string | undefined | undefined;
                                    authorFlairText?: string | undefined | undefined;
                                    authorFlairTextColor?: string | undefined | undefined;
                                    authorFlairType?: string | undefined | undefined;
                                    authorFullname?: string | undefined | undefined;
                                    authorIsBlocked?: boolean | undefined | undefined;
                                    authorPatreonFlair?: boolean | undefined | undefined;
                                    authorPremium?: boolean | undefined | undefined;
                                    awarders?: string[];
                                    bannedAtUtc?: number | undefined | undefined;
                                    bannedBy?: string | undefined | undefined;
                                    body?: string | undefined | undefined;
                                    bodyHtml?: string | undefined | undefined;
                                    canGild?: boolean | undefined | undefined;
                                    canModPost?: boolean | undefined | undefined;
                                    collapsed?: boolean | undefined | undefined;
                                    collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                    collapsedReason?: string | undefined | undefined;
                                    collapsedReasonCode?: string | undefined | undefined;
                                    commentType?: string | undefined | undefined;
                                    controversiality?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    distinguished?: string | undefined | undefined;
                                    downs?: number | undefined | undefined;
                                    edited?: boolean | undefined | undefined;
                                    gilded?: number | undefined | undefined;
                                    gildings?: {
                                        typeUrl?: string;
                                        value?: Uint8Array;
                                    } | undefined;
                                    id?: string | undefined | undefined;
                                    ignoreReports?: boolean | undefined | undefined;
                                    isSubmitter?: boolean | undefined | undefined;
                                    likes?: boolean | undefined | undefined;
                                    linkId?: string | undefined | undefined;
                                    locked?: boolean | undefined | undefined;
                                    modNote?: string | undefined | undefined;
                                    modReasonBy?: string | undefined | undefined;
                                    modReasonTitle?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    noFollow?: boolean | undefined | undefined;
                                    numReports?: number | undefined | undefined;
                                    parentId?: string | undefined | undefined;
                                    permalink?: string | undefined | undefined;
                                    removalReason?: string | undefined | undefined;
                                    removed?: boolean | undefined | undefined;
                                    replies?: string | undefined | undefined;
                                    reportReasons?: any[] | undefined;
                                    rteMode?: string | undefined | undefined;
                                    saved?: boolean | undefined | undefined;
                                    score?: number | undefined | undefined;
                                    scoreHidden?: boolean | undefined | undefined;
                                    sendReplies?: boolean | undefined | undefined;
                                    spam?: boolean | undefined | undefined;
                                    stickied?: boolean | undefined | undefined;
                                    subreddit?: string | undefined | undefined;
                                    subredditId?: string | undefined | undefined;
                                    subredditNamePrefixed?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    topAwardedType?: string | undefined | undefined;
                                    totalAwardsReceived?: number | undefined | undefined;
                                    treatmentTags?: {
                                        typeUrl?: string;
                                        value?: Uint8Array;
                                    }[];
                                    unrepliableReason?: string | undefined | undefined;
                                    ups?: number | undefined | undefined;
                                    depth?: number | undefined | undefined;
                                    linkTitle?: string | undefined | undefined;
                                    linkAuthor?: string | undefined | undefined;
                                    numComments?: number | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    linkPermalink?: string | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    linkUrl?: string | undefined | undefined;
                                    selftext?: string | undefined | undefined;
                                    selftextHtml?: string | undefined | undefined;
                                    thumbnail?: string | undefined | undefined;
                                    thumbnailWidth?: number | undefined | undefined;
                                    thumbnailHeight?: number | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    modPermissions?: string[];
                                    count?: number | undefined | undefined;
                                    children?: any[] | undefined;
                                    replyList?: {
                                        kind?: string;
                                        data?: {
                                            after?: string | undefined | undefined;
                                            before?: string | undefined | undefined;
                                            children?: /*elided*/ any[];
                                            dist?: number | undefined | undefined;
                                        } | undefined;
                                    } | undefined;
                                    hidden?: boolean | undefined | undefined;
                                    linkFlairBackgroundColor?: string | undefined | undefined;
                                    linkFlairCssClass?: string | undefined | undefined;
                                    linkFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                        a?: string | undefined | undefined;
                                        u?: string | undefined | undefined;
                                    }[];
                                    linkFlairTemplateId?: string | undefined | undefined;
                                    linkFlairText?: string | undefined | undefined;
                                    linkFlairTextColor?: string | undefined | undefined;
                                    linkFlairType?: string | undefined | undefined;
                                    secureMedia?: {
                                        type?: string;
                                        oembed?: {
                                            type?: string;
                                            title?: string | undefined | undefined;
                                            providerName?: string | undefined | undefined;
                                            providerUrl?: string | undefined | undefined;
                                            version?: string;
                                            thumbnailWidth?: number | undefined | undefined;
                                            thumbnailHeight?: number | undefined | undefined;
                                            thumbnailUrl?: string | undefined | undefined;
                                            html?: string;
                                            height?: number | undefined | undefined;
                                            width?: number | undefined | undefined;
                                            authorUrl?: string | undefined | undefined;
                                            authorName?: string | undefined | undefined;
                                        } | undefined;
                                        redditVideo?: {
                                            bitrateKbps?: number | undefined | undefined;
                                            dashUrl?: string | undefined | undefined;
                                            duration?: number | undefined | undefined;
                                            fallbackUrl?: string | undefined | undefined;
                                            height?: number | undefined | undefined;
                                            hlsUrl?: string | undefined | undefined;
                                            isGif?: boolean | undefined | undefined;
                                            scrubberMediaUrl?: string | undefined | undefined;
                                            transcodingStatus?: string | undefined | undefined;
                                            width?: number | undefined | undefined;
                                        } | undefined;
                                    } | undefined;
                                    spoiler?: boolean;
                                    modReports?: any[][];
                                    userReports?: any[][];
                                    removedBy?: string | undefined | undefined;
                                    removedByCategory?: string | undefined | undefined;
                                    gallery?: {
                                        url?: string;
                                        width?: number;
                                        height?: number;
                                        status?: import("../common/common_msg.js").GalleryMediaStatus;
                                    }[];
                                } | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                }): JsonRedditObjects;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        /** Update the custom post preview content for a Custom Post. */
        readonly setCustomPostPreview: {
            readonly name: "SetCustomPostPreview";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SetCustomPostPreviewRequest";
                encode(message: SetCustomPostPreviewRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SetCustomPostPreviewRequest;
                fromJSON(object: any): SetCustomPostPreviewRequest;
                toJSON(message: SetCustomPostPreviewRequest): unknown;
                create(base?: {
                    thingId?: string;
                    bodyType?: import("./linksandcomments_msg.js").SetCustomPostPreviewRequest_BodyType;
                    blocksRenderContent?: string | undefined | undefined;
                }): SetCustomPostPreviewRequest;
                fromPartial(object: {
                    thingId?: string;
                    bodyType?: import("./linksandcomments_msg.js").SetCustomPostPreviewRequest_BodyType;
                    blocksRenderContent?: string | undefined | undefined;
                }): SetCustomPostPreviewRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        /**
         * Set the "sticky" or "pinned" status of a Post
         *
         * If the post was created by the current user they can pin the post
         * to the top of their user profile.  Otherwise they must be a moderator
         * of the subreddit to stick it to the top of the subreddit it was posted in.
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_set_subreddit_sticky}
         */
        readonly setSubredditSticky: {
            readonly name: "SetSubredditSticky";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SetSubredditStickyRequest";
                encode(message: SetSubredditStickyRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SetSubredditStickyRequest;
                fromJSON(object: any): SetSubredditStickyRequest;
                toJSON(message: SetSubredditStickyRequest): unknown;
                create(base?: {
                    id?: string;
                    num?: number | undefined | undefined;
                    state?: boolean;
                    toProfile?: boolean | undefined | undefined;
                }): SetSubredditStickyRequest;
                fromPartial(object: {
                    id?: string;
                    num?: number | undefined | undefined;
                    state?: boolean;
                    toProfile?: boolean | undefined | undefined;
                }): SetSubredditStickyRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.JsonStatus";
                encode(message: JsonStatus, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonStatus;
                fromJSON(object: any): JsonStatus;
                toJSON(message: JsonStatus): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Set the default sort order for comments in the given Post
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_set_suggested_sort}
         */
        readonly setSuggestedSort: {
            readonly name: "SetSuggestedSort";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SetSuggestedSortRequest";
                encode(message: SetSuggestedSortRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SetSuggestedSortRequest;
                fromJSON(object: any): SetSuggestedSortRequest;
                toJSON(message: SetSuggestedSortRequest): unknown;
                create(base?: {
                    id?: string;
                    sort?: string;
                }): SetSuggestedSortRequest;
                fromPartial(object: {
                    id?: string;
                    sort?: string;
                }): SetSuggestedSortRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.JsonStatus";
                encode(message: JsonStatus, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonStatus;
                fromJSON(object: any): JsonStatus;
                toJSON(message: JsonStatus): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Sets the spoiler tag on a given Post to hide its contents by default
         * Note: `id` must be a single thing ID for a Post
         *
         * @see {@link Unspoiler}
         * @see {@link https://www.reddit.com/dev/api#POST_api_spoiler}
         */
        readonly spoiler: {
            readonly name: "Spoiler";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Create a new Post
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_submit}
         *
         * Note: not specifying ApiClientConfig to avoid automatic generation.
         * Submit has extra logic that needs to be manually implemented.
         */
        readonly submit: {
            readonly name: "Submit";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SubmitRequest";
                encode(message: SubmitRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SubmitRequest;
                fromJSON(object: any): SubmitRequest;
                toJSON(message: SubmitRequest): unknown;
                create(base?: {
                    collectionId?: string | undefined | undefined;
                    flairId?: string | undefined | undefined;
                    flairText?: string | undefined | undefined;
                    kind?: string;
                    nsfw?: boolean | undefined | undefined;
                    richtextJson?: string | undefined | undefined;
                    sendreplies?: boolean | undefined | undefined;
                    spoiler?: boolean | undefined | undefined;
                    sr?: string;
                    text?: string | undefined | undefined;
                    title?: string;
                    url?: string | undefined | undefined;
                    videoPosterUrl?: string | undefined | undefined;
                    crosspostFullname?: string | undefined | undefined;
                    richtextFallback?: string | undefined | undefined;
                    imageUrls?: any[] | undefined;
                    runAs?: import("../common/common_msg.js").RunAs;
                    userGeneratedContent?: {
                        text?: string;
                        imageUrls?: string[];
                    } | undefined;
                }): SubmitRequest;
                fromPartial(object: {
                    collectionId?: string | undefined | undefined;
                    flairId?: string | undefined | undefined;
                    flairText?: string | undefined | undefined;
                    kind?: string;
                    nsfw?: boolean | undefined | undefined;
                    richtextJson?: string | undefined | undefined;
                    sendreplies?: boolean | undefined | undefined;
                    spoiler?: boolean | undefined | undefined;
                    sr?: string;
                    text?: string | undefined | undefined;
                    title?: string;
                    url?: string | undefined | undefined;
                    videoPosterUrl?: string | undefined | undefined;
                    crosspostFullname?: string | undefined | undefined;
                    richtextFallback?: string | undefined | undefined;
                    imageUrls?: any[] | undefined;
                    runAs?: import("../common/common_msg.js").RunAs;
                    userGeneratedContent?: {
                        text?: string;
                        imageUrls?: string[];
                    } | undefined;
                }): SubmitRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SubmitResponse";
                encode(message: SubmitResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SubmitResponse;
                fromJSON(object: any): SubmitResponse;
                toJSON(message: SubmitResponse): unknown;
                create(base?: {
                    json?: {
                        errors?: {
                            typeUrl?: string;
                            value?: Uint8Array;
                        }[];
                        data?: {
                            url?: string | undefined | undefined;
                            draftsCount?: number | undefined | undefined;
                            id?: string | undefined | undefined;
                            name?: string | undefined | undefined;
                        } | undefined;
                    } | undefined;
                }): SubmitResponse;
                fromPartial(object: {
                    json?: {
                        errors?: {
                            typeUrl?: string;
                            value?: Uint8Array;
                        }[];
                        data?: {
                            url?: string | undefined | undefined;
                            draftsCount?: number | undefined | undefined;
                            id?: string | undefined | undefined;
                            name?: string | undefined | undefined;
                        } | undefined;
                    } | undefined;
                }): SubmitResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        /** Create a new Custom Post */
        readonly submitCustomPost: {
            readonly name: "SubmitCustomPost";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SubmitRequest";
                encode(message: SubmitRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SubmitRequest;
                fromJSON(object: any): SubmitRequest;
                toJSON(message: SubmitRequest): unknown;
                create(base?: {
                    collectionId?: string | undefined | undefined;
                    flairId?: string | undefined | undefined;
                    flairText?: string | undefined | undefined;
                    kind?: string;
                    nsfw?: boolean | undefined | undefined;
                    richtextJson?: string | undefined | undefined;
                    sendreplies?: boolean | undefined | undefined;
                    spoiler?: boolean | undefined | undefined;
                    sr?: string;
                    text?: string | undefined | undefined;
                    title?: string;
                    url?: string | undefined | undefined;
                    videoPosterUrl?: string | undefined | undefined;
                    crosspostFullname?: string | undefined | undefined;
                    richtextFallback?: string | undefined | undefined;
                    imageUrls?: any[] | undefined;
                    runAs?: import("../common/common_msg.js").RunAs;
                    userGeneratedContent?: {
                        text?: string;
                        imageUrls?: string[];
                    } | undefined;
                }): SubmitRequest;
                fromPartial(object: {
                    collectionId?: string | undefined | undefined;
                    flairId?: string | undefined | undefined;
                    flairText?: string | undefined | undefined;
                    kind?: string;
                    nsfw?: boolean | undefined | undefined;
                    richtextJson?: string | undefined | undefined;
                    sendreplies?: boolean | undefined | undefined;
                    spoiler?: boolean | undefined | undefined;
                    sr?: string;
                    text?: string | undefined | undefined;
                    title?: string;
                    url?: string | undefined | undefined;
                    videoPosterUrl?: string | undefined | undefined;
                    crosspostFullname?: string | undefined | undefined;
                    richtextFallback?: string | undefined | undefined;
                    imageUrls?: any[] | undefined;
                    runAs?: import("../common/common_msg.js").RunAs;
                    userGeneratedContent?: {
                        text?: string;
                        imageUrls?: string[];
                    } | undefined;
                }): SubmitRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.linksandcomments.SubmitResponse";
                encode(message: SubmitResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SubmitResponse;
                fromJSON(object: any): SubmitResponse;
                toJSON(message: SubmitResponse): unknown;
                create(base?: {
                    json?: {
                        errors?: {
                            typeUrl?: string;
                            value?: Uint8Array;
                        }[];
                        data?: {
                            url?: string | undefined | undefined;
                            draftsCount?: number | undefined | undefined;
                            id?: string | undefined | undefined;
                            name?: string | undefined | undefined;
                        } | undefined;
                    } | undefined;
                }): SubmitResponse;
                fromPartial(object: {
                    json?: {
                        errors?: {
                            typeUrl?: string;
                            value?: Uint8Array;
                        }[];
                        data?: {
                            url?: string | undefined | undefined;
                            draftsCount?: number | undefined | undefined;
                            id?: string | undefined | undefined;
                            name?: string | undefined | undefined;
                        } | undefined;
                    } | undefined;
                }): SubmitResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        /**
         * Unhide one or more Posts for the user
         * Note: `id` must be one or more comma-separated Post thing IDs
         *
         * @see {@link Hide}
         * @see {@link https://www.reddit.com/dev/api#POST_api_unhide}
         */
        readonly unhide: {
            readonly name: "Unhide";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Enable comments for a Post or Comment
         * Note: `id` must be a single thing ID for a Post or Comment
         *
         * @see {@link Lock}
         * @see {@link https://www.reddit.com/dev/api#POST_api_unlock}
         */
        readonly unlock: {
            readonly name: "Unlock";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Clears the Not-Safe-For-Work status from a Post
         *
         * @see {@link MarkNSFW}
         * @see {@link https://www.reddit.com/dev/api#POST_api_unmarknsfw}
         */
        readonly unmarkNSFW: {
            readonly name: "UnmarkNSFW";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Remove a Post or Comment from the user's Saved list
         *
         * @see {@link Save}
         * @see {@link https://www.reddit.com/dev/api#POST_api_unsave}
         */
        readonly unsave: {
            readonly name: "Unsave";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Clears the spoiler tag on a given Post
         *
         * @see {@link Spoiler}
         * @see {@link https://www.reddit.com/dev/api#POST_api_unspoiler}
         */
        readonly unspoiler: {
            readonly name: "Unspoiler";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.BasicIdRequest";
                encode(message: BasicIdRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BasicIdRequest;
                fromJSON(object: any): BasicIdRequest;
                toJSON(message: BasicIdRequest): unknown;
                create(base?: {
                    id?: string;
                }): BasicIdRequest;
                fromPartial(object: {
                    id?: string;
                }): BasicIdRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Vote or clear a vote on a Post or Comment
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_vote}
         */
        readonly vote: {
            readonly name: "Vote";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.linksandcomments.VoteRequest";
                encode(message: VoteRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): VoteRequest;
                fromJSON(object: any): VoteRequest;
                toJSON(message: VoteRequest): unknown;
                create(base?: {
                    dir?: number;
                    id?: string;
                }): VoteRequest;
                fromPartial(object: {
                    dir?: number;
                    id?: string;
                }): VoteRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
    };
};
interface Rpc {
    request(service: string, method: string, data: Uint8Array, metadata?: Metadata): Promise<Uint8Array>;
}
export {};
//# sourceMappingURL=linksandcomments_svc.d.ts.map