/**
 * #users_svc.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
import { Metadata } from "../../../../../lib/Types.js";
import { Empty } from "../../../../google/protobuf/empty.js";
import { BoolValue } from "../../../../google/protobuf/wrappers.js";
import { JsonStatus, Listing } from "../common/common_msg.js";
import { BlockUserRequest, BlockUserResponse, FriendRequest, GeneralFriendResponse, GenericUsersRequest, ReportUserRequest, SetPermissionsRequest, UnfriendRequest, UpdateFriendRelationshipRequest, UserAboutRequest, UserAboutResponse, UserDataByAccountIdsRequest, UserDataByAccountIdsResponse, UsernameAvailableRequest, UserTrophiesResponse, UserWhereRequest } from "./users_msg.js";
/**
 * USERS - https://www.reddit.com/dev/api#section_users
 * Note: all endpoints require oauth
 */
export interface Users {
    /** https://www.reddit.com/dev/api#POST_api_block_user */
    BlockUser(request: BlockUserRequest, metadata?: Metadata): Promise<BlockUserResponse>;
    /** https://www.reddit.com/dev/api#POST_api_friend */
    Friend(request: FriendRequest, metadata?: Metadata): Promise<JsonStatus>;
    /** https://www.reddit.com/dev/api#POST_api_report_user */
    ReportUser(request: ReportUserRequest, metadata?: Metadata): Promise<Empty>;
    /** https://www.reddit.com/dev/api#POST_api_setpermissions */
    SetPermissions(request: SetPermissionsRequest, metadata?: Metadata): Promise<JsonStatus>;
    /** https://www.reddit.com/dev/api#POST_api_unfriend */
    Unfriend(request: UnfriendRequest, metadata?: Metadata): Promise<Empty>;
    /** https://www.reddit.com/dev/api#GET_api_user_data_by_account_ids */
    UserDataByAccountIds(request: UserDataByAccountIdsRequest, metadata?: Metadata): Promise<UserDataByAccountIdsResponse>;
    /** https://www.reddit.com/dev/api#GET_api_username_available */
    UsernameAvailable(request: UsernameAvailableRequest, metadata?: Metadata): Promise<BoolValue>;
    /** https://www.reddit.com/dev/api#DELETE_api_v1_me_friends_username */
    UnfriendUser(request: GenericUsersRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * https://www.reddit.com/dev/api#GET_api_v1_me_friends_username
     * TODO: this actually returns a WrappedRedditObject. Fix this up after the system worker is deleted.
     */
    GetFriendInformation(request: GenericUsersRequest, metadata?: Metadata): Promise<GeneralFriendResponse>;
    /** https://www.reddit.com/dev/api#PUT_api_v1_me_friends_username */
    UpdateFriendRelationship(request: UpdateFriendRelationshipRequest, metadata?: Metadata): Promise<GeneralFriendResponse>;
    /** https://www.reddit.com/dev/api#GET_api_v1_user_username_trophies */
    UserTrophies(request: GenericUsersRequest, metadata?: Metadata): Promise<UserTrophiesResponse>;
    /** https://www.reddit.com/dev/api#GET_user_username_about */
    UserAbout(request: UserAboutRequest, metadata?: Metadata): Promise<UserAboutResponse>;
    /** https://www.reddit.com/dev/api#GET_user_username_where */
    UserWhere(request: UserWhereRequest, metadata?: Metadata): Promise<Listing>;
}
export declare const UsersServiceName = "devvit.plugin.redditapi.users.Users";
export declare class UsersClientImpl implements Users {
    private readonly rpc;
    private readonly service;
    constructor(rpc: Rpc, opts?: {
        service?: string;
    });
    BlockUser(request: BlockUserRequest, metadata?: Metadata): Promise<BlockUserResponse>;
    Friend(request: FriendRequest, metadata?: Metadata): Promise<JsonStatus>;
    ReportUser(request: ReportUserRequest, metadata?: Metadata): Promise<Empty>;
    SetPermissions(request: SetPermissionsRequest, metadata?: Metadata): Promise<JsonStatus>;
    Unfriend(request: UnfriendRequest, metadata?: Metadata): Promise<Empty>;
    UserDataByAccountIds(request: UserDataByAccountIdsRequest, metadata?: Metadata): Promise<UserDataByAccountIdsResponse>;
    UsernameAvailable(request: UsernameAvailableRequest, metadata?: Metadata): Promise<BoolValue>;
    UnfriendUser(request: GenericUsersRequest, metadata?: Metadata): Promise<Empty>;
    GetFriendInformation(request: GenericUsersRequest, metadata?: Metadata): Promise<GeneralFriendResponse>;
    UpdateFriendRelationship(request: UpdateFriendRelationshipRequest, metadata?: Metadata): Promise<GeneralFriendResponse>;
    UserTrophies(request: GenericUsersRequest, metadata?: Metadata): Promise<UserTrophiesResponse>;
    UserAbout(request: UserAboutRequest, metadata?: Metadata): Promise<UserAboutResponse>;
    UserWhere(request: UserWhereRequest, metadata?: Metadata): Promise<Listing>;
}
/**
 * USERS - https://www.reddit.com/dev/api#section_users
 * Note: all endpoints require oauth
 */
export type UsersDefinition = typeof UsersDefinition;
export declare const UsersDefinition: {
    readonly name: "Users";
    readonly fullName: "devvit.plugin.redditapi.users.Users";
    readonly methods: {
        /** https://www.reddit.com/dev/api#POST_api_block_user */
        readonly blockUser: {
            readonly name: "BlockUser";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.BlockUserRequest";
                encode(message: BlockUserRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BlockUserRequest;
                fromJSON(object: any): BlockUserRequest;
                toJSON(message: BlockUserRequest): unknown;
                create(base?: {
                    accountId?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                }): BlockUserRequest;
                fromPartial(object: {
                    accountId?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                }): BlockUserRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.users.BlockUserResponse";
                encode(message: BlockUserResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BlockUserResponse;
                fromJSON(object: any): BlockUserResponse;
                toJSON(message: BlockUserResponse): unknown;
                create(base?: {
                    date?: number | undefined | undefined;
                    iconImg?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                }): BlockUserResponse;
                fromPartial(object: {
                    date?: number | undefined | undefined;
                    iconImg?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                }): BlockUserResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#POST_api_friend */
        readonly friend: {
            readonly name: "Friend";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.FriendRequest";
                encode(message: FriendRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): FriendRequest;
                fromJSON(object: any): FriendRequest;
                toJSON(message: FriendRequest): unknown;
                create(base?: {
                    banContext?: string | undefined | undefined;
                    banMessage?: string | undefined | undefined;
                    banReason?: string | undefined | undefined;
                    duration?: number | undefined | undefined;
                    name?: string;
                    note?: string | undefined | undefined;
                    permissions?: string | undefined | undefined;
                    type?: string;
                    subreddit?: string | undefined | undefined;
                }): FriendRequest;
                fromPartial(object: {
                    banContext?: string | undefined | undefined;
                    banMessage?: string | undefined | undefined;
                    banReason?: string | undefined | undefined;
                    duration?: number | undefined | undefined;
                    name?: string;
                    note?: string | undefined | undefined;
                    permissions?: string | undefined | undefined;
                    type?: string;
                    subreddit?: string | undefined | undefined;
                }): FriendRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.JsonStatus";
                encode(message: JsonStatus, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonStatus;
                fromJSON(object: any): JsonStatus;
                toJSON(message: JsonStatus): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#POST_api_report_user */
        readonly reportUser: {
            readonly name: "ReportUser";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.ReportUserRequest";
                encode(message: ReportUserRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ReportUserRequest;
                fromJSON(object: any): ReportUserRequest;
                toJSON(message: ReportUserRequest): unknown;
                create(base?: {
                    details?: string;
                    reason?: string;
                    user?: string;
                }): ReportUserRequest;
                fromPartial(object: {
                    details?: string;
                    reason?: string;
                    user?: string;
                }): ReportUserRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#POST_api_setpermissions */
        readonly setPermissions: {
            readonly name: "SetPermissions";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.SetPermissionsRequest";
                encode(message: SetPermissionsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SetPermissionsRequest;
                fromJSON(object: any): SetPermissionsRequest;
                toJSON(message: SetPermissionsRequest): unknown;
                create(base?: {
                    name?: string;
                    subreddit?: string;
                    permissions?: string;
                    type?: string;
                }): SetPermissionsRequest;
                fromPartial(object: {
                    name?: string;
                    subreddit?: string;
                    permissions?: string;
                    type?: string;
                }): SetPermissionsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.JsonStatus";
                encode(message: JsonStatus, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): JsonStatus;
                fromJSON(object: any): JsonStatus;
                toJSON(message: JsonStatus): unknown;
                create(base?: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
                fromPartial(object: {
                    json?: {
                        errors?: string[];
                    } | undefined;
                }): JsonStatus;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#POST_api_unfriend */
        readonly unfriend: {
            readonly name: "Unfriend";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.UnfriendRequest";
                encode(message: UnfriendRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UnfriendRequest;
                fromJSON(object: any): UnfriendRequest;
                toJSON(message: UnfriendRequest): unknown;
                create(base?: {
                    id?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                    type?: string;
                    subreddit?: string | undefined | undefined;
                }): UnfriendRequest;
                fromPartial(object: {
                    id?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                    type?: string;
                    subreddit?: string | undefined | undefined;
                }): UnfriendRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#GET_api_user_data_by_account_ids */
        readonly userDataByAccountIds: {
            readonly name: "UserDataByAccountIds";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.UserDataByAccountIdsRequest";
                encode(message: UserDataByAccountIdsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UserDataByAccountIdsRequest;
                fromJSON(object: any): UserDataByAccountIdsRequest;
                toJSON(message: UserDataByAccountIdsRequest): unknown;
                create(base?: {
                    ids?: string;
                }): UserDataByAccountIdsRequest;
                fromPartial(object: {
                    ids?: string;
                }): UserDataByAccountIdsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.users.UserDataByAccountIdsResponse";
                encode(message: UserDataByAccountIdsResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UserDataByAccountIdsResponse;
                fromJSON(object: any): UserDataByAccountIdsResponse;
                toJSON(message: UserDataByAccountIdsResponse): unknown;
                create(base?: {
                    users?: {
                        [x: string]: {
                            name?: string | undefined | undefined;
                            createdUtc?: number | undefined | undefined;
                            linkKarma?: number | undefined | undefined;
                            commentKarma?: number | undefined | undefined;
                            profileImg?: string | undefined | undefined;
                            profileColor?: string | undefined | undefined;
                            profileOver18?: boolean | undefined | undefined;
                        } | undefined;
                    };
                }): UserDataByAccountIdsResponse;
                fromPartial(object: {
                    users?: {
                        [x: string]: {
                            name?: string | undefined | undefined;
                            createdUtc?: number | undefined | undefined;
                            linkKarma?: number | undefined | undefined;
                            commentKarma?: number | undefined | undefined;
                            profileImg?: string | undefined | undefined;
                            profileColor?: string | undefined | undefined;
                            profileOver18?: boolean | undefined | undefined;
                        } | undefined;
                    };
                }): UserDataByAccountIdsResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        /** https://www.reddit.com/dev/api#GET_api_username_available */
        readonly usernameAvailable: {
            readonly name: "UsernameAvailable";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.UsernameAvailableRequest";
                encode(message: UsernameAvailableRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UsernameAvailableRequest;
                fromJSON(object: any): UsernameAvailableRequest;
                toJSON(message: UsernameAvailableRequest): unknown;
                create(base?: {
                    user?: string;
                }): UsernameAvailableRequest;
                fromPartial(object: {
                    user?: string;
                }): UsernameAvailableRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.BoolValue";
                encode(message: BoolValue, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): BoolValue;
                fromJSON(object: any): BoolValue;
                toJSON(message: BoolValue): unknown;
                create(base?: {
                    value?: boolean;
                }): BoolValue;
                fromPartial(object: {
                    value?: boolean;
                }): BoolValue;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#DELETE_api_v1_me_friends_username */
        readonly unfriendUser: {
            readonly name: "UnfriendUser";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.GenericUsersRequest";
                encode(message: GenericUsersRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GenericUsersRequest;
                fromJSON(object: any): GenericUsersRequest;
                toJSON(message: GenericUsersRequest): unknown;
                create(base?: {
                    id?: string | undefined | undefined;
                    username?: string;
                }): GenericUsersRequest;
                fromPartial(object: {
                    id?: string | undefined | undefined;
                    username?: string;
                }): GenericUsersRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * https://www.reddit.com/dev/api#GET_api_v1_me_friends_username
         * TODO: this actually returns a WrappedRedditObject. Fix this up after the system worker is deleted.
         */
        readonly getFriendInformation: {
            readonly name: "GetFriendInformation";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.GenericUsersRequest";
                encode(message: GenericUsersRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GenericUsersRequest;
                fromJSON(object: any): GenericUsersRequest;
                toJSON(message: GenericUsersRequest): unknown;
                create(base?: {
                    id?: string | undefined | undefined;
                    username?: string;
                }): GenericUsersRequest;
                fromPartial(object: {
                    id?: string | undefined | undefined;
                    username?: string;
                }): GenericUsersRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.users.GeneralFriendResponse";
                encode(message: GeneralFriendResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GeneralFriendResponse;
                fromJSON(object: any): GeneralFriendResponse;
                toJSON(message: GeneralFriendResponse): unknown;
                create(base?: {
                    date?: number | undefined | undefined;
                    relId?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                    fields?: string[];
                    explanation?: string | undefined | undefined;
                    message?: string | undefined | undefined;
                    reason?: string | undefined | undefined;
                }): GeneralFriendResponse;
                fromPartial(object: {
                    date?: number | undefined | undefined;
                    relId?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                    fields?: string[];
                    explanation?: string | undefined | undefined;
                    message?: string | undefined | undefined;
                    reason?: string | undefined | undefined;
                }): GeneralFriendResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#PUT_api_v1_me_friends_username */
        readonly updateFriendRelationship: {
            readonly name: "UpdateFriendRelationship";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.UpdateFriendRelationshipRequest";
                encode(message: UpdateFriendRelationshipRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UpdateFriendRelationshipRequest;
                fromJSON(object: any): UpdateFriendRelationshipRequest;
                toJSON(message: UpdateFriendRelationshipRequest): unknown;
                create(base?: {
                    name?: string;
                    note?: string;
                }): UpdateFriendRelationshipRequest;
                fromPartial(object: {
                    name?: string;
                    note?: string;
                }): UpdateFriendRelationshipRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.users.GeneralFriendResponse";
                encode(message: GeneralFriendResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GeneralFriendResponse;
                fromJSON(object: any): GeneralFriendResponse;
                toJSON(message: GeneralFriendResponse): unknown;
                create(base?: {
                    date?: number | undefined | undefined;
                    relId?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                    fields?: string[];
                    explanation?: string | undefined | undefined;
                    message?: string | undefined | undefined;
                    reason?: string | undefined | undefined;
                }): GeneralFriendResponse;
                fromPartial(object: {
                    date?: number | undefined | undefined;
                    relId?: string | undefined | undefined;
                    name?: string | undefined | undefined;
                    id?: string | undefined | undefined;
                    fields?: string[];
                    explanation?: string | undefined | undefined;
                    message?: string | undefined | undefined;
                    reason?: string | undefined | undefined;
                }): GeneralFriendResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#GET_api_v1_user_username_trophies */
        readonly userTrophies: {
            readonly name: "UserTrophies";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.GenericUsersRequest";
                encode(message: GenericUsersRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GenericUsersRequest;
                fromJSON(object: any): GenericUsersRequest;
                toJSON(message: GenericUsersRequest): unknown;
                create(base?: {
                    id?: string | undefined | undefined;
                    username?: string;
                }): GenericUsersRequest;
                fromPartial(object: {
                    id?: string | undefined | undefined;
                    username?: string;
                }): GenericUsersRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.users.UserTrophiesResponse";
                encode(message: UserTrophiesResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UserTrophiesResponse;
                fromJSON(object: any): UserTrophiesResponse;
                toJSON(message: UserTrophiesResponse): unknown;
                create(base?: {
                    kind?: string | undefined | undefined;
                    data?: {
                        trophies?: {
                            kind?: string | undefined | undefined;
                            data?: {
                                icon70?: string | undefined | undefined;
                                grantedAt?: number | undefined | undefined;
                                url?: string | undefined | undefined;
                                icon40?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                awardId?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                description?: string | undefined | undefined;
                            } | undefined;
                        }[];
                    } | undefined;
                }): UserTrophiesResponse;
                fromPartial(object: {
                    kind?: string | undefined | undefined;
                    data?: {
                        trophies?: {
                            kind?: string | undefined | undefined;
                            data?: {
                                icon70?: string | undefined | undefined;
                                grantedAt?: number | undefined | undefined;
                                url?: string | undefined | undefined;
                                icon40?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                awardId?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                description?: string | undefined | undefined;
                            } | undefined;
                        }[];
                    } | undefined;
                }): UserTrophiesResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#GET_user_username_about */
        readonly userAbout: {
            readonly name: "UserAbout";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.UserAboutRequest";
                encode(message: UserAboutRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UserAboutRequest;
                fromJSON(object: any): UserAboutRequest;
                toJSON(message: UserAboutRequest): unknown;
                create(base?: {
                    username?: string;
                }): UserAboutRequest;
                fromPartial(object: {
                    username?: string;
                }): UserAboutRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.users.UserAboutResponse";
                encode(message: UserAboutResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UserAboutResponse;
                fromJSON(object: any): UserAboutResponse;
                toJSON(message: UserAboutResponse): unknown;
                create(base?: {
                    kind?: string | undefined | undefined;
                    data?: {
                        acceptChats?: boolean | undefined | undefined;
                        acceptFollowers?: boolean | undefined | undefined;
                        acceptPms?: boolean | undefined | undefined;
                        awardeeKarma?: number | undefined | undefined;
                        awarderKarma?: number | undefined | undefined;
                        canCreateSubreddit?: boolean | undefined | undefined;
                        canEditName?: boolean | undefined | undefined;
                        coins?: number | undefined | undefined;
                        commentKarma?: number | undefined | undefined;
                        created?: number | undefined | undefined;
                        createdUtc?: number | undefined | undefined;
                        features?: {
                            awardsOnStreams?: boolean | undefined | undefined;
                            canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                            chatGroupRollout?: boolean | undefined | undefined;
                            chatSubreddit?: boolean | undefined | undefined;
                            chatUserSettings?: boolean | undefined | undefined;
                            chat?: boolean | undefined | undefined;
                            cookieConsentBanner?: boolean | undefined | undefined;
                            crosspostNotif?: boolean | undefined | undefined;
                            crowdControlForPost?: boolean | undefined | undefined;
                            customFeedImage?: boolean | undefined | undefined;
                            doNotTrack?: boolean | undefined | undefined;
                            expensiveCoinsPackage?: boolean | undefined | undefined;
                            isEmailPermissionRequired?: boolean | undefined | undefined;
                            liveComments?: boolean | undefined | undefined;
                            liveOrangereds?: boolean | undefined | undefined;
                            modAwards?: boolean | undefined | undefined;
                            modServiceMuteReads?: boolean | undefined | undefined;
                            modServiceMuteWrites?: boolean | undefined | undefined;
                            modlogCopyrightRemoval?: boolean | undefined | undefined;
                            mwebNsfwXpromo?: {
                                experimentId?: number | undefined | undefined;
                                owner?: string | undefined | undefined;
                                variant?: string | undefined | undefined;
                            } | undefined;
                            mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                            mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                            mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                            mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                            mwebXpromoRevampV2?: {
                                experimentId?: number | undefined | undefined;
                                owner?: string | undefined | undefined;
                                variant?: string | undefined | undefined;
                            } | undefined;
                            mwebXpromoRevampV3?: {
                                experimentId?: number | undefined | undefined;
                                owner?: string | undefined | undefined;
                                variant?: string | undefined | undefined;
                            } | undefined;
                            noreferrerToNoopener?: boolean | undefined | undefined;
                            pollsMobile?: boolean | undefined | undefined;
                            premiumSubscriptionsTable?: boolean | undefined | undefined;
                            promotedTrendBlanks?: boolean | undefined | undefined;
                            resizedStylesImages?: boolean | undefined | undefined;
                            showAmpLink?: boolean | undefined | undefined;
                            showNpsSurvey?: boolean | undefined | undefined;
                            spezModal?: boolean | undefined | undefined;
                            usePrefAccountDeployment?: boolean | undefined | undefined;
                            userFlairMigrationTesting?: boolean | undefined | undefined;
                            webhookConfig?: boolean | undefined | undefined;
                        } | undefined;
                        forcePasswordReset?: boolean | undefined | undefined;
                        goldCreddits?: number | undefined | undefined;
                        goldExpiration?: string | undefined | undefined;
                        hasAndroidSubscription?: boolean | undefined | undefined;
                        hasExternalAccount?: boolean | undefined | undefined;
                        hasGoldSubscription?: boolean | undefined | undefined;
                        hasIosSubscription?: boolean | undefined | undefined;
                        hasMail?: boolean | undefined | undefined;
                        hasModMail?: boolean | undefined | undefined;
                        hasPaypalSubscription?: boolean | undefined | undefined;
                        hasStripeSubscription?: boolean | undefined | undefined;
                        hasSubscribed?: boolean | undefined | undefined;
                        hasSubscribedToPremium?: boolean | undefined | undefined;
                        hasVerifiedEmail?: boolean | undefined | undefined;
                        hasVisitedNewProfile?: boolean | undefined | undefined;
                        hideFromRobots?: boolean | undefined | undefined;
                        iconImg?: string | undefined | undefined;
                        id?: string | undefined | undefined;
                        inBeta?: boolean | undefined | undefined;
                        inChat?: boolean | undefined | undefined;
                        inRedesignBeta?: boolean | undefined | undefined;
                        inboxCount?: number | undefined | undefined;
                        isBlocked?: boolean | undefined | undefined;
                        isEmployee?: boolean | undefined | undefined;
                        isFriend?: boolean | undefined | undefined;
                        isGold?: boolean | undefined | undefined;
                        isMod?: boolean | undefined | undefined;
                        isSponsor?: boolean | undefined | undefined;
                        isSuspended?: boolean | undefined | undefined;
                        linkKarma?: number | undefined | undefined;
                        modhash?: string | undefined | undefined;
                        name?: string | undefined | undefined;
                        newModmailExists?: boolean | undefined | undefined;
                        numFriends?: number | undefined | undefined;
                        over18?: boolean | undefined | undefined;
                        passwordSet?: boolean | undefined | undefined;
                        prefAutoplay?: boolean | undefined | undefined;
                        prefClickgadget?: number | undefined | undefined;
                        prefGeopopular?: string | undefined | undefined;
                        prefNightmode?: boolean | undefined | undefined;
                        prefNoProfanity?: boolean | undefined | undefined;
                        prefShowPresence?: boolean | undefined | undefined;
                        prefShowSnoovatar?: boolean | undefined | undefined;
                        prefShowTrending?: boolean | undefined | undefined;
                        prefShowTwitter?: boolean | undefined | undefined;
                        prefTopKarmaSubreddits?: boolean | undefined | undefined;
                        prefVideoAutoplay?: boolean | undefined | undefined;
                        snoovatarImg?: string | undefined | undefined;
                        snoovatarSize?: number[];
                        subreddit?: {
                            acceptFollowers?: boolean | undefined | undefined;
                            accountsActiveIsFuzzed?: boolean | undefined | undefined;
                            accountsActive?: number | undefined | undefined;
                            activeUserCount?: number | undefined | undefined;
                            advertiserCategory?: string | undefined | undefined;
                            allOriginalContent?: boolean | undefined | undefined;
                            allowChatPostCreation?: boolean | undefined | undefined;
                            allowDiscovery?: boolean | undefined | undefined;
                            allowGalleries?: boolean | undefined | undefined;
                            allowImages?: boolean | undefined | undefined;
                            allowPolls?: boolean | undefined | undefined;
                            allowPredictionContributors?: boolean | undefined | undefined;
                            allowPredictionsTournament?: boolean | undefined | undefined;
                            allowPredictions?: boolean | undefined | undefined;
                            allowTalks?: boolean | undefined | undefined;
                            allowVideogifs?: boolean | undefined | undefined;
                            allowVideos?: boolean | undefined | undefined;
                            allowedMediaInComments?: string[];
                            bannerBackgroundColor?: string | undefined | undefined;
                            bannerBackgroundImage?: string | undefined | undefined;
                            bannerImg?: string | undefined | undefined;
                            bannerSize?: number[];
                            canAssignLinkFlair?: boolean | undefined | undefined;
                            canAssignUserFlair?: boolean | undefined | undefined;
                            coins?: number | undefined | undefined;
                            collapseDeletedComments?: boolean | undefined | undefined;
                            commentContributionSettings?: {
                                allowedMediaTypes?: string[];
                            } | undefined;
                            commentScoreHideMins?: number | undefined | undefined;
                            communityIcon?: string | undefined | undefined;
                            communityReviewed?: boolean | undefined | undefined;
                            contentCategory?: string | undefined | undefined;
                            createdUtc?: number | undefined | undefined;
                            created?: number | undefined | undefined;
                            defaultSet?: boolean | undefined | undefined;
                            description?: string | undefined | undefined;
                            descriptionHtml?: string | undefined | undefined;
                            disableContributorRequests?: boolean | undefined | undefined;
                            displayName?: string | undefined | undefined;
                            displayNamePrefixed?: string | undefined | undefined;
                            emojisCustomSize?: number[];
                            emojisEnabled?: boolean | undefined | undefined;
                            freeFormReports?: boolean | undefined | undefined;
                            hasMenuWidget?: boolean | undefined | undefined;
                            headerImg?: string | undefined | undefined;
                            headerSize?: number[];
                            headerTitle?: string | undefined | undefined;
                            hideAds?: boolean | undefined | undefined;
                            iconColor?: string | undefined | undefined;
                            iconImg?: string | undefined | undefined;
                            iconSize?: number[];
                            id?: string | undefined | undefined;
                            isChatPostFeatureEnabled?: boolean | undefined | undefined;
                            isCrosspostableSubreddit?: boolean | undefined | undefined;
                            isDefaultBanner?: boolean | undefined | undefined;
                            isDefaultIcon?: boolean | undefined | undefined;
                            isEnrolledInNewModmail?: boolean | undefined | undefined;
                            keyColor?: string | undefined | undefined;
                            lang?: string | undefined | undefined;
                            linkFlairEnabled?: boolean | undefined | undefined;
                            linkFlairPosition?: string | undefined | undefined;
                            mobileBannerImage?: string | undefined | undefined;
                            name?: string | undefined | undefined;
                            notificationLevel?: string | undefined | undefined;
                            originalContentTagEnabled?: string | undefined | undefined;
                            over18?: boolean | undefined | undefined;
                            predictionLeaderboardEntryType?: string | undefined | undefined;
                            previousNames?: string[];
                            primaryColor?: string | undefined | undefined;
                            publicDescription?: string | undefined | undefined;
                            publicDescriptionHtml?: string | undefined | undefined;
                            publicTraffic?: boolean | undefined | undefined;
                            quarantine?: boolean | undefined | undefined;
                            restrictCommenting?: boolean | undefined | undefined;
                            restrictPosting?: boolean | undefined | undefined;
                            shouldArchivePosts?: boolean | undefined | undefined;
                            shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                            showMedia?: boolean | undefined | undefined;
                            showMediaPreview?: boolean | undefined | undefined;
                            spoilersEnabled?: boolean | undefined | undefined;
                            submissionType?: string | undefined | undefined;
                            submitLinkLabel?: string | undefined | undefined;
                            submitText?: string | undefined | undefined;
                            submitTextHtml?: string | undefined | undefined;
                            submitTextLabel?: string | undefined | undefined;
                            subredditType?: string | undefined | undefined;
                            subscribers?: number | undefined | undefined;
                            suggestedCommentSort?: string | undefined | undefined;
                            title?: string | undefined | undefined;
                            url?: string | undefined | undefined;
                            userCanFlairInSr?: boolean | undefined | undefined;
                            userFlairBackgroundColor?: string | undefined | undefined;
                            userFlairCssClass?: string | undefined | undefined;
                            userFlairEnabledInSr?: boolean | undefined | undefined;
                            userFlairPosition?: string | undefined | undefined;
                            userFlairRichtext?: {
                                e?: string | undefined | undefined;
                                t?: string | undefined | undefined;
                            }[];
                            userFlairTemplateId?: string | undefined | undefined;
                            userFlairText?: string | undefined | undefined;
                            userFlairTextColor?: string | undefined | undefined;
                            userFlairType?: string | undefined | undefined;
                            userHasFavorited?: boolean | undefined | undefined;
                            userIsBanned?: boolean | undefined | undefined;
                            userIsContributor?: boolean | undefined | undefined;
                            userIsModerator?: boolean | undefined | undefined;
                            userIsSubscriber?: boolean | undefined | undefined;
                            userSrFlairEnabled?: boolean | undefined | undefined;
                            userSrThemeEnabled?: boolean | undefined | undefined;
                            videostreamLinksCount?: number | undefined | undefined;
                            whitelistStatus?: string | undefined | undefined;
                            wikiEnabled?: boolean | undefined | undefined;
                            wls?: number | undefined | undefined;
                            markedSpam?: boolean | undefined | undefined;
                            postRequirements?: {
                                bodyRestrictionPolicy?: string | undefined | undefined;
                            } | undefined;
                            userIsMuted?: boolean;
                        } | undefined;
                        suspensionExpirationUtc?: string | undefined | undefined;
                        totalKarma?: number | undefined | undefined;
                        verified?: boolean | undefined | undefined;
                        hasPhoneNumber?: boolean | undefined | undefined;
                        subredditsModerated?: number | undefined | undefined;
                        hasMetaSubscription?: boolean | undefined | undefined;
                        metaSubscriptionAge?: number | undefined | undefined;
                        metaPointsBalance?: string | undefined | undefined;
                        metaLockedPointsBalance?: string | undefined | undefined;
                        commentSubredditKarma?: number | undefined | undefined;
                        postSubredditKarma?: number | undefined | undefined;
                        markedSpam?: boolean | undefined | undefined;
                        isSubredditProxyAccount?: boolean | undefined | undefined;
                    } | undefined;
                }): UserAboutResponse;
                fromPartial(object: {
                    kind?: string | undefined | undefined;
                    data?: {
                        acceptChats?: boolean | undefined | undefined;
                        acceptFollowers?: boolean | undefined | undefined;
                        acceptPms?: boolean | undefined | undefined;
                        awardeeKarma?: number | undefined | undefined;
                        awarderKarma?: number | undefined | undefined;
                        canCreateSubreddit?: boolean | undefined | undefined;
                        canEditName?: boolean | undefined | undefined;
                        coins?: number | undefined | undefined;
                        commentKarma?: number | undefined | undefined;
                        created?: number | undefined | undefined;
                        createdUtc?: number | undefined | undefined;
                        features?: {
                            awardsOnStreams?: boolean | undefined | undefined;
                            canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                            chatGroupRollout?: boolean | undefined | undefined;
                            chatSubreddit?: boolean | undefined | undefined;
                            chatUserSettings?: boolean | undefined | undefined;
                            chat?: boolean | undefined | undefined;
                            cookieConsentBanner?: boolean | undefined | undefined;
                            crosspostNotif?: boolean | undefined | undefined;
                            crowdControlForPost?: boolean | undefined | undefined;
                            customFeedImage?: boolean | undefined | undefined;
                            doNotTrack?: boolean | undefined | undefined;
                            expensiveCoinsPackage?: boolean | undefined | undefined;
                            isEmailPermissionRequired?: boolean | undefined | undefined;
                            liveComments?: boolean | undefined | undefined;
                            liveOrangereds?: boolean | undefined | undefined;
                            modAwards?: boolean | undefined | undefined;
                            modServiceMuteReads?: boolean | undefined | undefined;
                            modServiceMuteWrites?: boolean | undefined | undefined;
                            modlogCopyrightRemoval?: boolean | undefined | undefined;
                            mwebNsfwXpromo?: {
                                experimentId?: number | undefined | undefined;
                                owner?: string | undefined | undefined;
                                variant?: string | undefined | undefined;
                            } | undefined;
                            mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                            mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                            mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                            mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                            mwebXpromoRevampV2?: {
                                experimentId?: number | undefined | undefined;
                                owner?: string | undefined | undefined;
                                variant?: string | undefined | undefined;
                            } | undefined;
                            mwebXpromoRevampV3?: {
                                experimentId?: number | undefined | undefined;
                                owner?: string | undefined | undefined;
                                variant?: string | undefined | undefined;
                            } | undefined;
                            noreferrerToNoopener?: boolean | undefined | undefined;
                            pollsMobile?: boolean | undefined | undefined;
                            premiumSubscriptionsTable?: boolean | undefined | undefined;
                            promotedTrendBlanks?: boolean | undefined | undefined;
                            resizedStylesImages?: boolean | undefined | undefined;
                            showAmpLink?: boolean | undefined | undefined;
                            showNpsSurvey?: boolean | undefined | undefined;
                            spezModal?: boolean | undefined | undefined;
                            usePrefAccountDeployment?: boolean | undefined | undefined;
                            userFlairMigrationTesting?: boolean | undefined | undefined;
                            webhookConfig?: boolean | undefined | undefined;
                        } | undefined;
                        forcePasswordReset?: boolean | undefined | undefined;
                        goldCreddits?: number | undefined | undefined;
                        goldExpiration?: string | undefined | undefined;
                        hasAndroidSubscription?: boolean | undefined | undefined;
                        hasExternalAccount?: boolean | undefined | undefined;
                        hasGoldSubscription?: boolean | undefined | undefined;
                        hasIosSubscription?: boolean | undefined | undefined;
                        hasMail?: boolean | undefined | undefined;
                        hasModMail?: boolean | undefined | undefined;
                        hasPaypalSubscription?: boolean | undefined | undefined;
                        hasStripeSubscription?: boolean | undefined | undefined;
                        hasSubscribed?: boolean | undefined | undefined;
                        hasSubscribedToPremium?: boolean | undefined | undefined;
                        hasVerifiedEmail?: boolean | undefined | undefined;
                        hasVisitedNewProfile?: boolean | undefined | undefined;
                        hideFromRobots?: boolean | undefined | undefined;
                        iconImg?: string | undefined | undefined;
                        id?: string | undefined | undefined;
                        inBeta?: boolean | undefined | undefined;
                        inChat?: boolean | undefined | undefined;
                        inRedesignBeta?: boolean | undefined | undefined;
                        inboxCount?: number | undefined | undefined;
                        isBlocked?: boolean | undefined | undefined;
                        isEmployee?: boolean | undefined | undefined;
                        isFriend?: boolean | undefined | undefined;
                        isGold?: boolean | undefined | undefined;
                        isMod?: boolean | undefined | undefined;
                        isSponsor?: boolean | undefined | undefined;
                        isSuspended?: boolean | undefined | undefined;
                        linkKarma?: number | undefined | undefined;
                        modhash?: string | undefined | undefined;
                        name?: string | undefined | undefined;
                        newModmailExists?: boolean | undefined | undefined;
                        numFriends?: number | undefined | undefined;
                        over18?: boolean | undefined | undefined;
                        passwordSet?: boolean | undefined | undefined;
                        prefAutoplay?: boolean | undefined | undefined;
                        prefClickgadget?: number | undefined | undefined;
                        prefGeopopular?: string | undefined | undefined;
                        prefNightmode?: boolean | undefined | undefined;
                        prefNoProfanity?: boolean | undefined | undefined;
                        prefShowPresence?: boolean | undefined | undefined;
                        prefShowSnoovatar?: boolean | undefined | undefined;
                        prefShowTrending?: boolean | undefined | undefined;
                        prefShowTwitter?: boolean | undefined | undefined;
                        prefTopKarmaSubreddits?: boolean | undefined | undefined;
                        prefVideoAutoplay?: boolean | undefined | undefined;
                        snoovatarImg?: string | undefined | undefined;
                        snoovatarSize?: number[];
                        subreddit?: {
                            acceptFollowers?: boolean | undefined | undefined;
                            accountsActiveIsFuzzed?: boolean | undefined | undefined;
                            accountsActive?: number | undefined | undefined;
                            activeUserCount?: number | undefined | undefined;
                            advertiserCategory?: string | undefined | undefined;
                            allOriginalContent?: boolean | undefined | undefined;
                            allowChatPostCreation?: boolean | undefined | undefined;
                            allowDiscovery?: boolean | undefined | undefined;
                            allowGalleries?: boolean | undefined | undefined;
                            allowImages?: boolean | undefined | undefined;
                            allowPolls?: boolean | undefined | undefined;
                            allowPredictionContributors?: boolean | undefined | undefined;
                            allowPredictionsTournament?: boolean | undefined | undefined;
                            allowPredictions?: boolean | undefined | undefined;
                            allowTalks?: boolean | undefined | undefined;
                            allowVideogifs?: boolean | undefined | undefined;
                            allowVideos?: boolean | undefined | undefined;
                            allowedMediaInComments?: string[];
                            bannerBackgroundColor?: string | undefined | undefined;
                            bannerBackgroundImage?: string | undefined | undefined;
                            bannerImg?: string | undefined | undefined;
                            bannerSize?: number[];
                            canAssignLinkFlair?: boolean | undefined | undefined;
                            canAssignUserFlair?: boolean | undefined | undefined;
                            coins?: number | undefined | undefined;
                            collapseDeletedComments?: boolean | undefined | undefined;
                            commentContributionSettings?: {
                                allowedMediaTypes?: string[];
                            } | undefined;
                            commentScoreHideMins?: number | undefined | undefined;
                            communityIcon?: string | undefined | undefined;
                            communityReviewed?: boolean | undefined | undefined;
                            contentCategory?: string | undefined | undefined;
                            createdUtc?: number | undefined | undefined;
                            created?: number | undefined | undefined;
                            defaultSet?: boolean | undefined | undefined;
                            description?: string | undefined | undefined;
                            descriptionHtml?: string | undefined | undefined;
                            disableContributorRequests?: boolean | undefined | undefined;
                            displayName?: string | undefined | undefined;
                            displayNamePrefixed?: string | undefined | undefined;
                            emojisCustomSize?: number[];
                            emojisEnabled?: boolean | undefined | undefined;
                            freeFormReports?: boolean | undefined | undefined;
                            hasMenuWidget?: boolean | undefined | undefined;
                            headerImg?: string | undefined | undefined;
                            headerSize?: number[];
                            headerTitle?: string | undefined | undefined;
                            hideAds?: boolean | undefined | undefined;
                            iconColor?: string | undefined | undefined;
                            iconImg?: string | undefined | undefined;
                            iconSize?: number[];
                            id?: string | undefined | undefined;
                            isChatPostFeatureEnabled?: boolean | undefined | undefined;
                            isCrosspostableSubreddit?: boolean | undefined | undefined;
                            isDefaultBanner?: boolean | undefined | undefined;
                            isDefaultIcon?: boolean | undefined | undefined;
                            isEnrolledInNewModmail?: boolean | undefined | undefined;
                            keyColor?: string | undefined | undefined;
                            lang?: string | undefined | undefined;
                            linkFlairEnabled?: boolean | undefined | undefined;
                            linkFlairPosition?: string | undefined | undefined;
                            mobileBannerImage?: string | undefined | undefined;
                            name?: string | undefined | undefined;
                            notificationLevel?: string | undefined | undefined;
                            originalContentTagEnabled?: string | undefined | undefined;
                            over18?: boolean | undefined | undefined;
                            predictionLeaderboardEntryType?: string | undefined | undefined;
                            previousNames?: string[];
                            primaryColor?: string | undefined | undefined;
                            publicDescription?: string | undefined | undefined;
                            publicDescriptionHtml?: string | undefined | undefined;
                            publicTraffic?: boolean | undefined | undefined;
                            quarantine?: boolean | undefined | undefined;
                            restrictCommenting?: boolean | undefined | undefined;
                            restrictPosting?: boolean | undefined | undefined;
                            shouldArchivePosts?: boolean | undefined | undefined;
                            shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                            showMedia?: boolean | undefined | undefined;
                            showMediaPreview?: boolean | undefined | undefined;
                            spoilersEnabled?: boolean | undefined | undefined;
                            submissionType?: string | undefined | undefined;
                            submitLinkLabel?: string | undefined | undefined;
                            submitText?: string | undefined | undefined;
                            submitTextHtml?: string | undefined | undefined;
                            submitTextLabel?: string | undefined | undefined;
                            subredditType?: string | undefined | undefined;
                            subscribers?: number | undefined | undefined;
                            suggestedCommentSort?: string | undefined | undefined;
                            title?: string | undefined | undefined;
                            url?: string | undefined | undefined;
                            userCanFlairInSr?: boolean | undefined | undefined;
                            userFlairBackgroundColor?: string | undefined | undefined;
                            userFlairCssClass?: string | undefined | undefined;
                            userFlairEnabledInSr?: boolean | undefined | undefined;
                            userFlairPosition?: string | undefined | undefined;
                            userFlairRichtext?: {
                                e?: string | undefined | undefined;
                                t?: string | undefined | undefined;
                            }[];
                            userFlairTemplateId?: string | undefined | undefined;
                            userFlairText?: string | undefined | undefined;
                            userFlairTextColor?: string | undefined | undefined;
                            userFlairType?: string | undefined | undefined;
                            userHasFavorited?: boolean | undefined | undefined;
                            userIsBanned?: boolean | undefined | undefined;
                            userIsContributor?: boolean | undefined | undefined;
                            userIsModerator?: boolean | undefined | undefined;
                            userIsSubscriber?: boolean | undefined | undefined;
                            userSrFlairEnabled?: boolean | undefined | undefined;
                            userSrThemeEnabled?: boolean | undefined | undefined;
                            videostreamLinksCount?: number | undefined | undefined;
                            whitelistStatus?: string | undefined | undefined;
                            wikiEnabled?: boolean | undefined | undefined;
                            wls?: number | undefined | undefined;
                            markedSpam?: boolean | undefined | undefined;
                            postRequirements?: {
                                bodyRestrictionPolicy?: string | undefined | undefined;
                            } | undefined;
                            userIsMuted?: boolean;
                        } | undefined;
                        suspensionExpirationUtc?: string | undefined | undefined;
                        totalKarma?: number | undefined | undefined;
                        verified?: boolean | undefined | undefined;
                        hasPhoneNumber?: boolean | undefined | undefined;
                        subredditsModerated?: number | undefined | undefined;
                        hasMetaSubscription?: boolean | undefined | undefined;
                        metaSubscriptionAge?: number | undefined | undefined;
                        metaPointsBalance?: string | undefined | undefined;
                        metaLockedPointsBalance?: string | undefined | undefined;
                        commentSubredditKarma?: number | undefined | undefined;
                        postSubredditKarma?: number | undefined | undefined;
                        markedSpam?: boolean | undefined | undefined;
                        isSubredditProxyAccount?: boolean | undefined | undefined;
                    } | undefined;
                }): UserAboutResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /** https://www.reddit.com/dev/api#GET_user_username_where */
        readonly userWhere: {
            readonly name: "UserWhere";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.users.UserWhereRequest";
                encode(message: UserWhereRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UserWhereRequest;
                fromJSON(object: any): UserWhereRequest;
                toJSON(message: UserWhereRequest): unknown;
                create(base?: {
                    context?: number | undefined | undefined;
                    show?: string | undefined | undefined;
                    sort?: string | undefined | undefined;
                    t?: string | undefined | undefined;
                    type?: string | undefined | undefined;
                    after?: string | undefined | undefined;
                    before?: string | undefined | undefined;
                    count?: number | undefined | undefined;
                    limit?: number | undefined | undefined;
                    username?: string | undefined | undefined;
                    where?: string;
                }): UserWhereRequest;
                fromPartial(object: {
                    context?: number | undefined | undefined;
                    show?: string | undefined | undefined;
                    sort?: string | undefined | undefined;
                    t?: string | undefined | undefined;
                    type?: string | undefined | undefined;
                    after?: string | undefined | undefined;
                    before?: string | undefined | undefined;
                    count?: number | undefined | undefined;
                    limit?: number | undefined | undefined;
                    username?: string | undefined | undefined;
                    where?: string;
                }): UserWhereRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.common.Listing";
                encode(message: Listing, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Listing;
                fromJSON(object: any): Listing;
                toJSON(message: Listing): unknown;
                create(base?: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            kind?: string;
                            data?: {
                                allAwardings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                approved?: boolean | undefined | undefined;
                                approvedAtUtc?: number | undefined | undefined;
                                approvedBy?: string | undefined | undefined;
                                archived?: boolean | undefined | undefined;
                                associatedAward?: string | undefined | undefined;
                                author?: string | undefined | undefined;
                                authorFlairBackgroundColor?: string | undefined | undefined;
                                authorFlairCssClass?: string | undefined | undefined;
                                authorFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                authorFlairTemplateId?: string | undefined | undefined;
                                authorFlairText?: string | undefined | undefined;
                                authorFlairTextColor?: string | undefined | undefined;
                                authorFlairType?: string | undefined | undefined;
                                authorFullname?: string | undefined | undefined;
                                authorIsBlocked?: boolean | undefined | undefined;
                                authorPatreonFlair?: boolean | undefined | undefined;
                                authorPremium?: boolean | undefined | undefined;
                                awarders?: string[];
                                bannedAtUtc?: number | undefined | undefined;
                                bannedBy?: string | undefined | undefined;
                                body?: string | undefined | undefined;
                                bodyHtml?: string | undefined | undefined;
                                canGild?: boolean | undefined | undefined;
                                canModPost?: boolean | undefined | undefined;
                                collapsed?: boolean | undefined | undefined;
                                collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                collapsedReason?: string | undefined | undefined;
                                collapsedReasonCode?: string | undefined | undefined;
                                commentType?: string | undefined | undefined;
                                controversiality?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                distinguished?: string | undefined | undefined;
                                downs?: number | undefined | undefined;
                                edited?: boolean | undefined | undefined;
                                gilded?: number | undefined | undefined;
                                gildings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                } | undefined;
                                id?: string | undefined | undefined;
                                ignoreReports?: boolean | undefined | undefined;
                                isSubmitter?: boolean | undefined | undefined;
                                likes?: boolean | undefined | undefined;
                                linkId?: string | undefined | undefined;
                                locked?: boolean | undefined | undefined;
                                modNote?: string | undefined | undefined;
                                modReasonBy?: string | undefined | undefined;
                                modReasonTitle?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                noFollow?: boolean | undefined | undefined;
                                numReports?: number | undefined | undefined;
                                parentId?: string | undefined | undefined;
                                permalink?: string | undefined | undefined;
                                removalReason?: string | undefined | undefined;
                                removed?: boolean | undefined | undefined;
                                replies?: string | undefined | undefined;
                                reportReasons?: any[] | undefined;
                                rteMode?: string | undefined | undefined;
                                saved?: boolean | undefined | undefined;
                                score?: number | undefined | undefined;
                                scoreHidden?: boolean | undefined | undefined;
                                sendReplies?: boolean | undefined | undefined;
                                spam?: boolean | undefined | undefined;
                                stickied?: boolean | undefined | undefined;
                                subreddit?: string | undefined | undefined;
                                subredditId?: string | undefined | undefined;
                                subredditNamePrefixed?: string | undefined | undefined;
                                subredditType?: string | undefined | undefined;
                                topAwardedType?: string | undefined | undefined;
                                totalAwardsReceived?: number | undefined | undefined;
                                treatmentTags?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                unrepliableReason?: string | undefined | undefined;
                                ups?: number | undefined | undefined;
                                depth?: number | undefined | undefined;
                                linkTitle?: string | undefined | undefined;
                                linkAuthor?: string | undefined | undefined;
                                numComments?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                linkPermalink?: string | undefined | undefined;
                                quarantine?: boolean | undefined | undefined;
                                linkUrl?: string | undefined | undefined;
                                selftext?: string | undefined | undefined;
                                selftextHtml?: string | undefined | undefined;
                                thumbnail?: string | undefined | undefined;
                                thumbnailWidth?: number | undefined | undefined;
                                thumbnailHeight?: number | undefined | undefined;
                                title?: string | undefined | undefined;
                                url?: string | undefined | undefined;
                                displayName?: string | undefined | undefined;
                                modPermissions?: string[];
                                count?: number | undefined | undefined;
                                children?: any[] | undefined;
                                replyList?: /*elided*/ any | undefined;
                                hidden?: boolean | undefined | undefined;
                                linkFlairBackgroundColor?: string | undefined | undefined;
                                linkFlairCssClass?: string | undefined | undefined;
                                linkFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                linkFlairTemplateId?: string | undefined | undefined;
                                linkFlairText?: string | undefined | undefined;
                                linkFlairTextColor?: string | undefined | undefined;
                                linkFlairType?: string | undefined | undefined;
                                secureMedia?: {
                                    type?: string;
                                    oembed?: {
                                        type?: string;
                                        title?: string | undefined | undefined;
                                        providerName?: string | undefined | undefined;
                                        providerUrl?: string | undefined | undefined;
                                        version?: string;
                                        thumbnailWidth?: number | undefined | undefined;
                                        thumbnailHeight?: number | undefined | undefined;
                                        thumbnailUrl?: string | undefined | undefined;
                                        html?: string;
                                        height?: number | undefined | undefined;
                                        width?: number | undefined | undefined;
                                        authorUrl?: string | undefined | undefined;
                                        authorName?: string | undefined | undefined;
                                    } | undefined;
                                    redditVideo?: {
                                        bitrateKbps?: number | undefined | undefined;
                                        dashUrl?: string | undefined | undefined;
                                        duration?: number | undefined | undefined;
                                        fallbackUrl?: string | undefined | undefined;
                                        height?: number | undefined | undefined;
                                        hlsUrl?: string | undefined | undefined;
                                        isGif?: boolean | undefined | undefined;
                                        scrubberMediaUrl?: string | undefined | undefined;
                                        transcodingStatus?: string | undefined | undefined;
                                        width?: number | undefined | undefined;
                                    } | undefined;
                                } | undefined;
                                spoiler?: boolean;
                                modReports?: any[][];
                                userReports?: any[][];
                                removedBy?: string | undefined | undefined;
                                removedByCategory?: string | undefined | undefined;
                                gallery?: {
                                    url?: string;
                                    width?: number;
                                    height?: number;
                                    status?: import("../common/common_msg.js").GalleryMediaStatus;
                                }[];
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): Listing;
                fromPartial(object: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            kind?: string;
                            data?: {
                                allAwardings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                approved?: boolean | undefined | undefined;
                                approvedAtUtc?: number | undefined | undefined;
                                approvedBy?: string | undefined | undefined;
                                archived?: boolean | undefined | undefined;
                                associatedAward?: string | undefined | undefined;
                                author?: string | undefined | undefined;
                                authorFlairBackgroundColor?: string | undefined | undefined;
                                authorFlairCssClass?: string | undefined | undefined;
                                authorFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                authorFlairTemplateId?: string | undefined | undefined;
                                authorFlairText?: string | undefined | undefined;
                                authorFlairTextColor?: string | undefined | undefined;
                                authorFlairType?: string | undefined | undefined;
                                authorFullname?: string | undefined | undefined;
                                authorIsBlocked?: boolean | undefined | undefined;
                                authorPatreonFlair?: boolean | undefined | undefined;
                                authorPremium?: boolean | undefined | undefined;
                                awarders?: string[];
                                bannedAtUtc?: number | undefined | undefined;
                                bannedBy?: string | undefined | undefined;
                                body?: string | undefined | undefined;
                                bodyHtml?: string | undefined | undefined;
                                canGild?: boolean | undefined | undefined;
                                canModPost?: boolean | undefined | undefined;
                                collapsed?: boolean | undefined | undefined;
                                collapsedBecauseCrowdControl?: boolean | undefined | undefined;
                                collapsedReason?: string | undefined | undefined;
                                collapsedReasonCode?: string | undefined | undefined;
                                commentType?: string | undefined | undefined;
                                controversiality?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                distinguished?: string | undefined | undefined;
                                downs?: number | undefined | undefined;
                                edited?: boolean | undefined | undefined;
                                gilded?: number | undefined | undefined;
                                gildings?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                } | undefined;
                                id?: string | undefined | undefined;
                                ignoreReports?: boolean | undefined | undefined;
                                isSubmitter?: boolean | undefined | undefined;
                                likes?: boolean | undefined | undefined;
                                linkId?: string | undefined | undefined;
                                locked?: boolean | undefined | undefined;
                                modNote?: string | undefined | undefined;
                                modReasonBy?: string | undefined | undefined;
                                modReasonTitle?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                noFollow?: boolean | undefined | undefined;
                                numReports?: number | undefined | undefined;
                                parentId?: string | undefined | undefined;
                                permalink?: string | undefined | undefined;
                                removalReason?: string | undefined | undefined;
                                removed?: boolean | undefined | undefined;
                                replies?: string | undefined | undefined;
                                reportReasons?: any[] | undefined;
                                rteMode?: string | undefined | undefined;
                                saved?: boolean | undefined | undefined;
                                score?: number | undefined | undefined;
                                scoreHidden?: boolean | undefined | undefined;
                                sendReplies?: boolean | undefined | undefined;
                                spam?: boolean | undefined | undefined;
                                stickied?: boolean | undefined | undefined;
                                subreddit?: string | undefined | undefined;
                                subredditId?: string | undefined | undefined;
                                subredditNamePrefixed?: string | undefined | undefined;
                                subredditType?: string | undefined | undefined;
                                topAwardedType?: string | undefined | undefined;
                                totalAwardsReceived?: number | undefined | undefined;
                                treatmentTags?: {
                                    typeUrl?: string;
                                    value?: Uint8Array;
                                }[];
                                unrepliableReason?: string | undefined | undefined;
                                ups?: number | undefined | undefined;
                                depth?: number | undefined | undefined;
                                linkTitle?: string | undefined | undefined;
                                linkAuthor?: string | undefined | undefined;
                                numComments?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                linkPermalink?: string | undefined | undefined;
                                quarantine?: boolean | undefined | undefined;
                                linkUrl?: string | undefined | undefined;
                                selftext?: string | undefined | undefined;
                                selftextHtml?: string | undefined | undefined;
                                thumbnail?: string | undefined | undefined;
                                thumbnailWidth?: number | undefined | undefined;
                                thumbnailHeight?: number | undefined | undefined;
                                title?: string | undefined | undefined;
                                url?: string | undefined | undefined;
                                displayName?: string | undefined | undefined;
                                modPermissions?: string[];
                                count?: number | undefined | undefined;
                                children?: any[] | undefined;
                                replyList?: /*elided*/ any | undefined;
                                hidden?: boolean | undefined | undefined;
                                linkFlairBackgroundColor?: string | undefined | undefined;
                                linkFlairCssClass?: string | undefined | undefined;
                                linkFlairRichtext?: {
                                    e?: string | undefined | undefined;
                                    t?: string | undefined | undefined;
                                    a?: string | undefined | undefined;
                                    u?: string | undefined | undefined;
                                }[];
                                linkFlairTemplateId?: string | undefined | undefined;
                                linkFlairText?: string | undefined | undefined;
                                linkFlairTextColor?: string | undefined | undefined;
                                linkFlairType?: string | undefined | undefined;
                                secureMedia?: {
                                    type?: string;
                                    oembed?: {
                                        type?: string;
                                        title?: string | undefined | undefined;
                                        providerName?: string | undefined | undefined;
                                        providerUrl?: string | undefined | undefined;
                                        version?: string;
                                        thumbnailWidth?: number | undefined | undefined;
                                        thumbnailHeight?: number | undefined | undefined;
                                        thumbnailUrl?: string | undefined | undefined;
                                        html?: string;
                                        height?: number | undefined | undefined;
                                        width?: number | undefined | undefined;
                                        authorUrl?: string | undefined | undefined;
                                        authorName?: string | undefined | undefined;
                                    } | undefined;
                                    redditVideo?: {
                                        bitrateKbps?: number | undefined | undefined;
                                        dashUrl?: string | undefined | undefined;
                                        duration?: number | undefined | undefined;
                                        fallbackUrl?: string | undefined | undefined;
                                        height?: number | undefined | undefined;
                                        hlsUrl?: string | undefined | undefined;
                                        isGif?: boolean | undefined | undefined;
                                        scrubberMediaUrl?: string | undefined | undefined;
                                        transcodingStatus?: string | undefined | undefined;
                                        width?: number | undefined | undefined;
                                    } | undefined;
                                } | undefined;
                                spoiler?: boolean;
                                modReports?: any[][];
                                userReports?: any[][];
                                removedBy?: string | undefined | undefined;
                                removedByCategory?: string | undefined | undefined;
                                gallery?: {
                                    url?: string;
                                    width?: number;
                                    height?: number;
                                    status?: import("../common/common_msg.js").GalleryMediaStatus;
                                }[];
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): Listing;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
    };
};
interface Rpc {
    request(service: string, method: string, data: Uint8Array, metadata?: Metadata): Promise<Uint8Array>;
}
export {};
//# sourceMappingURL=users_svc.d.ts.map