/**
 * #wiki_svc.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
import { Metadata } from "../../../../../lib/Types.js";
import { Empty } from "../../../../google/protobuf/empty.js";
import { AllowEditorRequest, EditWikiPageRequest, GetWikiPageRequest, GetWikiPageResponse, GetWikiPageRevisionsRequest, GetWikiPageSettingsRequest, GetWikiPagesRequest, GetWikiPagesResponse, GetWikiRevisionsRequest, HideWikiPageRevisionRequest, HideWikiPageRevisionResponse, RevertWikiPageRequest, UpdateWikiPageSettingsRequest, WikiPageRevisionListing, WikiPageSettings } from "./wiki_msg.js";
/** WIKI - https://www.reddit.com/dev/api#section_wiki */
export interface Wiki {
    /**
     * Get a list of wiki pages for a subreddit
     *
     * @see {@link https://www.reddit.com/dev/api#GET_wiki_pages}
     */
    GetWikiPages(request: GetWikiPagesRequest, metadata?: Metadata): Promise<GetWikiPagesResponse>;
    /**
     * Get a wiki page
     *
     * @see {@link https://www.reddit.com/dev/api#GET_wiki_\{page\}}
     */
    GetWikiPage(request: GetWikiPageRequest, metadata?: Metadata): Promise<GetWikiPageResponse>;
    /**
     * Edit wiki page
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_edit}
     */
    EditWikiPage(request: EditWikiPageRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Hide a wiki page revision
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_hide}
     */
    HideWikiPageRevision(request: HideWikiPageRevisionRequest, metadata?: Metadata): Promise<HideWikiPageRevisionResponse>;
    /**
     * Get a list of revisions of a wiki page
     *
     * @see {@link https://www.reddit.com/dev/api#GET_wiki_revisions_\{page\}}
     */
    GetWikiPageRevisions(request: GetWikiPageRevisionsRequest, metadata?: Metadata): Promise<WikiPageRevisionListing>;
    /**
     * Retrieve a list of recently changed wiki pages in this subreddit
     *
     * @see {@link https://www.reddit.com/dev/api#GET_wiki_revisions}
     */
    GetWikiRevisions(request: GetWikiRevisionsRequest, metadata?: Metadata): Promise<WikiPageRevisionListing>;
    /**
     * Revert a wiki page to revision
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_revert}
     */
    RevertWikiPage(request: RevertWikiPageRequest, metadata?: Metadata): Promise<Empty>;
    /**
     * Retrieve the current permission settings for page
     *
     * @see {@link https://www.reddit.com/dev/api#GET_wiki_settings_\{page\}}
     */
    GetWikiPageSettings(request: GetWikiPageSettingsRequest, metadata?: Metadata): Promise<WikiPageSettings>;
    /**
     * Update the permissions and visibility of wiki page
     *
     * @see {@link https://www.reddit.com/dev/api#POST_wiki_settings_\{page\}}
     */
    UpdateWikiPageSettings(request: UpdateWikiPageSettingsRequest, metadata?: Metadata): Promise<WikiPageSettings>;
    /**
     * Allow/deny username to edit this wiki page
     * Note act must be either "add" or "del"
     *
     * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_alloweditor_\{act\}}
     */
    AllowEditor(request: AllowEditorRequest, metadata?: Metadata): Promise<Empty>;
}
export declare const WikiServiceName = "devvit.plugin.redditapi.wiki.Wiki";
export declare class WikiClientImpl implements Wiki {
    private readonly rpc;
    private readonly service;
    constructor(rpc: Rpc, opts?: {
        service?: string;
    });
    GetWikiPages(request: GetWikiPagesRequest, metadata?: Metadata): Promise<GetWikiPagesResponse>;
    GetWikiPage(request: GetWikiPageRequest, metadata?: Metadata): Promise<GetWikiPageResponse>;
    EditWikiPage(request: EditWikiPageRequest, metadata?: Metadata): Promise<Empty>;
    HideWikiPageRevision(request: HideWikiPageRevisionRequest, metadata?: Metadata): Promise<HideWikiPageRevisionResponse>;
    GetWikiPageRevisions(request: GetWikiPageRevisionsRequest, metadata?: Metadata): Promise<WikiPageRevisionListing>;
    GetWikiRevisions(request: GetWikiRevisionsRequest, metadata?: Metadata): Promise<WikiPageRevisionListing>;
    RevertWikiPage(request: RevertWikiPageRequest, metadata?: Metadata): Promise<Empty>;
    GetWikiPageSettings(request: GetWikiPageSettingsRequest, metadata?: Metadata): Promise<WikiPageSettings>;
    UpdateWikiPageSettings(request: UpdateWikiPageSettingsRequest, metadata?: Metadata): Promise<WikiPageSettings>;
    AllowEditor(request: AllowEditorRequest, metadata?: Metadata): Promise<Empty>;
}
/** WIKI - https://www.reddit.com/dev/api#section_wiki */
export type WikiDefinition = typeof WikiDefinition;
export declare const WikiDefinition: {
    readonly name: "Wiki";
    readonly fullName: "devvit.plugin.redditapi.wiki.Wiki";
    readonly methods: {
        /**
         * Get a list of wiki pages for a subreddit
         *
         * @see {@link https://www.reddit.com/dev/api#GET_wiki_pages}
         */
        readonly getWikiPages: {
            readonly name: "GetWikiPages";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.GetWikiPagesRequest";
                encode(message: GetWikiPagesRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWikiPagesRequest;
                fromJSON(object: any): GetWikiPagesRequest;
                toJSON(message: GetWikiPagesRequest): unknown;
                create(base?: {
                    subreddit?: string;
                }): GetWikiPagesRequest;
                fromPartial(object: {
                    subreddit?: string;
                }): GetWikiPagesRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.wiki.GetWikiPagesResponse";
                encode(message: GetWikiPagesResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWikiPagesResponse;
                fromJSON(object: any): GetWikiPagesResponse;
                toJSON(message: GetWikiPagesResponse): unknown;
                create(base?: {
                    kind?: string;
                    data?: string[];
                }): GetWikiPagesResponse;
                fromPartial(object: {
                    kind?: string;
                    data?: string[];
                }): GetWikiPagesResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Get a wiki page
         *
         * @see {@link https://www.reddit.com/dev/api#GET_wiki_\{page\}}
         */
        readonly getWikiPage: {
            readonly name: "GetWikiPage";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.GetWikiPageRequest";
                encode(message: GetWikiPageRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWikiPageRequest;
                fromJSON(object: any): GetWikiPageRequest;
                toJSON(message: GetWikiPageRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                }): GetWikiPageRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                }): GetWikiPageRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.wiki.GetWikiPageResponse";
                encode(message: GetWikiPageResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWikiPageResponse;
                fromJSON(object: any): GetWikiPageResponse;
                toJSON(message: GetWikiPageResponse): unknown;
                create(base?: {
                    kind?: string;
                    data?: {
                        contentMd?: string;
                        contentHtml?: string;
                        revisionId?: string;
                        revisionDate?: number;
                        mayRevise?: boolean;
                        reason?: string | undefined | undefined;
                        revisionBy?: {
                            id?: string | undefined | undefined;
                            data?: {
                                acceptChats?: boolean | undefined | undefined;
                                acceptFollowers?: boolean | undefined | undefined;
                                acceptPms?: boolean | undefined | undefined;
                                awardeeKarma?: number | undefined | undefined;
                                awarderKarma?: number | undefined | undefined;
                                canCreateSubreddit?: boolean | undefined | undefined;
                                canEditName?: boolean | undefined | undefined;
                                coins?: number | undefined | undefined;
                                commentKarma?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                features?: {
                                    awardsOnStreams?: boolean | undefined | undefined;
                                    canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                    chatGroupRollout?: boolean | undefined | undefined;
                                    chatSubreddit?: boolean | undefined | undefined;
                                    chatUserSettings?: boolean | undefined | undefined;
                                    chat?: boolean | undefined | undefined;
                                    cookieConsentBanner?: boolean | undefined | undefined;
                                    crosspostNotif?: boolean | undefined | undefined;
                                    crowdControlForPost?: boolean | undefined | undefined;
                                    customFeedImage?: boolean | undefined | undefined;
                                    doNotTrack?: boolean | undefined | undefined;
                                    expensiveCoinsPackage?: boolean | undefined | undefined;
                                    isEmailPermissionRequired?: boolean | undefined | undefined;
                                    liveComments?: boolean | undefined | undefined;
                                    liveOrangereds?: boolean | undefined | undefined;
                                    modAwards?: boolean | undefined | undefined;
                                    modServiceMuteReads?: boolean | undefined | undefined;
                                    modServiceMuteWrites?: boolean | undefined | undefined;
                                    modlogCopyrightRemoval?: boolean | undefined | undefined;
                                    mwebNsfwXpromo?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                    mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                    mwebXpromoRevampV2?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoRevampV3?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    noreferrerToNoopener?: boolean | undefined | undefined;
                                    pollsMobile?: boolean | undefined | undefined;
                                    premiumSubscriptionsTable?: boolean | undefined | undefined;
                                    promotedTrendBlanks?: boolean | undefined | undefined;
                                    resizedStylesImages?: boolean | undefined | undefined;
                                    showAmpLink?: boolean | undefined | undefined;
                                    showNpsSurvey?: boolean | undefined | undefined;
                                    spezModal?: boolean | undefined | undefined;
                                    usePrefAccountDeployment?: boolean | undefined | undefined;
                                    userFlairMigrationTesting?: boolean | undefined | undefined;
                                    webhookConfig?: boolean | undefined | undefined;
                                } | undefined;
                                forcePasswordReset?: boolean | undefined | undefined;
                                goldCreddits?: number | undefined | undefined;
                                goldExpiration?: string | undefined | undefined;
                                hasAndroidSubscription?: boolean | undefined | undefined;
                                hasExternalAccount?: boolean | undefined | undefined;
                                hasGoldSubscription?: boolean | undefined | undefined;
                                hasIosSubscription?: boolean | undefined | undefined;
                                hasMail?: boolean | undefined | undefined;
                                hasModMail?: boolean | undefined | undefined;
                                hasPaypalSubscription?: boolean | undefined | undefined;
                                hasStripeSubscription?: boolean | undefined | undefined;
                                hasSubscribed?: boolean | undefined | undefined;
                                hasSubscribedToPremium?: boolean | undefined | undefined;
                                hasVerifiedEmail?: boolean | undefined | undefined;
                                hasVisitedNewProfile?: boolean | undefined | undefined;
                                hideFromRobots?: boolean | undefined | undefined;
                                iconImg?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                inBeta?: boolean | undefined | undefined;
                                inChat?: boolean | undefined | undefined;
                                inRedesignBeta?: boolean | undefined | undefined;
                                inboxCount?: number | undefined | undefined;
                                isBlocked?: boolean | undefined | undefined;
                                isEmployee?: boolean | undefined | undefined;
                                isFriend?: boolean | undefined | undefined;
                                isGold?: boolean | undefined | undefined;
                                isMod?: boolean | undefined | undefined;
                                isSponsor?: boolean | undefined | undefined;
                                isSuspended?: boolean | undefined | undefined;
                                linkKarma?: number | undefined | undefined;
                                modhash?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                newModmailExists?: boolean | undefined | undefined;
                                numFriends?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                passwordSet?: boolean | undefined | undefined;
                                prefAutoplay?: boolean | undefined | undefined;
                                prefClickgadget?: number | undefined | undefined;
                                prefGeopopular?: string | undefined | undefined;
                                prefNightmode?: boolean | undefined | undefined;
                                prefNoProfanity?: boolean | undefined | undefined;
                                prefShowPresence?: boolean | undefined | undefined;
                                prefShowSnoovatar?: boolean | undefined | undefined;
                                prefShowTrending?: boolean | undefined | undefined;
                                prefShowTwitter?: boolean | undefined | undefined;
                                prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                prefVideoAutoplay?: boolean | undefined | undefined;
                                snoovatarImg?: string | undefined | undefined;
                                snoovatarSize?: number[];
                                subreddit?: {
                                    acceptFollowers?: boolean | undefined | undefined;
                                    accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                    accountsActive?: number | undefined | undefined;
                                    activeUserCount?: number | undefined | undefined;
                                    advertiserCategory?: string | undefined | undefined;
                                    allOriginalContent?: boolean | undefined | undefined;
                                    allowChatPostCreation?: boolean | undefined | undefined;
                                    allowDiscovery?: boolean | undefined | undefined;
                                    allowGalleries?: boolean | undefined | undefined;
                                    allowImages?: boolean | undefined | undefined;
                                    allowPolls?: boolean | undefined | undefined;
                                    allowPredictionContributors?: boolean | undefined | undefined;
                                    allowPredictionsTournament?: boolean | undefined | undefined;
                                    allowPredictions?: boolean | undefined | undefined;
                                    allowTalks?: boolean | undefined | undefined;
                                    allowVideogifs?: boolean | undefined | undefined;
                                    allowVideos?: boolean | undefined | undefined;
                                    allowedMediaInComments?: string[];
                                    bannerBackgroundColor?: string | undefined | undefined;
                                    bannerBackgroundImage?: string | undefined | undefined;
                                    bannerImg?: string | undefined | undefined;
                                    bannerSize?: number[];
                                    canAssignLinkFlair?: boolean | undefined | undefined;
                                    canAssignUserFlair?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    collapseDeletedComments?: boolean | undefined | undefined;
                                    commentContributionSettings?: {
                                        allowedMediaTypes?: string[];
                                    } | undefined;
                                    commentScoreHideMins?: number | undefined | undefined;
                                    communityIcon?: string | undefined | undefined;
                                    communityReviewed?: boolean | undefined | undefined;
                                    contentCategory?: string | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    defaultSet?: boolean | undefined | undefined;
                                    description?: string | undefined | undefined;
                                    descriptionHtml?: string | undefined | undefined;
                                    disableContributorRequests?: boolean | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    displayNamePrefixed?: string | undefined | undefined;
                                    emojisCustomSize?: number[];
                                    emojisEnabled?: boolean | undefined | undefined;
                                    freeFormReports?: boolean | undefined | undefined;
                                    hasMenuWidget?: boolean | undefined | undefined;
                                    headerImg?: string | undefined | undefined;
                                    headerSize?: number[];
                                    headerTitle?: string | undefined | undefined;
                                    hideAds?: boolean | undefined | undefined;
                                    iconColor?: string | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    iconSize?: number[];
                                    id?: string | undefined | undefined;
                                    isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                    isCrosspostableSubreddit?: boolean | undefined | undefined;
                                    isDefaultBanner?: boolean | undefined | undefined;
                                    isDefaultIcon?: boolean | undefined | undefined;
                                    isEnrolledInNewModmail?: boolean | undefined | undefined;
                                    keyColor?: string | undefined | undefined;
                                    lang?: string | undefined | undefined;
                                    linkFlairEnabled?: boolean | undefined | undefined;
                                    linkFlairPosition?: string | undefined | undefined;
                                    mobileBannerImage?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    notificationLevel?: string | undefined | undefined;
                                    originalContentTagEnabled?: string | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    predictionLeaderboardEntryType?: string | undefined | undefined;
                                    previousNames?: string[];
                                    primaryColor?: string | undefined | undefined;
                                    publicDescription?: string | undefined | undefined;
                                    publicDescriptionHtml?: string | undefined | undefined;
                                    publicTraffic?: boolean | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    restrictCommenting?: boolean | undefined | undefined;
                                    restrictPosting?: boolean | undefined | undefined;
                                    shouldArchivePosts?: boolean | undefined | undefined;
                                    shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                    showMedia?: boolean | undefined | undefined;
                                    showMediaPreview?: boolean | undefined | undefined;
                                    spoilersEnabled?: boolean | undefined | undefined;
                                    submissionType?: string | undefined | undefined;
                                    submitLinkLabel?: string | undefined | undefined;
                                    submitText?: string | undefined | undefined;
                                    submitTextHtml?: string | undefined | undefined;
                                    submitTextLabel?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    subscribers?: number | undefined | undefined;
                                    suggestedCommentSort?: string | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    userCanFlairInSr?: boolean | undefined | undefined;
                                    userFlairBackgroundColor?: string | undefined | undefined;
                                    userFlairCssClass?: string | undefined | undefined;
                                    userFlairEnabledInSr?: boolean | undefined | undefined;
                                    userFlairPosition?: string | undefined | undefined;
                                    userFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    userFlairTemplateId?: string | undefined | undefined;
                                    userFlairText?: string | undefined | undefined;
                                    userFlairTextColor?: string | undefined | undefined;
                                    userFlairType?: string | undefined | undefined;
                                    userHasFavorited?: boolean | undefined | undefined;
                                    userIsBanned?: boolean | undefined | undefined;
                                    userIsContributor?: boolean | undefined | undefined;
                                    userIsModerator?: boolean | undefined | undefined;
                                    userIsSubscriber?: boolean | undefined | undefined;
                                    userSrFlairEnabled?: boolean | undefined | undefined;
                                    userSrThemeEnabled?: boolean | undefined | undefined;
                                    videostreamLinksCount?: number | undefined | undefined;
                                    whitelistStatus?: string | undefined | undefined;
                                    wikiEnabled?: boolean | undefined | undefined;
                                    wls?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    postRequirements?: {
                                        bodyRestrictionPolicy?: string | undefined | undefined;
                                    } | undefined;
                                    userIsMuted?: boolean;
                                } | undefined;
                                suspensionExpirationUtc?: string | undefined | undefined;
                                totalKarma?: number | undefined | undefined;
                                verified?: boolean | undefined | undefined;
                                hasPhoneNumber?: boolean | undefined | undefined;
                                subredditsModerated?: number | undefined | undefined;
                                hasMetaSubscription?: boolean | undefined | undefined;
                                metaSubscriptionAge?: number | undefined | undefined;
                                metaPointsBalance?: string | undefined | undefined;
                                metaLockedPointsBalance?: string | undefined | undefined;
                                commentSubredditKarma?: number | undefined | undefined;
                                postSubredditKarma?: number | undefined | undefined;
                                markedSpam?: boolean | undefined | undefined;
                                isSubredditProxyAccount?: boolean | undefined | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                }): GetWikiPageResponse;
                fromPartial(object: {
                    kind?: string;
                    data?: {
                        contentMd?: string;
                        contentHtml?: string;
                        revisionId?: string;
                        revisionDate?: number;
                        mayRevise?: boolean;
                        reason?: string | undefined | undefined;
                        revisionBy?: {
                            id?: string | undefined | undefined;
                            data?: {
                                acceptChats?: boolean | undefined | undefined;
                                acceptFollowers?: boolean | undefined | undefined;
                                acceptPms?: boolean | undefined | undefined;
                                awardeeKarma?: number | undefined | undefined;
                                awarderKarma?: number | undefined | undefined;
                                canCreateSubreddit?: boolean | undefined | undefined;
                                canEditName?: boolean | undefined | undefined;
                                coins?: number | undefined | undefined;
                                commentKarma?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                features?: {
                                    awardsOnStreams?: boolean | undefined | undefined;
                                    canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                    chatGroupRollout?: boolean | undefined | undefined;
                                    chatSubreddit?: boolean | undefined | undefined;
                                    chatUserSettings?: boolean | undefined | undefined;
                                    chat?: boolean | undefined | undefined;
                                    cookieConsentBanner?: boolean | undefined | undefined;
                                    crosspostNotif?: boolean | undefined | undefined;
                                    crowdControlForPost?: boolean | undefined | undefined;
                                    customFeedImage?: boolean | undefined | undefined;
                                    doNotTrack?: boolean | undefined | undefined;
                                    expensiveCoinsPackage?: boolean | undefined | undefined;
                                    isEmailPermissionRequired?: boolean | undefined | undefined;
                                    liveComments?: boolean | undefined | undefined;
                                    liveOrangereds?: boolean | undefined | undefined;
                                    modAwards?: boolean | undefined | undefined;
                                    modServiceMuteReads?: boolean | undefined | undefined;
                                    modServiceMuteWrites?: boolean | undefined | undefined;
                                    modlogCopyrightRemoval?: boolean | undefined | undefined;
                                    mwebNsfwXpromo?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                    mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                    mwebXpromoRevampV2?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoRevampV3?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    noreferrerToNoopener?: boolean | undefined | undefined;
                                    pollsMobile?: boolean | undefined | undefined;
                                    premiumSubscriptionsTable?: boolean | undefined | undefined;
                                    promotedTrendBlanks?: boolean | undefined | undefined;
                                    resizedStylesImages?: boolean | undefined | undefined;
                                    showAmpLink?: boolean | undefined | undefined;
                                    showNpsSurvey?: boolean | undefined | undefined;
                                    spezModal?: boolean | undefined | undefined;
                                    usePrefAccountDeployment?: boolean | undefined | undefined;
                                    userFlairMigrationTesting?: boolean | undefined | undefined;
                                    webhookConfig?: boolean | undefined | undefined;
                                } | undefined;
                                forcePasswordReset?: boolean | undefined | undefined;
                                goldCreddits?: number | undefined | undefined;
                                goldExpiration?: string | undefined | undefined;
                                hasAndroidSubscription?: boolean | undefined | undefined;
                                hasExternalAccount?: boolean | undefined | undefined;
                                hasGoldSubscription?: boolean | undefined | undefined;
                                hasIosSubscription?: boolean | undefined | undefined;
                                hasMail?: boolean | undefined | undefined;
                                hasModMail?: boolean | undefined | undefined;
                                hasPaypalSubscription?: boolean | undefined | undefined;
                                hasStripeSubscription?: boolean | undefined | undefined;
                                hasSubscribed?: boolean | undefined | undefined;
                                hasSubscribedToPremium?: boolean | undefined | undefined;
                                hasVerifiedEmail?: boolean | undefined | undefined;
                                hasVisitedNewProfile?: boolean | undefined | undefined;
                                hideFromRobots?: boolean | undefined | undefined;
                                iconImg?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                inBeta?: boolean | undefined | undefined;
                                inChat?: boolean | undefined | undefined;
                                inRedesignBeta?: boolean | undefined | undefined;
                                inboxCount?: number | undefined | undefined;
                                isBlocked?: boolean | undefined | undefined;
                                isEmployee?: boolean | undefined | undefined;
                                isFriend?: boolean | undefined | undefined;
                                isGold?: boolean | undefined | undefined;
                                isMod?: boolean | undefined | undefined;
                                isSponsor?: boolean | undefined | undefined;
                                isSuspended?: boolean | undefined | undefined;
                                linkKarma?: number | undefined | undefined;
                                modhash?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                newModmailExists?: boolean | undefined | undefined;
                                numFriends?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                passwordSet?: boolean | undefined | undefined;
                                prefAutoplay?: boolean | undefined | undefined;
                                prefClickgadget?: number | undefined | undefined;
                                prefGeopopular?: string | undefined | undefined;
                                prefNightmode?: boolean | undefined | undefined;
                                prefNoProfanity?: boolean | undefined | undefined;
                                prefShowPresence?: boolean | undefined | undefined;
                                prefShowSnoovatar?: boolean | undefined | undefined;
                                prefShowTrending?: boolean | undefined | undefined;
                                prefShowTwitter?: boolean | undefined | undefined;
                                prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                prefVideoAutoplay?: boolean | undefined | undefined;
                                snoovatarImg?: string | undefined | undefined;
                                snoovatarSize?: number[];
                                subreddit?: {
                                    acceptFollowers?: boolean | undefined | undefined;
                                    accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                    accountsActive?: number | undefined | undefined;
                                    activeUserCount?: number | undefined | undefined;
                                    advertiserCategory?: string | undefined | undefined;
                                    allOriginalContent?: boolean | undefined | undefined;
                                    allowChatPostCreation?: boolean | undefined | undefined;
                                    allowDiscovery?: boolean | undefined | undefined;
                                    allowGalleries?: boolean | undefined | undefined;
                                    allowImages?: boolean | undefined | undefined;
                                    allowPolls?: boolean | undefined | undefined;
                                    allowPredictionContributors?: boolean | undefined | undefined;
                                    allowPredictionsTournament?: boolean | undefined | undefined;
                                    allowPredictions?: boolean | undefined | undefined;
                                    allowTalks?: boolean | undefined | undefined;
                                    allowVideogifs?: boolean | undefined | undefined;
                                    allowVideos?: boolean | undefined | undefined;
                                    allowedMediaInComments?: string[];
                                    bannerBackgroundColor?: string | undefined | undefined;
                                    bannerBackgroundImage?: string | undefined | undefined;
                                    bannerImg?: string | undefined | undefined;
                                    bannerSize?: number[];
                                    canAssignLinkFlair?: boolean | undefined | undefined;
                                    canAssignUserFlair?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    collapseDeletedComments?: boolean | undefined | undefined;
                                    commentContributionSettings?: {
                                        allowedMediaTypes?: string[];
                                    } | undefined;
                                    commentScoreHideMins?: number | undefined | undefined;
                                    communityIcon?: string | undefined | undefined;
                                    communityReviewed?: boolean | undefined | undefined;
                                    contentCategory?: string | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    defaultSet?: boolean | undefined | undefined;
                                    description?: string | undefined | undefined;
                                    descriptionHtml?: string | undefined | undefined;
                                    disableContributorRequests?: boolean | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    displayNamePrefixed?: string | undefined | undefined;
                                    emojisCustomSize?: number[];
                                    emojisEnabled?: boolean | undefined | undefined;
                                    freeFormReports?: boolean | undefined | undefined;
                                    hasMenuWidget?: boolean | undefined | undefined;
                                    headerImg?: string | undefined | undefined;
                                    headerSize?: number[];
                                    headerTitle?: string | undefined | undefined;
                                    hideAds?: boolean | undefined | undefined;
                                    iconColor?: string | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    iconSize?: number[];
                                    id?: string | undefined | undefined;
                                    isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                    isCrosspostableSubreddit?: boolean | undefined | undefined;
                                    isDefaultBanner?: boolean | undefined | undefined;
                                    isDefaultIcon?: boolean | undefined | undefined;
                                    isEnrolledInNewModmail?: boolean | undefined | undefined;
                                    keyColor?: string | undefined | undefined;
                                    lang?: string | undefined | undefined;
                                    linkFlairEnabled?: boolean | undefined | undefined;
                                    linkFlairPosition?: string | undefined | undefined;
                                    mobileBannerImage?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    notificationLevel?: string | undefined | undefined;
                                    originalContentTagEnabled?: string | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    predictionLeaderboardEntryType?: string | undefined | undefined;
                                    previousNames?: string[];
                                    primaryColor?: string | undefined | undefined;
                                    publicDescription?: string | undefined | undefined;
                                    publicDescriptionHtml?: string | undefined | undefined;
                                    publicTraffic?: boolean | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    restrictCommenting?: boolean | undefined | undefined;
                                    restrictPosting?: boolean | undefined | undefined;
                                    shouldArchivePosts?: boolean | undefined | undefined;
                                    shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                    showMedia?: boolean | undefined | undefined;
                                    showMediaPreview?: boolean | undefined | undefined;
                                    spoilersEnabled?: boolean | undefined | undefined;
                                    submissionType?: string | undefined | undefined;
                                    submitLinkLabel?: string | undefined | undefined;
                                    submitText?: string | undefined | undefined;
                                    submitTextHtml?: string | undefined | undefined;
                                    submitTextLabel?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    subscribers?: number | undefined | undefined;
                                    suggestedCommentSort?: string | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    userCanFlairInSr?: boolean | undefined | undefined;
                                    userFlairBackgroundColor?: string | undefined | undefined;
                                    userFlairCssClass?: string | undefined | undefined;
                                    userFlairEnabledInSr?: boolean | undefined | undefined;
                                    userFlairPosition?: string | undefined | undefined;
                                    userFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    userFlairTemplateId?: string | undefined | undefined;
                                    userFlairText?: string | undefined | undefined;
                                    userFlairTextColor?: string | undefined | undefined;
                                    userFlairType?: string | undefined | undefined;
                                    userHasFavorited?: boolean | undefined | undefined;
                                    userIsBanned?: boolean | undefined | undefined;
                                    userIsContributor?: boolean | undefined | undefined;
                                    userIsModerator?: boolean | undefined | undefined;
                                    userIsSubscriber?: boolean | undefined | undefined;
                                    userSrFlairEnabled?: boolean | undefined | undefined;
                                    userSrThemeEnabled?: boolean | undefined | undefined;
                                    videostreamLinksCount?: number | undefined | undefined;
                                    whitelistStatus?: string | undefined | undefined;
                                    wikiEnabled?: boolean | undefined | undefined;
                                    wls?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    postRequirements?: {
                                        bodyRestrictionPolicy?: string | undefined | undefined;
                                    } | undefined;
                                    userIsMuted?: boolean;
                                } | undefined;
                                suspensionExpirationUtc?: string | undefined | undefined;
                                totalKarma?: number | undefined | undefined;
                                verified?: boolean | undefined | undefined;
                                hasPhoneNumber?: boolean | undefined | undefined;
                                subredditsModerated?: number | undefined | undefined;
                                hasMetaSubscription?: boolean | undefined | undefined;
                                metaSubscriptionAge?: number | undefined | undefined;
                                metaPointsBalance?: string | undefined | undefined;
                                metaLockedPointsBalance?: string | undefined | undefined;
                                commentSubredditKarma?: number | undefined | undefined;
                                postSubredditKarma?: number | undefined | undefined;
                                markedSpam?: boolean | undefined | undefined;
                                isSubredditProxyAccount?: boolean | undefined | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                }): GetWikiPageResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Edit wiki page
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_edit}
         */
        readonly editWikiPage: {
            readonly name: "EditWikiPage";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.EditWikiPageRequest";
                encode(message: EditWikiPageRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): EditWikiPageRequest;
                fromJSON(object: any): EditWikiPageRequest;
                toJSON(message: EditWikiPageRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                    content?: string;
                    reason?: string;
                }): EditWikiPageRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                    content?: string;
                    reason?: string;
                }): EditWikiPageRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Hide a wiki page revision
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_hide}
         */
        readonly hideWikiPageRevision: {
            readonly name: "HideWikiPageRevision";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.HideWikiPageRevisionRequest";
                encode(message: HideWikiPageRevisionRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): HideWikiPageRevisionRequest;
                fromJSON(object: any): HideWikiPageRevisionRequest;
                toJSON(message: HideWikiPageRevisionRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                    revision?: string;
                }): HideWikiPageRevisionRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                    revision?: string;
                }): HideWikiPageRevisionRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.wiki.HideWikiPageRevisionResponse";
                encode(message: HideWikiPageRevisionResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): HideWikiPageRevisionResponse;
                fromJSON(object: any): HideWikiPageRevisionResponse;
                toJSON(message: HideWikiPageRevisionResponse): unknown;
                create(base?: {
                    status?: boolean;
                }): HideWikiPageRevisionResponse;
                fromPartial(object: {
                    status?: boolean;
                }): HideWikiPageRevisionResponse;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Get a list of revisions of a wiki page
         *
         * @see {@link https://www.reddit.com/dev/api#GET_wiki_revisions_\{page\}}
         */
        readonly getWikiPageRevisions: {
            readonly name: "GetWikiPageRevisions";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.GetWikiPageRevisionsRequest";
                encode(message: GetWikiPageRevisionsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWikiPageRevisionsRequest;
                fromJSON(object: any): GetWikiPageRevisionsRequest;
                toJSON(message: GetWikiPageRevisionsRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                    after?: string | undefined | undefined;
                    before?: string | undefined | undefined;
                    limit?: number | undefined | undefined;
                    count?: number | undefined | undefined;
                    show?: boolean | undefined | undefined;
                    srDetail?: boolean | undefined | undefined;
                }): GetWikiPageRevisionsRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                    after?: string | undefined | undefined;
                    before?: string | undefined | undefined;
                    limit?: number | undefined | undefined;
                    count?: number | undefined | undefined;
                    show?: boolean | undefined | undefined;
                    srDetail?: boolean | undefined | undefined;
                }): GetWikiPageRevisionsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.wiki.WikiPageRevisionListing";
                encode(message: WikiPageRevisionListing, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WikiPageRevisionListing;
                fromJSON(object: any): WikiPageRevisionListing;
                toJSON(message: WikiPageRevisionListing): unknown;
                create(base?: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            id?: string;
                            page?: string;
                            timestamp?: number;
                            reason?: string;
                            revisionHidden?: boolean;
                            author?: {
                                id?: string | undefined | undefined;
                                data?: {
                                    acceptChats?: boolean | undefined | undefined;
                                    acceptFollowers?: boolean | undefined | undefined;
                                    acceptPms?: boolean | undefined | undefined;
                                    awardeeKarma?: number | undefined | undefined;
                                    awarderKarma?: number | undefined | undefined;
                                    canCreateSubreddit?: boolean | undefined | undefined;
                                    canEditName?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    commentKarma?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    features?: {
                                        awardsOnStreams?: boolean | undefined | undefined;
                                        canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                        chatGroupRollout?: boolean | undefined | undefined;
                                        chatSubreddit?: boolean | undefined | undefined;
                                        chatUserSettings?: boolean | undefined | undefined;
                                        chat?: boolean | undefined | undefined;
                                        cookieConsentBanner?: boolean | undefined | undefined;
                                        crosspostNotif?: boolean | undefined | undefined;
                                        crowdControlForPost?: boolean | undefined | undefined;
                                        customFeedImage?: boolean | undefined | undefined;
                                        doNotTrack?: boolean | undefined | undefined;
                                        expensiveCoinsPackage?: boolean | undefined | undefined;
                                        isEmailPermissionRequired?: boolean | undefined | undefined;
                                        liveComments?: boolean | undefined | undefined;
                                        liveOrangereds?: boolean | undefined | undefined;
                                        modAwards?: boolean | undefined | undefined;
                                        modServiceMuteReads?: boolean | undefined | undefined;
                                        modServiceMuteWrites?: boolean | undefined | undefined;
                                        modlogCopyrightRemoval?: boolean | undefined | undefined;
                                        mwebNsfwXpromo?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                        mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                        mwebXpromoRevampV2?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoRevampV3?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        noreferrerToNoopener?: boolean | undefined | undefined;
                                        pollsMobile?: boolean | undefined | undefined;
                                        premiumSubscriptionsTable?: boolean | undefined | undefined;
                                        promotedTrendBlanks?: boolean | undefined | undefined;
                                        resizedStylesImages?: boolean | undefined | undefined;
                                        showAmpLink?: boolean | undefined | undefined;
                                        showNpsSurvey?: boolean | undefined | undefined;
                                        spezModal?: boolean | undefined | undefined;
                                        usePrefAccountDeployment?: boolean | undefined | undefined;
                                        userFlairMigrationTesting?: boolean | undefined | undefined;
                                        webhookConfig?: boolean | undefined | undefined;
                                    } | undefined;
                                    forcePasswordReset?: boolean | undefined | undefined;
                                    goldCreddits?: number | undefined | undefined;
                                    goldExpiration?: string | undefined | undefined;
                                    hasAndroidSubscription?: boolean | undefined | undefined;
                                    hasExternalAccount?: boolean | undefined | undefined;
                                    hasGoldSubscription?: boolean | undefined | undefined;
                                    hasIosSubscription?: boolean | undefined | undefined;
                                    hasMail?: boolean | undefined | undefined;
                                    hasModMail?: boolean | undefined | undefined;
                                    hasPaypalSubscription?: boolean | undefined | undefined;
                                    hasStripeSubscription?: boolean | undefined | undefined;
                                    hasSubscribed?: boolean | undefined | undefined;
                                    hasSubscribedToPremium?: boolean | undefined | undefined;
                                    hasVerifiedEmail?: boolean | undefined | undefined;
                                    hasVisitedNewProfile?: boolean | undefined | undefined;
                                    hideFromRobots?: boolean | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    id?: string | undefined | undefined;
                                    inBeta?: boolean | undefined | undefined;
                                    inChat?: boolean | undefined | undefined;
                                    inRedesignBeta?: boolean | undefined | undefined;
                                    inboxCount?: number | undefined | undefined;
                                    isBlocked?: boolean | undefined | undefined;
                                    isEmployee?: boolean | undefined | undefined;
                                    isFriend?: boolean | undefined | undefined;
                                    isGold?: boolean | undefined | undefined;
                                    isMod?: boolean | undefined | undefined;
                                    isSponsor?: boolean | undefined | undefined;
                                    isSuspended?: boolean | undefined | undefined;
                                    linkKarma?: number | undefined | undefined;
                                    modhash?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    newModmailExists?: boolean | undefined | undefined;
                                    numFriends?: number | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    passwordSet?: boolean | undefined | undefined;
                                    prefAutoplay?: boolean | undefined | undefined;
                                    prefClickgadget?: number | undefined | undefined;
                                    prefGeopopular?: string | undefined | undefined;
                                    prefNightmode?: boolean | undefined | undefined;
                                    prefNoProfanity?: boolean | undefined | undefined;
                                    prefShowPresence?: boolean | undefined | undefined;
                                    prefShowSnoovatar?: boolean | undefined | undefined;
                                    prefShowTrending?: boolean | undefined | undefined;
                                    prefShowTwitter?: boolean | undefined | undefined;
                                    prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                    prefVideoAutoplay?: boolean | undefined | undefined;
                                    snoovatarImg?: string | undefined | undefined;
                                    snoovatarSize?: number[];
                                    subreddit?: {
                                        acceptFollowers?: boolean | undefined | undefined;
                                        accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                        accountsActive?: number | undefined | undefined;
                                        activeUserCount?: number | undefined | undefined;
                                        advertiserCategory?: string | undefined | undefined;
                                        allOriginalContent?: boolean | undefined | undefined;
                                        allowChatPostCreation?: boolean | undefined | undefined;
                                        allowDiscovery?: boolean | undefined | undefined;
                                        allowGalleries?: boolean | undefined | undefined;
                                        allowImages?: boolean | undefined | undefined;
                                        allowPolls?: boolean | undefined | undefined;
                                        allowPredictionContributors?: boolean | undefined | undefined;
                                        allowPredictionsTournament?: boolean | undefined | undefined;
                                        allowPredictions?: boolean | undefined | undefined;
                                        allowTalks?: boolean | undefined | undefined;
                                        allowVideogifs?: boolean | undefined | undefined;
                                        allowVideos?: boolean | undefined | undefined;
                                        allowedMediaInComments?: string[];
                                        bannerBackgroundColor?: string | undefined | undefined;
                                        bannerBackgroundImage?: string | undefined | undefined;
                                        bannerImg?: string | undefined | undefined;
                                        bannerSize?: number[];
                                        canAssignLinkFlair?: boolean | undefined | undefined;
                                        canAssignUserFlair?: boolean | undefined | undefined;
                                        coins?: number | undefined | undefined;
                                        collapseDeletedComments?: boolean | undefined | undefined;
                                        commentContributionSettings?: {
                                            allowedMediaTypes?: string[];
                                        } | undefined;
                                        commentScoreHideMins?: number | undefined | undefined;
                                        communityIcon?: string | undefined | undefined;
                                        communityReviewed?: boolean | undefined | undefined;
                                        contentCategory?: string | undefined | undefined;
                                        createdUtc?: number | undefined | undefined;
                                        created?: number | undefined | undefined;
                                        defaultSet?: boolean | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        descriptionHtml?: string | undefined | undefined;
                                        disableContributorRequests?: boolean | undefined | undefined;
                                        displayName?: string | undefined | undefined;
                                        displayNamePrefixed?: string | undefined | undefined;
                                        emojisCustomSize?: number[];
                                        emojisEnabled?: boolean | undefined | undefined;
                                        freeFormReports?: boolean | undefined | undefined;
                                        hasMenuWidget?: boolean | undefined | undefined;
                                        headerImg?: string | undefined | undefined;
                                        headerSize?: number[];
                                        headerTitle?: string | undefined | undefined;
                                        hideAds?: boolean | undefined | undefined;
                                        iconColor?: string | undefined | undefined;
                                        iconImg?: string | undefined | undefined;
                                        iconSize?: number[];
                                        id?: string | undefined | undefined;
                                        isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                        isCrosspostableSubreddit?: boolean | undefined | undefined;
                                        isDefaultBanner?: boolean | undefined | undefined;
                                        isDefaultIcon?: boolean | undefined | undefined;
                                        isEnrolledInNewModmail?: boolean | undefined | undefined;
                                        keyColor?: string | undefined | undefined;
                                        lang?: string | undefined | undefined;
                                        linkFlairEnabled?: boolean | undefined | undefined;
                                        linkFlairPosition?: string | undefined | undefined;
                                        mobileBannerImage?: string | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        notificationLevel?: string | undefined | undefined;
                                        originalContentTagEnabled?: string | undefined | undefined;
                                        over18?: boolean | undefined | undefined;
                                        predictionLeaderboardEntryType?: string | undefined | undefined;
                                        previousNames?: string[];
                                        primaryColor?: string | undefined | undefined;
                                        publicDescription?: string | undefined | undefined;
                                        publicDescriptionHtml?: string | undefined | undefined;
                                        publicTraffic?: boolean | undefined | undefined;
                                        quarantine?: boolean | undefined | undefined;
                                        restrictCommenting?: boolean | undefined | undefined;
                                        restrictPosting?: boolean | undefined | undefined;
                                        shouldArchivePosts?: boolean | undefined | undefined;
                                        shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                        showMedia?: boolean | undefined | undefined;
                                        showMediaPreview?: boolean | undefined | undefined;
                                        spoilersEnabled?: boolean | undefined | undefined;
                                        submissionType?: string | undefined | undefined;
                                        submitLinkLabel?: string | undefined | undefined;
                                        submitText?: string | undefined | undefined;
                                        submitTextHtml?: string | undefined | undefined;
                                        submitTextLabel?: string | undefined | undefined;
                                        subredditType?: string | undefined | undefined;
                                        subscribers?: number | undefined | undefined;
                                        suggestedCommentSort?: string | undefined | undefined;
                                        title?: string | undefined | undefined;
                                        url?: string | undefined | undefined;
                                        userCanFlairInSr?: boolean | undefined | undefined;
                                        userFlairBackgroundColor?: string | undefined | undefined;
                                        userFlairCssClass?: string | undefined | undefined;
                                        userFlairEnabledInSr?: boolean | undefined | undefined;
                                        userFlairPosition?: string | undefined | undefined;
                                        userFlairRichtext?: {
                                            e?: string | undefined | undefined;
                                            t?: string | undefined | undefined;
                                        }[];
                                        userFlairTemplateId?: string | undefined | undefined;
                                        userFlairText?: string | undefined | undefined;
                                        userFlairTextColor?: string | undefined | undefined;
                                        userFlairType?: string | undefined | undefined;
                                        userHasFavorited?: boolean | undefined | undefined;
                                        userIsBanned?: boolean | undefined | undefined;
                                        userIsContributor?: boolean | undefined | undefined;
                                        userIsModerator?: boolean | undefined | undefined;
                                        userIsSubscriber?: boolean | undefined | undefined;
                                        userSrFlairEnabled?: boolean | undefined | undefined;
                                        userSrThemeEnabled?: boolean | undefined | undefined;
                                        videostreamLinksCount?: number | undefined | undefined;
                                        whitelistStatus?: string | undefined | undefined;
                                        wikiEnabled?: boolean | undefined | undefined;
                                        wls?: number | undefined | undefined;
                                        markedSpam?: boolean | undefined | undefined;
                                        postRequirements?: {
                                            bodyRestrictionPolicy?: string | undefined | undefined;
                                        } | undefined;
                                        userIsMuted?: boolean;
                                    } | undefined;
                                    suspensionExpirationUtc?: string | undefined | undefined;
                                    totalKarma?: number | undefined | undefined;
                                    verified?: boolean | undefined | undefined;
                                    hasPhoneNumber?: boolean | undefined | undefined;
                                    subredditsModerated?: number | undefined | undefined;
                                    hasMetaSubscription?: boolean | undefined | undefined;
                                    metaSubscriptionAge?: number | undefined | undefined;
                                    metaPointsBalance?: string | undefined | undefined;
                                    metaLockedPointsBalance?: string | undefined | undefined;
                                    commentSubredditKarma?: number | undefined | undefined;
                                    postSubredditKarma?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    isSubredditProxyAccount?: boolean | undefined | undefined;
                                } | undefined;
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): WikiPageRevisionListing;
                fromPartial(object: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            id?: string;
                            page?: string;
                            timestamp?: number;
                            reason?: string;
                            revisionHidden?: boolean;
                            author?: {
                                id?: string | undefined | undefined;
                                data?: {
                                    acceptChats?: boolean | undefined | undefined;
                                    acceptFollowers?: boolean | undefined | undefined;
                                    acceptPms?: boolean | undefined | undefined;
                                    awardeeKarma?: number | undefined | undefined;
                                    awarderKarma?: number | undefined | undefined;
                                    canCreateSubreddit?: boolean | undefined | undefined;
                                    canEditName?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    commentKarma?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    features?: {
                                        awardsOnStreams?: boolean | undefined | undefined;
                                        canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                        chatGroupRollout?: boolean | undefined | undefined;
                                        chatSubreddit?: boolean | undefined | undefined;
                                        chatUserSettings?: boolean | undefined | undefined;
                                        chat?: boolean | undefined | undefined;
                                        cookieConsentBanner?: boolean | undefined | undefined;
                                        crosspostNotif?: boolean | undefined | undefined;
                                        crowdControlForPost?: boolean | undefined | undefined;
                                        customFeedImage?: boolean | undefined | undefined;
                                        doNotTrack?: boolean | undefined | undefined;
                                        expensiveCoinsPackage?: boolean | undefined | undefined;
                                        isEmailPermissionRequired?: boolean | undefined | undefined;
                                        liveComments?: boolean | undefined | undefined;
                                        liveOrangereds?: boolean | undefined | undefined;
                                        modAwards?: boolean | undefined | undefined;
                                        modServiceMuteReads?: boolean | undefined | undefined;
                                        modServiceMuteWrites?: boolean | undefined | undefined;
                                        modlogCopyrightRemoval?: boolean | undefined | undefined;
                                        mwebNsfwXpromo?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                        mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                        mwebXpromoRevampV2?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoRevampV3?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        noreferrerToNoopener?: boolean | undefined | undefined;
                                        pollsMobile?: boolean | undefined | undefined;
                                        premiumSubscriptionsTable?: boolean | undefined | undefined;
                                        promotedTrendBlanks?: boolean | undefined | undefined;
                                        resizedStylesImages?: boolean | undefined | undefined;
                                        showAmpLink?: boolean | undefined | undefined;
                                        showNpsSurvey?: boolean | undefined | undefined;
                                        spezModal?: boolean | undefined | undefined;
                                        usePrefAccountDeployment?: boolean | undefined | undefined;
                                        userFlairMigrationTesting?: boolean | undefined | undefined;
                                        webhookConfig?: boolean | undefined | undefined;
                                    } | undefined;
                                    forcePasswordReset?: boolean | undefined | undefined;
                                    goldCreddits?: number | undefined | undefined;
                                    goldExpiration?: string | undefined | undefined;
                                    hasAndroidSubscription?: boolean | undefined | undefined;
                                    hasExternalAccount?: boolean | undefined | undefined;
                                    hasGoldSubscription?: boolean | undefined | undefined;
                                    hasIosSubscription?: boolean | undefined | undefined;
                                    hasMail?: boolean | undefined | undefined;
                                    hasModMail?: boolean | undefined | undefined;
                                    hasPaypalSubscription?: boolean | undefined | undefined;
                                    hasStripeSubscription?: boolean | undefined | undefined;
                                    hasSubscribed?: boolean | undefined | undefined;
                                    hasSubscribedToPremium?: boolean | undefined | undefined;
                                    hasVerifiedEmail?: boolean | undefined | undefined;
                                    hasVisitedNewProfile?: boolean | undefined | undefined;
                                    hideFromRobots?: boolean | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    id?: string | undefined | undefined;
                                    inBeta?: boolean | undefined | undefined;
                                    inChat?: boolean | undefined | undefined;
                                    inRedesignBeta?: boolean | undefined | undefined;
                                    inboxCount?: number | undefined | undefined;
                                    isBlocked?: boolean | undefined | undefined;
                                    isEmployee?: boolean | undefined | undefined;
                                    isFriend?: boolean | undefined | undefined;
                                    isGold?: boolean | undefined | undefined;
                                    isMod?: boolean | undefined | undefined;
                                    isSponsor?: boolean | undefined | undefined;
                                    isSuspended?: boolean | undefined | undefined;
                                    linkKarma?: number | undefined | undefined;
                                    modhash?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    newModmailExists?: boolean | undefined | undefined;
                                    numFriends?: number | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    passwordSet?: boolean | undefined | undefined;
                                    prefAutoplay?: boolean | undefined | undefined;
                                    prefClickgadget?: number | undefined | undefined;
                                    prefGeopopular?: string | undefined | undefined;
                                    prefNightmode?: boolean | undefined | undefined;
                                    prefNoProfanity?: boolean | undefined | undefined;
                                    prefShowPresence?: boolean | undefined | undefined;
                                    prefShowSnoovatar?: boolean | undefined | undefined;
                                    prefShowTrending?: boolean | undefined | undefined;
                                    prefShowTwitter?: boolean | undefined | undefined;
                                    prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                    prefVideoAutoplay?: boolean | undefined | undefined;
                                    snoovatarImg?: string | undefined | undefined;
                                    snoovatarSize?: number[];
                                    subreddit?: {
                                        acceptFollowers?: boolean | undefined | undefined;
                                        accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                        accountsActive?: number | undefined | undefined;
                                        activeUserCount?: number | undefined | undefined;
                                        advertiserCategory?: string | undefined | undefined;
                                        allOriginalContent?: boolean | undefined | undefined;
                                        allowChatPostCreation?: boolean | undefined | undefined;
                                        allowDiscovery?: boolean | undefined | undefined;
                                        allowGalleries?: boolean | undefined | undefined;
                                        allowImages?: boolean | undefined | undefined;
                                        allowPolls?: boolean | undefined | undefined;
                                        allowPredictionContributors?: boolean | undefined | undefined;
                                        allowPredictionsTournament?: boolean | undefined | undefined;
                                        allowPredictions?: boolean | undefined | undefined;
                                        allowTalks?: boolean | undefined | undefined;
                                        allowVideogifs?: boolean | undefined | undefined;
                                        allowVideos?: boolean | undefined | undefined;
                                        allowedMediaInComments?: string[];
                                        bannerBackgroundColor?: string | undefined | undefined;
                                        bannerBackgroundImage?: string | undefined | undefined;
                                        bannerImg?: string | undefined | undefined;
                                        bannerSize?: number[];
                                        canAssignLinkFlair?: boolean | undefined | undefined;
                                        canAssignUserFlair?: boolean | undefined | undefined;
                                        coins?: number | undefined | undefined;
                                        collapseDeletedComments?: boolean | undefined | undefined;
                                        commentContributionSettings?: {
                                            allowedMediaTypes?: string[];
                                        } | undefined;
                                        commentScoreHideMins?: number | undefined | undefined;
                                        communityIcon?: string | undefined | undefined;
                                        communityReviewed?: boolean | undefined | undefined;
                                        contentCategory?: string | undefined | undefined;
                                        createdUtc?: number | undefined | undefined;
                                        created?: number | undefined | undefined;
                                        defaultSet?: boolean | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        descriptionHtml?: string | undefined | undefined;
                                        disableContributorRequests?: boolean | undefined | undefined;
                                        displayName?: string | undefined | undefined;
                                        displayNamePrefixed?: string | undefined | undefined;
                                        emojisCustomSize?: number[];
                                        emojisEnabled?: boolean | undefined | undefined;
                                        freeFormReports?: boolean | undefined | undefined;
                                        hasMenuWidget?: boolean | undefined | undefined;
                                        headerImg?: string | undefined | undefined;
                                        headerSize?: number[];
                                        headerTitle?: string | undefined | undefined;
                                        hideAds?: boolean | undefined | undefined;
                                        iconColor?: string | undefined | undefined;
                                        iconImg?: string | undefined | undefined;
                                        iconSize?: number[];
                                        id?: string | undefined | undefined;
                                        isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                        isCrosspostableSubreddit?: boolean | undefined | undefined;
                                        isDefaultBanner?: boolean | undefined | undefined;
                                        isDefaultIcon?: boolean | undefined | undefined;
                                        isEnrolledInNewModmail?: boolean | undefined | undefined;
                                        keyColor?: string | undefined | undefined;
                                        lang?: string | undefined | undefined;
                                        linkFlairEnabled?: boolean | undefined | undefined;
                                        linkFlairPosition?: string | undefined | undefined;
                                        mobileBannerImage?: string | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        notificationLevel?: string | undefined | undefined;
                                        originalContentTagEnabled?: string | undefined | undefined;
                                        over18?: boolean | undefined | undefined;
                                        predictionLeaderboardEntryType?: string | undefined | undefined;
                                        previousNames?: string[];
                                        primaryColor?: string | undefined | undefined;
                                        publicDescription?: string | undefined | undefined;
                                        publicDescriptionHtml?: string | undefined | undefined;
                                        publicTraffic?: boolean | undefined | undefined;
                                        quarantine?: boolean | undefined | undefined;
                                        restrictCommenting?: boolean | undefined | undefined;
                                        restrictPosting?: boolean | undefined | undefined;
                                        shouldArchivePosts?: boolean | undefined | undefined;
                                        shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                        showMedia?: boolean | undefined | undefined;
                                        showMediaPreview?: boolean | undefined | undefined;
                                        spoilersEnabled?: boolean | undefined | undefined;
                                        submissionType?: string | undefined | undefined;
                                        submitLinkLabel?: string | undefined | undefined;
                                        submitText?: string | undefined | undefined;
                                        submitTextHtml?: string | undefined | undefined;
                                        submitTextLabel?: string | undefined | undefined;
                                        subredditType?: string | undefined | undefined;
                                        subscribers?: number | undefined | undefined;
                                        suggestedCommentSort?: string | undefined | undefined;
                                        title?: string | undefined | undefined;
                                        url?: string | undefined | undefined;
                                        userCanFlairInSr?: boolean | undefined | undefined;
                                        userFlairBackgroundColor?: string | undefined | undefined;
                                        userFlairCssClass?: string | undefined | undefined;
                                        userFlairEnabledInSr?: boolean | undefined | undefined;
                                        userFlairPosition?: string | undefined | undefined;
                                        userFlairRichtext?: {
                                            e?: string | undefined | undefined;
                                            t?: string | undefined | undefined;
                                        }[];
                                        userFlairTemplateId?: string | undefined | undefined;
                                        userFlairText?: string | undefined | undefined;
                                        userFlairTextColor?: string | undefined | undefined;
                                        userFlairType?: string | undefined | undefined;
                                        userHasFavorited?: boolean | undefined | undefined;
                                        userIsBanned?: boolean | undefined | undefined;
                                        userIsContributor?: boolean | undefined | undefined;
                                        userIsModerator?: boolean | undefined | undefined;
                                        userIsSubscriber?: boolean | undefined | undefined;
                                        userSrFlairEnabled?: boolean | undefined | undefined;
                                        userSrThemeEnabled?: boolean | undefined | undefined;
                                        videostreamLinksCount?: number | undefined | undefined;
                                        whitelistStatus?: string | undefined | undefined;
                                        wikiEnabled?: boolean | undefined | undefined;
                                        wls?: number | undefined | undefined;
                                        markedSpam?: boolean | undefined | undefined;
                                        postRequirements?: {
                                            bodyRestrictionPolicy?: string | undefined | undefined;
                                        } | undefined;
                                        userIsMuted?: boolean;
                                    } | undefined;
                                    suspensionExpirationUtc?: string | undefined | undefined;
                                    totalKarma?: number | undefined | undefined;
                                    verified?: boolean | undefined | undefined;
                                    hasPhoneNumber?: boolean | undefined | undefined;
                                    subredditsModerated?: number | undefined | undefined;
                                    hasMetaSubscription?: boolean | undefined | undefined;
                                    metaSubscriptionAge?: number | undefined | undefined;
                                    metaPointsBalance?: string | undefined | undefined;
                                    metaLockedPointsBalance?: string | undefined | undefined;
                                    commentSubredditKarma?: number | undefined | undefined;
                                    postSubredditKarma?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    isSubredditProxyAccount?: boolean | undefined | undefined;
                                } | undefined;
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): WikiPageRevisionListing;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Retrieve a list of recently changed wiki pages in this subreddit
         *
         * @see {@link https://www.reddit.com/dev/api#GET_wiki_revisions}
         */
        readonly getWikiRevisions: {
            readonly name: "GetWikiRevisions";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.GetWikiRevisionsRequest";
                encode(message: GetWikiRevisionsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWikiRevisionsRequest;
                fromJSON(object: any): GetWikiRevisionsRequest;
                toJSON(message: GetWikiRevisionsRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    after?: string | undefined | undefined;
                    before?: string | undefined | undefined;
                    limit?: number | undefined | undefined;
                    count?: number | undefined | undefined;
                    show?: boolean | undefined | undefined;
                    srDetail?: boolean | undefined | undefined;
                }): GetWikiRevisionsRequest;
                fromPartial(object: {
                    subreddit?: string;
                    after?: string | undefined | undefined;
                    before?: string | undefined | undefined;
                    limit?: number | undefined | undefined;
                    count?: number | undefined | undefined;
                    show?: boolean | undefined | undefined;
                    srDetail?: boolean | undefined | undefined;
                }): GetWikiRevisionsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.wiki.WikiPageRevisionListing";
                encode(message: WikiPageRevisionListing, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WikiPageRevisionListing;
                fromJSON(object: any): WikiPageRevisionListing;
                toJSON(message: WikiPageRevisionListing): unknown;
                create(base?: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            id?: string;
                            page?: string;
                            timestamp?: number;
                            reason?: string;
                            revisionHidden?: boolean;
                            author?: {
                                id?: string | undefined | undefined;
                                data?: {
                                    acceptChats?: boolean | undefined | undefined;
                                    acceptFollowers?: boolean | undefined | undefined;
                                    acceptPms?: boolean | undefined | undefined;
                                    awardeeKarma?: number | undefined | undefined;
                                    awarderKarma?: number | undefined | undefined;
                                    canCreateSubreddit?: boolean | undefined | undefined;
                                    canEditName?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    commentKarma?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    features?: {
                                        awardsOnStreams?: boolean | undefined | undefined;
                                        canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                        chatGroupRollout?: boolean | undefined | undefined;
                                        chatSubreddit?: boolean | undefined | undefined;
                                        chatUserSettings?: boolean | undefined | undefined;
                                        chat?: boolean | undefined | undefined;
                                        cookieConsentBanner?: boolean | undefined | undefined;
                                        crosspostNotif?: boolean | undefined | undefined;
                                        crowdControlForPost?: boolean | undefined | undefined;
                                        customFeedImage?: boolean | undefined | undefined;
                                        doNotTrack?: boolean | undefined | undefined;
                                        expensiveCoinsPackage?: boolean | undefined | undefined;
                                        isEmailPermissionRequired?: boolean | undefined | undefined;
                                        liveComments?: boolean | undefined | undefined;
                                        liveOrangereds?: boolean | undefined | undefined;
                                        modAwards?: boolean | undefined | undefined;
                                        modServiceMuteReads?: boolean | undefined | undefined;
                                        modServiceMuteWrites?: boolean | undefined | undefined;
                                        modlogCopyrightRemoval?: boolean | undefined | undefined;
                                        mwebNsfwXpromo?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                        mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                        mwebXpromoRevampV2?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoRevampV3?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        noreferrerToNoopener?: boolean | undefined | undefined;
                                        pollsMobile?: boolean | undefined | undefined;
                                        premiumSubscriptionsTable?: boolean | undefined | undefined;
                                        promotedTrendBlanks?: boolean | undefined | undefined;
                                        resizedStylesImages?: boolean | undefined | undefined;
                                        showAmpLink?: boolean | undefined | undefined;
                                        showNpsSurvey?: boolean | undefined | undefined;
                                        spezModal?: boolean | undefined | undefined;
                                        usePrefAccountDeployment?: boolean | undefined | undefined;
                                        userFlairMigrationTesting?: boolean | undefined | undefined;
                                        webhookConfig?: boolean | undefined | undefined;
                                    } | undefined;
                                    forcePasswordReset?: boolean | undefined | undefined;
                                    goldCreddits?: number | undefined | undefined;
                                    goldExpiration?: string | undefined | undefined;
                                    hasAndroidSubscription?: boolean | undefined | undefined;
                                    hasExternalAccount?: boolean | undefined | undefined;
                                    hasGoldSubscription?: boolean | undefined | undefined;
                                    hasIosSubscription?: boolean | undefined | undefined;
                                    hasMail?: boolean | undefined | undefined;
                                    hasModMail?: boolean | undefined | undefined;
                                    hasPaypalSubscription?: boolean | undefined | undefined;
                                    hasStripeSubscription?: boolean | undefined | undefined;
                                    hasSubscribed?: boolean | undefined | undefined;
                                    hasSubscribedToPremium?: boolean | undefined | undefined;
                                    hasVerifiedEmail?: boolean | undefined | undefined;
                                    hasVisitedNewProfile?: boolean | undefined | undefined;
                                    hideFromRobots?: boolean | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    id?: string | undefined | undefined;
                                    inBeta?: boolean | undefined | undefined;
                                    inChat?: boolean | undefined | undefined;
                                    inRedesignBeta?: boolean | undefined | undefined;
                                    inboxCount?: number | undefined | undefined;
                                    isBlocked?: boolean | undefined | undefined;
                                    isEmployee?: boolean | undefined | undefined;
                                    isFriend?: boolean | undefined | undefined;
                                    isGold?: boolean | undefined | undefined;
                                    isMod?: boolean | undefined | undefined;
                                    isSponsor?: boolean | undefined | undefined;
                                    isSuspended?: boolean | undefined | undefined;
                                    linkKarma?: number | undefined | undefined;
                                    modhash?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    newModmailExists?: boolean | undefined | undefined;
                                    numFriends?: number | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    passwordSet?: boolean | undefined | undefined;
                                    prefAutoplay?: boolean | undefined | undefined;
                                    prefClickgadget?: number | undefined | undefined;
                                    prefGeopopular?: string | undefined | undefined;
                                    prefNightmode?: boolean | undefined | undefined;
                                    prefNoProfanity?: boolean | undefined | undefined;
                                    prefShowPresence?: boolean | undefined | undefined;
                                    prefShowSnoovatar?: boolean | undefined | undefined;
                                    prefShowTrending?: boolean | undefined | undefined;
                                    prefShowTwitter?: boolean | undefined | undefined;
                                    prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                    prefVideoAutoplay?: boolean | undefined | undefined;
                                    snoovatarImg?: string | undefined | undefined;
                                    snoovatarSize?: number[];
                                    subreddit?: {
                                        acceptFollowers?: boolean | undefined | undefined;
                                        accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                        accountsActive?: number | undefined | undefined;
                                        activeUserCount?: number | undefined | undefined;
                                        advertiserCategory?: string | undefined | undefined;
                                        allOriginalContent?: boolean | undefined | undefined;
                                        allowChatPostCreation?: boolean | undefined | undefined;
                                        allowDiscovery?: boolean | undefined | undefined;
                                        allowGalleries?: boolean | undefined | undefined;
                                        allowImages?: boolean | undefined | undefined;
                                        allowPolls?: boolean | undefined | undefined;
                                        allowPredictionContributors?: boolean | undefined | undefined;
                                        allowPredictionsTournament?: boolean | undefined | undefined;
                                        allowPredictions?: boolean | undefined | undefined;
                                        allowTalks?: boolean | undefined | undefined;
                                        allowVideogifs?: boolean | undefined | undefined;
                                        allowVideos?: boolean | undefined | undefined;
                                        allowedMediaInComments?: string[];
                                        bannerBackgroundColor?: string | undefined | undefined;
                                        bannerBackgroundImage?: string | undefined | undefined;
                                        bannerImg?: string | undefined | undefined;
                                        bannerSize?: number[];
                                        canAssignLinkFlair?: boolean | undefined | undefined;
                                        canAssignUserFlair?: boolean | undefined | undefined;
                                        coins?: number | undefined | undefined;
                                        collapseDeletedComments?: boolean | undefined | undefined;
                                        commentContributionSettings?: {
                                            allowedMediaTypes?: string[];
                                        } | undefined;
                                        commentScoreHideMins?: number | undefined | undefined;
                                        communityIcon?: string | undefined | undefined;
                                        communityReviewed?: boolean | undefined | undefined;
                                        contentCategory?: string | undefined | undefined;
                                        createdUtc?: number | undefined | undefined;
                                        created?: number | undefined | undefined;
                                        defaultSet?: boolean | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        descriptionHtml?: string | undefined | undefined;
                                        disableContributorRequests?: boolean | undefined | undefined;
                                        displayName?: string | undefined | undefined;
                                        displayNamePrefixed?: string | undefined | undefined;
                                        emojisCustomSize?: number[];
                                        emojisEnabled?: boolean | undefined | undefined;
                                        freeFormReports?: boolean | undefined | undefined;
                                        hasMenuWidget?: boolean | undefined | undefined;
                                        headerImg?: string | undefined | undefined;
                                        headerSize?: number[];
                                        headerTitle?: string | undefined | undefined;
                                        hideAds?: boolean | undefined | undefined;
                                        iconColor?: string | undefined | undefined;
                                        iconImg?: string | undefined | undefined;
                                        iconSize?: number[];
                                        id?: string | undefined | undefined;
                                        isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                        isCrosspostableSubreddit?: boolean | undefined | undefined;
                                        isDefaultBanner?: boolean | undefined | undefined;
                                        isDefaultIcon?: boolean | undefined | undefined;
                                        isEnrolledInNewModmail?: boolean | undefined | undefined;
                                        keyColor?: string | undefined | undefined;
                                        lang?: string | undefined | undefined;
                                        linkFlairEnabled?: boolean | undefined | undefined;
                                        linkFlairPosition?: string | undefined | undefined;
                                        mobileBannerImage?: string | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        notificationLevel?: string | undefined | undefined;
                                        originalContentTagEnabled?: string | undefined | undefined;
                                        over18?: boolean | undefined | undefined;
                                        predictionLeaderboardEntryType?: string | undefined | undefined;
                                        previousNames?: string[];
                                        primaryColor?: string | undefined | undefined;
                                        publicDescription?: string | undefined | undefined;
                                        publicDescriptionHtml?: string | undefined | undefined;
                                        publicTraffic?: boolean | undefined | undefined;
                                        quarantine?: boolean | undefined | undefined;
                                        restrictCommenting?: boolean | undefined | undefined;
                                        restrictPosting?: boolean | undefined | undefined;
                                        shouldArchivePosts?: boolean | undefined | undefined;
                                        shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                        showMedia?: boolean | undefined | undefined;
                                        showMediaPreview?: boolean | undefined | undefined;
                                        spoilersEnabled?: boolean | undefined | undefined;
                                        submissionType?: string | undefined | undefined;
                                        submitLinkLabel?: string | undefined | undefined;
                                        submitText?: string | undefined | undefined;
                                        submitTextHtml?: string | undefined | undefined;
                                        submitTextLabel?: string | undefined | undefined;
                                        subredditType?: string | undefined | undefined;
                                        subscribers?: number | undefined | undefined;
                                        suggestedCommentSort?: string | undefined | undefined;
                                        title?: string | undefined | undefined;
                                        url?: string | undefined | undefined;
                                        userCanFlairInSr?: boolean | undefined | undefined;
                                        userFlairBackgroundColor?: string | undefined | undefined;
                                        userFlairCssClass?: string | undefined | undefined;
                                        userFlairEnabledInSr?: boolean | undefined | undefined;
                                        userFlairPosition?: string | undefined | undefined;
                                        userFlairRichtext?: {
                                            e?: string | undefined | undefined;
                                            t?: string | undefined | undefined;
                                        }[];
                                        userFlairTemplateId?: string | undefined | undefined;
                                        userFlairText?: string | undefined | undefined;
                                        userFlairTextColor?: string | undefined | undefined;
                                        userFlairType?: string | undefined | undefined;
                                        userHasFavorited?: boolean | undefined | undefined;
                                        userIsBanned?: boolean | undefined | undefined;
                                        userIsContributor?: boolean | undefined | undefined;
                                        userIsModerator?: boolean | undefined | undefined;
                                        userIsSubscriber?: boolean | undefined | undefined;
                                        userSrFlairEnabled?: boolean | undefined | undefined;
                                        userSrThemeEnabled?: boolean | undefined | undefined;
                                        videostreamLinksCount?: number | undefined | undefined;
                                        whitelistStatus?: string | undefined | undefined;
                                        wikiEnabled?: boolean | undefined | undefined;
                                        wls?: number | undefined | undefined;
                                        markedSpam?: boolean | undefined | undefined;
                                        postRequirements?: {
                                            bodyRestrictionPolicy?: string | undefined | undefined;
                                        } | undefined;
                                        userIsMuted?: boolean;
                                    } | undefined;
                                    suspensionExpirationUtc?: string | undefined | undefined;
                                    totalKarma?: number | undefined | undefined;
                                    verified?: boolean | undefined | undefined;
                                    hasPhoneNumber?: boolean | undefined | undefined;
                                    subredditsModerated?: number | undefined | undefined;
                                    hasMetaSubscription?: boolean | undefined | undefined;
                                    metaSubscriptionAge?: number | undefined | undefined;
                                    metaPointsBalance?: string | undefined | undefined;
                                    metaLockedPointsBalance?: string | undefined | undefined;
                                    commentSubredditKarma?: number | undefined | undefined;
                                    postSubredditKarma?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    isSubredditProxyAccount?: boolean | undefined | undefined;
                                } | undefined;
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): WikiPageRevisionListing;
                fromPartial(object: {
                    kind?: string;
                    data?: {
                        after?: string | undefined | undefined;
                        before?: string | undefined | undefined;
                        children?: {
                            id?: string;
                            page?: string;
                            timestamp?: number;
                            reason?: string;
                            revisionHidden?: boolean;
                            author?: {
                                id?: string | undefined | undefined;
                                data?: {
                                    acceptChats?: boolean | undefined | undefined;
                                    acceptFollowers?: boolean | undefined | undefined;
                                    acceptPms?: boolean | undefined | undefined;
                                    awardeeKarma?: number | undefined | undefined;
                                    awarderKarma?: number | undefined | undefined;
                                    canCreateSubreddit?: boolean | undefined | undefined;
                                    canEditName?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    commentKarma?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    features?: {
                                        awardsOnStreams?: boolean | undefined | undefined;
                                        canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                        chatGroupRollout?: boolean | undefined | undefined;
                                        chatSubreddit?: boolean | undefined | undefined;
                                        chatUserSettings?: boolean | undefined | undefined;
                                        chat?: boolean | undefined | undefined;
                                        cookieConsentBanner?: boolean | undefined | undefined;
                                        crosspostNotif?: boolean | undefined | undefined;
                                        crowdControlForPost?: boolean | undefined | undefined;
                                        customFeedImage?: boolean | undefined | undefined;
                                        doNotTrack?: boolean | undefined | undefined;
                                        expensiveCoinsPackage?: boolean | undefined | undefined;
                                        isEmailPermissionRequired?: boolean | undefined | undefined;
                                        liveComments?: boolean | undefined | undefined;
                                        liveOrangereds?: boolean | undefined | undefined;
                                        modAwards?: boolean | undefined | undefined;
                                        modServiceMuteReads?: boolean | undefined | undefined;
                                        modServiceMuteWrites?: boolean | undefined | undefined;
                                        modlogCopyrightRemoval?: boolean | undefined | undefined;
                                        mwebNsfwXpromo?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                        mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                        mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                        mwebXpromoRevampV2?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        mwebXpromoRevampV3?: {
                                            experimentId?: number | undefined | undefined;
                                            owner?: string | undefined | undefined;
                                            variant?: string | undefined | undefined;
                                        } | undefined;
                                        noreferrerToNoopener?: boolean | undefined | undefined;
                                        pollsMobile?: boolean | undefined | undefined;
                                        premiumSubscriptionsTable?: boolean | undefined | undefined;
                                        promotedTrendBlanks?: boolean | undefined | undefined;
                                        resizedStylesImages?: boolean | undefined | undefined;
                                        showAmpLink?: boolean | undefined | undefined;
                                        showNpsSurvey?: boolean | undefined | undefined;
                                        spezModal?: boolean | undefined | undefined;
                                        usePrefAccountDeployment?: boolean | undefined | undefined;
                                        userFlairMigrationTesting?: boolean | undefined | undefined;
                                        webhookConfig?: boolean | undefined | undefined;
                                    } | undefined;
                                    forcePasswordReset?: boolean | undefined | undefined;
                                    goldCreddits?: number | undefined | undefined;
                                    goldExpiration?: string | undefined | undefined;
                                    hasAndroidSubscription?: boolean | undefined | undefined;
                                    hasExternalAccount?: boolean | undefined | undefined;
                                    hasGoldSubscription?: boolean | undefined | undefined;
                                    hasIosSubscription?: boolean | undefined | undefined;
                                    hasMail?: boolean | undefined | undefined;
                                    hasModMail?: boolean | undefined | undefined;
                                    hasPaypalSubscription?: boolean | undefined | undefined;
                                    hasStripeSubscription?: boolean | undefined | undefined;
                                    hasSubscribed?: boolean | undefined | undefined;
                                    hasSubscribedToPremium?: boolean | undefined | undefined;
                                    hasVerifiedEmail?: boolean | undefined | undefined;
                                    hasVisitedNewProfile?: boolean | undefined | undefined;
                                    hideFromRobots?: boolean | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    id?: string | undefined | undefined;
                                    inBeta?: boolean | undefined | undefined;
                                    inChat?: boolean | undefined | undefined;
                                    inRedesignBeta?: boolean | undefined | undefined;
                                    inboxCount?: number | undefined | undefined;
                                    isBlocked?: boolean | undefined | undefined;
                                    isEmployee?: boolean | undefined | undefined;
                                    isFriend?: boolean | undefined | undefined;
                                    isGold?: boolean | undefined | undefined;
                                    isMod?: boolean | undefined | undefined;
                                    isSponsor?: boolean | undefined | undefined;
                                    isSuspended?: boolean | undefined | undefined;
                                    linkKarma?: number | undefined | undefined;
                                    modhash?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    newModmailExists?: boolean | undefined | undefined;
                                    numFriends?: number | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    passwordSet?: boolean | undefined | undefined;
                                    prefAutoplay?: boolean | undefined | undefined;
                                    prefClickgadget?: number | undefined | undefined;
                                    prefGeopopular?: string | undefined | undefined;
                                    prefNightmode?: boolean | undefined | undefined;
                                    prefNoProfanity?: boolean | undefined | undefined;
                                    prefShowPresence?: boolean | undefined | undefined;
                                    prefShowSnoovatar?: boolean | undefined | undefined;
                                    prefShowTrending?: boolean | undefined | undefined;
                                    prefShowTwitter?: boolean | undefined | undefined;
                                    prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                    prefVideoAutoplay?: boolean | undefined | undefined;
                                    snoovatarImg?: string | undefined | undefined;
                                    snoovatarSize?: number[];
                                    subreddit?: {
                                        acceptFollowers?: boolean | undefined | undefined;
                                        accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                        accountsActive?: number | undefined | undefined;
                                        activeUserCount?: number | undefined | undefined;
                                        advertiserCategory?: string | undefined | undefined;
                                        allOriginalContent?: boolean | undefined | undefined;
                                        allowChatPostCreation?: boolean | undefined | undefined;
                                        allowDiscovery?: boolean | undefined | undefined;
                                        allowGalleries?: boolean | undefined | undefined;
                                        allowImages?: boolean | undefined | undefined;
                                        allowPolls?: boolean | undefined | undefined;
                                        allowPredictionContributors?: boolean | undefined | undefined;
                                        allowPredictionsTournament?: boolean | undefined | undefined;
                                        allowPredictions?: boolean | undefined | undefined;
                                        allowTalks?: boolean | undefined | undefined;
                                        allowVideogifs?: boolean | undefined | undefined;
                                        allowVideos?: boolean | undefined | undefined;
                                        allowedMediaInComments?: string[];
                                        bannerBackgroundColor?: string | undefined | undefined;
                                        bannerBackgroundImage?: string | undefined | undefined;
                                        bannerImg?: string | undefined | undefined;
                                        bannerSize?: number[];
                                        canAssignLinkFlair?: boolean | undefined | undefined;
                                        canAssignUserFlair?: boolean | undefined | undefined;
                                        coins?: number | undefined | undefined;
                                        collapseDeletedComments?: boolean | undefined | undefined;
                                        commentContributionSettings?: {
                                            allowedMediaTypes?: string[];
                                        } | undefined;
                                        commentScoreHideMins?: number | undefined | undefined;
                                        communityIcon?: string | undefined | undefined;
                                        communityReviewed?: boolean | undefined | undefined;
                                        contentCategory?: string | undefined | undefined;
                                        createdUtc?: number | undefined | undefined;
                                        created?: number | undefined | undefined;
                                        defaultSet?: boolean | undefined | undefined;
                                        description?: string | undefined | undefined;
                                        descriptionHtml?: string | undefined | undefined;
                                        disableContributorRequests?: boolean | undefined | undefined;
                                        displayName?: string | undefined | undefined;
                                        displayNamePrefixed?: string | undefined | undefined;
                                        emojisCustomSize?: number[];
                                        emojisEnabled?: boolean | undefined | undefined;
                                        freeFormReports?: boolean | undefined | undefined;
                                        hasMenuWidget?: boolean | undefined | undefined;
                                        headerImg?: string | undefined | undefined;
                                        headerSize?: number[];
                                        headerTitle?: string | undefined | undefined;
                                        hideAds?: boolean | undefined | undefined;
                                        iconColor?: string | undefined | undefined;
                                        iconImg?: string | undefined | undefined;
                                        iconSize?: number[];
                                        id?: string | undefined | undefined;
                                        isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                        isCrosspostableSubreddit?: boolean | undefined | undefined;
                                        isDefaultBanner?: boolean | undefined | undefined;
                                        isDefaultIcon?: boolean | undefined | undefined;
                                        isEnrolledInNewModmail?: boolean | undefined | undefined;
                                        keyColor?: string | undefined | undefined;
                                        lang?: string | undefined | undefined;
                                        linkFlairEnabled?: boolean | undefined | undefined;
                                        linkFlairPosition?: string | undefined | undefined;
                                        mobileBannerImage?: string | undefined | undefined;
                                        name?: string | undefined | undefined;
                                        notificationLevel?: string | undefined | undefined;
                                        originalContentTagEnabled?: string | undefined | undefined;
                                        over18?: boolean | undefined | undefined;
                                        predictionLeaderboardEntryType?: string | undefined | undefined;
                                        previousNames?: string[];
                                        primaryColor?: string | undefined | undefined;
                                        publicDescription?: string | undefined | undefined;
                                        publicDescriptionHtml?: string | undefined | undefined;
                                        publicTraffic?: boolean | undefined | undefined;
                                        quarantine?: boolean | undefined | undefined;
                                        restrictCommenting?: boolean | undefined | undefined;
                                        restrictPosting?: boolean | undefined | undefined;
                                        shouldArchivePosts?: boolean | undefined | undefined;
                                        shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                        showMedia?: boolean | undefined | undefined;
                                        showMediaPreview?: boolean | undefined | undefined;
                                        spoilersEnabled?: boolean | undefined | undefined;
                                        submissionType?: string | undefined | undefined;
                                        submitLinkLabel?: string | undefined | undefined;
                                        submitText?: string | undefined | undefined;
                                        submitTextHtml?: string | undefined | undefined;
                                        submitTextLabel?: string | undefined | undefined;
                                        subredditType?: string | undefined | undefined;
                                        subscribers?: number | undefined | undefined;
                                        suggestedCommentSort?: string | undefined | undefined;
                                        title?: string | undefined | undefined;
                                        url?: string | undefined | undefined;
                                        userCanFlairInSr?: boolean | undefined | undefined;
                                        userFlairBackgroundColor?: string | undefined | undefined;
                                        userFlairCssClass?: string | undefined | undefined;
                                        userFlairEnabledInSr?: boolean | undefined | undefined;
                                        userFlairPosition?: string | undefined | undefined;
                                        userFlairRichtext?: {
                                            e?: string | undefined | undefined;
                                            t?: string | undefined | undefined;
                                        }[];
                                        userFlairTemplateId?: string | undefined | undefined;
                                        userFlairText?: string | undefined | undefined;
                                        userFlairTextColor?: string | undefined | undefined;
                                        userFlairType?: string | undefined | undefined;
                                        userHasFavorited?: boolean | undefined | undefined;
                                        userIsBanned?: boolean | undefined | undefined;
                                        userIsContributor?: boolean | undefined | undefined;
                                        userIsModerator?: boolean | undefined | undefined;
                                        userIsSubscriber?: boolean | undefined | undefined;
                                        userSrFlairEnabled?: boolean | undefined | undefined;
                                        userSrThemeEnabled?: boolean | undefined | undefined;
                                        videostreamLinksCount?: number | undefined | undefined;
                                        whitelistStatus?: string | undefined | undefined;
                                        wikiEnabled?: boolean | undefined | undefined;
                                        wls?: number | undefined | undefined;
                                        markedSpam?: boolean | undefined | undefined;
                                        postRequirements?: {
                                            bodyRestrictionPolicy?: string | undefined | undefined;
                                        } | undefined;
                                        userIsMuted?: boolean;
                                    } | undefined;
                                    suspensionExpirationUtc?: string | undefined | undefined;
                                    totalKarma?: number | undefined | undefined;
                                    verified?: boolean | undefined | undefined;
                                    hasPhoneNumber?: boolean | undefined | undefined;
                                    subredditsModerated?: number | undefined | undefined;
                                    hasMetaSubscription?: boolean | undefined | undefined;
                                    metaSubscriptionAge?: number | undefined | undefined;
                                    metaPointsBalance?: string | undefined | undefined;
                                    metaLockedPointsBalance?: string | undefined | undefined;
                                    commentSubredditKarma?: number | undefined | undefined;
                                    postSubredditKarma?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    isSubredditProxyAccount?: boolean | undefined | undefined;
                                } | undefined;
                            } | undefined;
                        }[];
                        dist?: number | undefined | undefined;
                    } | undefined;
                }): WikiPageRevisionListing;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Revert a wiki page to revision
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_revert}
         */
        readonly revertWikiPage: {
            readonly name: "RevertWikiPage";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.RevertWikiPageRequest";
                encode(message: RevertWikiPageRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): RevertWikiPageRequest;
                fromJSON(object: any): RevertWikiPageRequest;
                toJSON(message: RevertWikiPageRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                    revision?: string;
                }): RevertWikiPageRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                    revision?: string;
                }): RevertWikiPageRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Retrieve the current permission settings for page
         *
         * @see {@link https://www.reddit.com/dev/api#GET_wiki_settings_\{page\}}
         */
        readonly getWikiPageSettings: {
            readonly name: "GetWikiPageSettings";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.GetWikiPageSettingsRequest";
                encode(message: GetWikiPageSettingsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWikiPageSettingsRequest;
                fromJSON(object: any): GetWikiPageSettingsRequest;
                toJSON(message: GetWikiPageSettingsRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                }): GetWikiPageSettingsRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                }): GetWikiPageSettingsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.wiki.WikiPageSettings";
                encode(message: WikiPageSettings, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WikiPageSettings;
                fromJSON(object: any): WikiPageSettings;
                toJSON(message: WikiPageSettings): unknown;
                create(base?: {
                    kind?: string;
                    data?: {
                        permLevel?: number;
                        editors?: {
                            id?: string | undefined | undefined;
                            data?: {
                                acceptChats?: boolean | undefined | undefined;
                                acceptFollowers?: boolean | undefined | undefined;
                                acceptPms?: boolean | undefined | undefined;
                                awardeeKarma?: number | undefined | undefined;
                                awarderKarma?: number | undefined | undefined;
                                canCreateSubreddit?: boolean | undefined | undefined;
                                canEditName?: boolean | undefined | undefined;
                                coins?: number | undefined | undefined;
                                commentKarma?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                features?: {
                                    awardsOnStreams?: boolean | undefined | undefined;
                                    canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                    chatGroupRollout?: boolean | undefined | undefined;
                                    chatSubreddit?: boolean | undefined | undefined;
                                    chatUserSettings?: boolean | undefined | undefined;
                                    chat?: boolean | undefined | undefined;
                                    cookieConsentBanner?: boolean | undefined | undefined;
                                    crosspostNotif?: boolean | undefined | undefined;
                                    crowdControlForPost?: boolean | undefined | undefined;
                                    customFeedImage?: boolean | undefined | undefined;
                                    doNotTrack?: boolean | undefined | undefined;
                                    expensiveCoinsPackage?: boolean | undefined | undefined;
                                    isEmailPermissionRequired?: boolean | undefined | undefined;
                                    liveComments?: boolean | undefined | undefined;
                                    liveOrangereds?: boolean | undefined | undefined;
                                    modAwards?: boolean | undefined | undefined;
                                    modServiceMuteReads?: boolean | undefined | undefined;
                                    modServiceMuteWrites?: boolean | undefined | undefined;
                                    modlogCopyrightRemoval?: boolean | undefined | undefined;
                                    mwebNsfwXpromo?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                    mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                    mwebXpromoRevampV2?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoRevampV3?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    noreferrerToNoopener?: boolean | undefined | undefined;
                                    pollsMobile?: boolean | undefined | undefined;
                                    premiumSubscriptionsTable?: boolean | undefined | undefined;
                                    promotedTrendBlanks?: boolean | undefined | undefined;
                                    resizedStylesImages?: boolean | undefined | undefined;
                                    showAmpLink?: boolean | undefined | undefined;
                                    showNpsSurvey?: boolean | undefined | undefined;
                                    spezModal?: boolean | undefined | undefined;
                                    usePrefAccountDeployment?: boolean | undefined | undefined;
                                    userFlairMigrationTesting?: boolean | undefined | undefined;
                                    webhookConfig?: boolean | undefined | undefined;
                                } | undefined;
                                forcePasswordReset?: boolean | undefined | undefined;
                                goldCreddits?: number | undefined | undefined;
                                goldExpiration?: string | undefined | undefined;
                                hasAndroidSubscription?: boolean | undefined | undefined;
                                hasExternalAccount?: boolean | undefined | undefined;
                                hasGoldSubscription?: boolean | undefined | undefined;
                                hasIosSubscription?: boolean | undefined | undefined;
                                hasMail?: boolean | undefined | undefined;
                                hasModMail?: boolean | undefined | undefined;
                                hasPaypalSubscription?: boolean | undefined | undefined;
                                hasStripeSubscription?: boolean | undefined | undefined;
                                hasSubscribed?: boolean | undefined | undefined;
                                hasSubscribedToPremium?: boolean | undefined | undefined;
                                hasVerifiedEmail?: boolean | undefined | undefined;
                                hasVisitedNewProfile?: boolean | undefined | undefined;
                                hideFromRobots?: boolean | undefined | undefined;
                                iconImg?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                inBeta?: boolean | undefined | undefined;
                                inChat?: boolean | undefined | undefined;
                                inRedesignBeta?: boolean | undefined | undefined;
                                inboxCount?: number | undefined | undefined;
                                isBlocked?: boolean | undefined | undefined;
                                isEmployee?: boolean | undefined | undefined;
                                isFriend?: boolean | undefined | undefined;
                                isGold?: boolean | undefined | undefined;
                                isMod?: boolean | undefined | undefined;
                                isSponsor?: boolean | undefined | undefined;
                                isSuspended?: boolean | undefined | undefined;
                                linkKarma?: number | undefined | undefined;
                                modhash?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                newModmailExists?: boolean | undefined | undefined;
                                numFriends?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                passwordSet?: boolean | undefined | undefined;
                                prefAutoplay?: boolean | undefined | undefined;
                                prefClickgadget?: number | undefined | undefined;
                                prefGeopopular?: string | undefined | undefined;
                                prefNightmode?: boolean | undefined | undefined;
                                prefNoProfanity?: boolean | undefined | undefined;
                                prefShowPresence?: boolean | undefined | undefined;
                                prefShowSnoovatar?: boolean | undefined | undefined;
                                prefShowTrending?: boolean | undefined | undefined;
                                prefShowTwitter?: boolean | undefined | undefined;
                                prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                prefVideoAutoplay?: boolean | undefined | undefined;
                                snoovatarImg?: string | undefined | undefined;
                                snoovatarSize?: number[];
                                subreddit?: {
                                    acceptFollowers?: boolean | undefined | undefined;
                                    accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                    accountsActive?: number | undefined | undefined;
                                    activeUserCount?: number | undefined | undefined;
                                    advertiserCategory?: string | undefined | undefined;
                                    allOriginalContent?: boolean | undefined | undefined;
                                    allowChatPostCreation?: boolean | undefined | undefined;
                                    allowDiscovery?: boolean | undefined | undefined;
                                    allowGalleries?: boolean | undefined | undefined;
                                    allowImages?: boolean | undefined | undefined;
                                    allowPolls?: boolean | undefined | undefined;
                                    allowPredictionContributors?: boolean | undefined | undefined;
                                    allowPredictionsTournament?: boolean | undefined | undefined;
                                    allowPredictions?: boolean | undefined | undefined;
                                    allowTalks?: boolean | undefined | undefined;
                                    allowVideogifs?: boolean | undefined | undefined;
                                    allowVideos?: boolean | undefined | undefined;
                                    allowedMediaInComments?: string[];
                                    bannerBackgroundColor?: string | undefined | undefined;
                                    bannerBackgroundImage?: string | undefined | undefined;
                                    bannerImg?: string | undefined | undefined;
                                    bannerSize?: number[];
                                    canAssignLinkFlair?: boolean | undefined | undefined;
                                    canAssignUserFlair?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    collapseDeletedComments?: boolean | undefined | undefined;
                                    commentContributionSettings?: {
                                        allowedMediaTypes?: string[];
                                    } | undefined;
                                    commentScoreHideMins?: number | undefined | undefined;
                                    communityIcon?: string | undefined | undefined;
                                    communityReviewed?: boolean | undefined | undefined;
                                    contentCategory?: string | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    defaultSet?: boolean | undefined | undefined;
                                    description?: string | undefined | undefined;
                                    descriptionHtml?: string | undefined | undefined;
                                    disableContributorRequests?: boolean | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    displayNamePrefixed?: string | undefined | undefined;
                                    emojisCustomSize?: number[];
                                    emojisEnabled?: boolean | undefined | undefined;
                                    freeFormReports?: boolean | undefined | undefined;
                                    hasMenuWidget?: boolean | undefined | undefined;
                                    headerImg?: string | undefined | undefined;
                                    headerSize?: number[];
                                    headerTitle?: string | undefined | undefined;
                                    hideAds?: boolean | undefined | undefined;
                                    iconColor?: string | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    iconSize?: number[];
                                    id?: string | undefined | undefined;
                                    isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                    isCrosspostableSubreddit?: boolean | undefined | undefined;
                                    isDefaultBanner?: boolean | undefined | undefined;
                                    isDefaultIcon?: boolean | undefined | undefined;
                                    isEnrolledInNewModmail?: boolean | undefined | undefined;
                                    keyColor?: string | undefined | undefined;
                                    lang?: string | undefined | undefined;
                                    linkFlairEnabled?: boolean | undefined | undefined;
                                    linkFlairPosition?: string | undefined | undefined;
                                    mobileBannerImage?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    notificationLevel?: string | undefined | undefined;
                                    originalContentTagEnabled?: string | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    predictionLeaderboardEntryType?: string | undefined | undefined;
                                    previousNames?: string[];
                                    primaryColor?: string | undefined | undefined;
                                    publicDescription?: string | undefined | undefined;
                                    publicDescriptionHtml?: string | undefined | undefined;
                                    publicTraffic?: boolean | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    restrictCommenting?: boolean | undefined | undefined;
                                    restrictPosting?: boolean | undefined | undefined;
                                    shouldArchivePosts?: boolean | undefined | undefined;
                                    shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                    showMedia?: boolean | undefined | undefined;
                                    showMediaPreview?: boolean | undefined | undefined;
                                    spoilersEnabled?: boolean | undefined | undefined;
                                    submissionType?: string | undefined | undefined;
                                    submitLinkLabel?: string | undefined | undefined;
                                    submitText?: string | undefined | undefined;
                                    submitTextHtml?: string | undefined | undefined;
                                    submitTextLabel?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    subscribers?: number | undefined | undefined;
                                    suggestedCommentSort?: string | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    userCanFlairInSr?: boolean | undefined | undefined;
                                    userFlairBackgroundColor?: string | undefined | undefined;
                                    userFlairCssClass?: string | undefined | undefined;
                                    userFlairEnabledInSr?: boolean | undefined | undefined;
                                    userFlairPosition?: string | undefined | undefined;
                                    userFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    userFlairTemplateId?: string | undefined | undefined;
                                    userFlairText?: string | undefined | undefined;
                                    userFlairTextColor?: string | undefined | undefined;
                                    userFlairType?: string | undefined | undefined;
                                    userHasFavorited?: boolean | undefined | undefined;
                                    userIsBanned?: boolean | undefined | undefined;
                                    userIsContributor?: boolean | undefined | undefined;
                                    userIsModerator?: boolean | undefined | undefined;
                                    userIsSubscriber?: boolean | undefined | undefined;
                                    userSrFlairEnabled?: boolean | undefined | undefined;
                                    userSrThemeEnabled?: boolean | undefined | undefined;
                                    videostreamLinksCount?: number | undefined | undefined;
                                    whitelistStatus?: string | undefined | undefined;
                                    wikiEnabled?: boolean | undefined | undefined;
                                    wls?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    postRequirements?: {
                                        bodyRestrictionPolicy?: string | undefined | undefined;
                                    } | undefined;
                                    userIsMuted?: boolean;
                                } | undefined;
                                suspensionExpirationUtc?: string | undefined | undefined;
                                totalKarma?: number | undefined | undefined;
                                verified?: boolean | undefined | undefined;
                                hasPhoneNumber?: boolean | undefined | undefined;
                                subredditsModerated?: number | undefined | undefined;
                                hasMetaSubscription?: boolean | undefined | undefined;
                                metaSubscriptionAge?: number | undefined | undefined;
                                metaPointsBalance?: string | undefined | undefined;
                                metaLockedPointsBalance?: string | undefined | undefined;
                                commentSubredditKarma?: number | undefined | undefined;
                                postSubredditKarma?: number | undefined | undefined;
                                markedSpam?: boolean | undefined | undefined;
                                isSubredditProxyAccount?: boolean | undefined | undefined;
                            } | undefined;
                        }[];
                        listed?: boolean;
                    } | undefined;
                }): WikiPageSettings;
                fromPartial(object: {
                    kind?: string;
                    data?: {
                        permLevel?: number;
                        editors?: {
                            id?: string | undefined | undefined;
                            data?: {
                                acceptChats?: boolean | undefined | undefined;
                                acceptFollowers?: boolean | undefined | undefined;
                                acceptPms?: boolean | undefined | undefined;
                                awardeeKarma?: number | undefined | undefined;
                                awarderKarma?: number | undefined | undefined;
                                canCreateSubreddit?: boolean | undefined | undefined;
                                canEditName?: boolean | undefined | undefined;
                                coins?: number | undefined | undefined;
                                commentKarma?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                features?: {
                                    awardsOnStreams?: boolean | undefined | undefined;
                                    canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                    chatGroupRollout?: boolean | undefined | undefined;
                                    chatSubreddit?: boolean | undefined | undefined;
                                    chatUserSettings?: boolean | undefined | undefined;
                                    chat?: boolean | undefined | undefined;
                                    cookieConsentBanner?: boolean | undefined | undefined;
                                    crosspostNotif?: boolean | undefined | undefined;
                                    crowdControlForPost?: boolean | undefined | undefined;
                                    customFeedImage?: boolean | undefined | undefined;
                                    doNotTrack?: boolean | undefined | undefined;
                                    expensiveCoinsPackage?: boolean | undefined | undefined;
                                    isEmailPermissionRequired?: boolean | undefined | undefined;
                                    liveComments?: boolean | undefined | undefined;
                                    liveOrangereds?: boolean | undefined | undefined;
                                    modAwards?: boolean | undefined | undefined;
                                    modServiceMuteReads?: boolean | undefined | undefined;
                                    modServiceMuteWrites?: boolean | undefined | undefined;
                                    modlogCopyrightRemoval?: boolean | undefined | undefined;
                                    mwebNsfwXpromo?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                    mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                    mwebXpromoRevampV2?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoRevampV3?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    noreferrerToNoopener?: boolean | undefined | undefined;
                                    pollsMobile?: boolean | undefined | undefined;
                                    premiumSubscriptionsTable?: boolean | undefined | undefined;
                                    promotedTrendBlanks?: boolean | undefined | undefined;
                                    resizedStylesImages?: boolean | undefined | undefined;
                                    showAmpLink?: boolean | undefined | undefined;
                                    showNpsSurvey?: boolean | undefined | undefined;
                                    spezModal?: boolean | undefined | undefined;
                                    usePrefAccountDeployment?: boolean | undefined | undefined;
                                    userFlairMigrationTesting?: boolean | undefined | undefined;
                                    webhookConfig?: boolean | undefined | undefined;
                                } | undefined;
                                forcePasswordReset?: boolean | undefined | undefined;
                                goldCreddits?: number | undefined | undefined;
                                goldExpiration?: string | undefined | undefined;
                                hasAndroidSubscription?: boolean | undefined | undefined;
                                hasExternalAccount?: boolean | undefined | undefined;
                                hasGoldSubscription?: boolean | undefined | undefined;
                                hasIosSubscription?: boolean | undefined | undefined;
                                hasMail?: boolean | undefined | undefined;
                                hasModMail?: boolean | undefined | undefined;
                                hasPaypalSubscription?: boolean | undefined | undefined;
                                hasStripeSubscription?: boolean | undefined | undefined;
                                hasSubscribed?: boolean | undefined | undefined;
                                hasSubscribedToPremium?: boolean | undefined | undefined;
                                hasVerifiedEmail?: boolean | undefined | undefined;
                                hasVisitedNewProfile?: boolean | undefined | undefined;
                                hideFromRobots?: boolean | undefined | undefined;
                                iconImg?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                inBeta?: boolean | undefined | undefined;
                                inChat?: boolean | undefined | undefined;
                                inRedesignBeta?: boolean | undefined | undefined;
                                inboxCount?: number | undefined | undefined;
                                isBlocked?: boolean | undefined | undefined;
                                isEmployee?: boolean | undefined | undefined;
                                isFriend?: boolean | undefined | undefined;
                                isGold?: boolean | undefined | undefined;
                                isMod?: boolean | undefined | undefined;
                                isSponsor?: boolean | undefined | undefined;
                                isSuspended?: boolean | undefined | undefined;
                                linkKarma?: number | undefined | undefined;
                                modhash?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                newModmailExists?: boolean | undefined | undefined;
                                numFriends?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                passwordSet?: boolean | undefined | undefined;
                                prefAutoplay?: boolean | undefined | undefined;
                                prefClickgadget?: number | undefined | undefined;
                                prefGeopopular?: string | undefined | undefined;
                                prefNightmode?: boolean | undefined | undefined;
                                prefNoProfanity?: boolean | undefined | undefined;
                                prefShowPresence?: boolean | undefined | undefined;
                                prefShowSnoovatar?: boolean | undefined | undefined;
                                prefShowTrending?: boolean | undefined | undefined;
                                prefShowTwitter?: boolean | undefined | undefined;
                                prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                prefVideoAutoplay?: boolean | undefined | undefined;
                                snoovatarImg?: string | undefined | undefined;
                                snoovatarSize?: number[];
                                subreddit?: {
                                    acceptFollowers?: boolean | undefined | undefined;
                                    accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                    accountsActive?: number | undefined | undefined;
                                    activeUserCount?: number | undefined | undefined;
                                    advertiserCategory?: string | undefined | undefined;
                                    allOriginalContent?: boolean | undefined | undefined;
                                    allowChatPostCreation?: boolean | undefined | undefined;
                                    allowDiscovery?: boolean | undefined | undefined;
                                    allowGalleries?: boolean | undefined | undefined;
                                    allowImages?: boolean | undefined | undefined;
                                    allowPolls?: boolean | undefined | undefined;
                                    allowPredictionContributors?: boolean | undefined | undefined;
                                    allowPredictionsTournament?: boolean | undefined | undefined;
                                    allowPredictions?: boolean | undefined | undefined;
                                    allowTalks?: boolean | undefined | undefined;
                                    allowVideogifs?: boolean | undefined | undefined;
                                    allowVideos?: boolean | undefined | undefined;
                                    allowedMediaInComments?: string[];
                                    bannerBackgroundColor?: string | undefined | undefined;
                                    bannerBackgroundImage?: string | undefined | undefined;
                                    bannerImg?: string | undefined | undefined;
                                    bannerSize?: number[];
                                    canAssignLinkFlair?: boolean | undefined | undefined;
                                    canAssignUserFlair?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    collapseDeletedComments?: boolean | undefined | undefined;
                                    commentContributionSettings?: {
                                        allowedMediaTypes?: string[];
                                    } | undefined;
                                    commentScoreHideMins?: number | undefined | undefined;
                                    communityIcon?: string | undefined | undefined;
                                    communityReviewed?: boolean | undefined | undefined;
                                    contentCategory?: string | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    defaultSet?: boolean | undefined | undefined;
                                    description?: string | undefined | undefined;
                                    descriptionHtml?: string | undefined | undefined;
                                    disableContributorRequests?: boolean | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    displayNamePrefixed?: string | undefined | undefined;
                                    emojisCustomSize?: number[];
                                    emojisEnabled?: boolean | undefined | undefined;
                                    freeFormReports?: boolean | undefined | undefined;
                                    hasMenuWidget?: boolean | undefined | undefined;
                                    headerImg?: string | undefined | undefined;
                                    headerSize?: number[];
                                    headerTitle?: string | undefined | undefined;
                                    hideAds?: boolean | undefined | undefined;
                                    iconColor?: string | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    iconSize?: number[];
                                    id?: string | undefined | undefined;
                                    isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                    isCrosspostableSubreddit?: boolean | undefined | undefined;
                                    isDefaultBanner?: boolean | undefined | undefined;
                                    isDefaultIcon?: boolean | undefined | undefined;
                                    isEnrolledInNewModmail?: boolean | undefined | undefined;
                                    keyColor?: string | undefined | undefined;
                                    lang?: string | undefined | undefined;
                                    linkFlairEnabled?: boolean | undefined | undefined;
                                    linkFlairPosition?: string | undefined | undefined;
                                    mobileBannerImage?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    notificationLevel?: string | undefined | undefined;
                                    originalContentTagEnabled?: string | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    predictionLeaderboardEntryType?: string | undefined | undefined;
                                    previousNames?: string[];
                                    primaryColor?: string | undefined | undefined;
                                    publicDescription?: string | undefined | undefined;
                                    publicDescriptionHtml?: string | undefined | undefined;
                                    publicTraffic?: boolean | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    restrictCommenting?: boolean | undefined | undefined;
                                    restrictPosting?: boolean | undefined | undefined;
                                    shouldArchivePosts?: boolean | undefined | undefined;
                                    shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                    showMedia?: boolean | undefined | undefined;
                                    showMediaPreview?: boolean | undefined | undefined;
                                    spoilersEnabled?: boolean | undefined | undefined;
                                    submissionType?: string | undefined | undefined;
                                    submitLinkLabel?: string | undefined | undefined;
                                    submitText?: string | undefined | undefined;
                                    submitTextHtml?: string | undefined | undefined;
                                    submitTextLabel?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    subscribers?: number | undefined | undefined;
                                    suggestedCommentSort?: string | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    userCanFlairInSr?: boolean | undefined | undefined;
                                    userFlairBackgroundColor?: string | undefined | undefined;
                                    userFlairCssClass?: string | undefined | undefined;
                                    userFlairEnabledInSr?: boolean | undefined | undefined;
                                    userFlairPosition?: string | undefined | undefined;
                                    userFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    userFlairTemplateId?: string | undefined | undefined;
                                    userFlairText?: string | undefined | undefined;
                                    userFlairTextColor?: string | undefined | undefined;
                                    userFlairType?: string | undefined | undefined;
                                    userHasFavorited?: boolean | undefined | undefined;
                                    userIsBanned?: boolean | undefined | undefined;
                                    userIsContributor?: boolean | undefined | undefined;
                                    userIsModerator?: boolean | undefined | undefined;
                                    userIsSubscriber?: boolean | undefined | undefined;
                                    userSrFlairEnabled?: boolean | undefined | undefined;
                                    userSrThemeEnabled?: boolean | undefined | undefined;
                                    videostreamLinksCount?: number | undefined | undefined;
                                    whitelistStatus?: string | undefined | undefined;
                                    wikiEnabled?: boolean | undefined | undefined;
                                    wls?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    postRequirements?: {
                                        bodyRestrictionPolicy?: string | undefined | undefined;
                                    } | undefined;
                                    userIsMuted?: boolean;
                                } | undefined;
                                suspensionExpirationUtc?: string | undefined | undefined;
                                totalKarma?: number | undefined | undefined;
                                verified?: boolean | undefined | undefined;
                                hasPhoneNumber?: boolean | undefined | undefined;
                                subredditsModerated?: number | undefined | undefined;
                                hasMetaSubscription?: boolean | undefined | undefined;
                                metaSubscriptionAge?: number | undefined | undefined;
                                metaPointsBalance?: string | undefined | undefined;
                                metaLockedPointsBalance?: string | undefined | undefined;
                                commentSubredditKarma?: number | undefined | undefined;
                                postSubredditKarma?: number | undefined | undefined;
                                markedSpam?: boolean | undefined | undefined;
                                isSubredditProxyAccount?: boolean | undefined | undefined;
                            } | undefined;
                        }[];
                        listed?: boolean;
                    } | undefined;
                }): WikiPageSettings;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Update the permissions and visibility of wiki page
         *
         * @see {@link https://www.reddit.com/dev/api#POST_wiki_settings_\{page\}}
         */
        readonly updateWikiPageSettings: {
            readonly name: "UpdateWikiPageSettings";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.UpdateWikiPageSettingsRequest";
                encode(message: UpdateWikiPageSettingsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): UpdateWikiPageSettingsRequest;
                fromJSON(object: any): UpdateWikiPageSettingsRequest;
                toJSON(message: UpdateWikiPageSettingsRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                    permlevel?: number;
                    listed?: string;
                }): UpdateWikiPageSettingsRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                    permlevel?: number;
                    listed?: string;
                }): UpdateWikiPageSettingsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.plugin.redditapi.wiki.WikiPageSettings";
                encode(message: WikiPageSettings, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WikiPageSettings;
                fromJSON(object: any): WikiPageSettings;
                toJSON(message: WikiPageSettings): unknown;
                create(base?: {
                    kind?: string;
                    data?: {
                        permLevel?: number;
                        editors?: {
                            id?: string | undefined | undefined;
                            data?: {
                                acceptChats?: boolean | undefined | undefined;
                                acceptFollowers?: boolean | undefined | undefined;
                                acceptPms?: boolean | undefined | undefined;
                                awardeeKarma?: number | undefined | undefined;
                                awarderKarma?: number | undefined | undefined;
                                canCreateSubreddit?: boolean | undefined | undefined;
                                canEditName?: boolean | undefined | undefined;
                                coins?: number | undefined | undefined;
                                commentKarma?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                features?: {
                                    awardsOnStreams?: boolean | undefined | undefined;
                                    canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                    chatGroupRollout?: boolean | undefined | undefined;
                                    chatSubreddit?: boolean | undefined | undefined;
                                    chatUserSettings?: boolean | undefined | undefined;
                                    chat?: boolean | undefined | undefined;
                                    cookieConsentBanner?: boolean | undefined | undefined;
                                    crosspostNotif?: boolean | undefined | undefined;
                                    crowdControlForPost?: boolean | undefined | undefined;
                                    customFeedImage?: boolean | undefined | undefined;
                                    doNotTrack?: boolean | undefined | undefined;
                                    expensiveCoinsPackage?: boolean | undefined | undefined;
                                    isEmailPermissionRequired?: boolean | undefined | undefined;
                                    liveComments?: boolean | undefined | undefined;
                                    liveOrangereds?: boolean | undefined | undefined;
                                    modAwards?: boolean | undefined | undefined;
                                    modServiceMuteReads?: boolean | undefined | undefined;
                                    modServiceMuteWrites?: boolean | undefined | undefined;
                                    modlogCopyrightRemoval?: boolean | undefined | undefined;
                                    mwebNsfwXpromo?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                    mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                    mwebXpromoRevampV2?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoRevampV3?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    noreferrerToNoopener?: boolean | undefined | undefined;
                                    pollsMobile?: boolean | undefined | undefined;
                                    premiumSubscriptionsTable?: boolean | undefined | undefined;
                                    promotedTrendBlanks?: boolean | undefined | undefined;
                                    resizedStylesImages?: boolean | undefined | undefined;
                                    showAmpLink?: boolean | undefined | undefined;
                                    showNpsSurvey?: boolean | undefined | undefined;
                                    spezModal?: boolean | undefined | undefined;
                                    usePrefAccountDeployment?: boolean | undefined | undefined;
                                    userFlairMigrationTesting?: boolean | undefined | undefined;
                                    webhookConfig?: boolean | undefined | undefined;
                                } | undefined;
                                forcePasswordReset?: boolean | undefined | undefined;
                                goldCreddits?: number | undefined | undefined;
                                goldExpiration?: string | undefined | undefined;
                                hasAndroidSubscription?: boolean | undefined | undefined;
                                hasExternalAccount?: boolean | undefined | undefined;
                                hasGoldSubscription?: boolean | undefined | undefined;
                                hasIosSubscription?: boolean | undefined | undefined;
                                hasMail?: boolean | undefined | undefined;
                                hasModMail?: boolean | undefined | undefined;
                                hasPaypalSubscription?: boolean | undefined | undefined;
                                hasStripeSubscription?: boolean | undefined | undefined;
                                hasSubscribed?: boolean | undefined | undefined;
                                hasSubscribedToPremium?: boolean | undefined | undefined;
                                hasVerifiedEmail?: boolean | undefined | undefined;
                                hasVisitedNewProfile?: boolean | undefined | undefined;
                                hideFromRobots?: boolean | undefined | undefined;
                                iconImg?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                inBeta?: boolean | undefined | undefined;
                                inChat?: boolean | undefined | undefined;
                                inRedesignBeta?: boolean | undefined | undefined;
                                inboxCount?: number | undefined | undefined;
                                isBlocked?: boolean | undefined | undefined;
                                isEmployee?: boolean | undefined | undefined;
                                isFriend?: boolean | undefined | undefined;
                                isGold?: boolean | undefined | undefined;
                                isMod?: boolean | undefined | undefined;
                                isSponsor?: boolean | undefined | undefined;
                                isSuspended?: boolean | undefined | undefined;
                                linkKarma?: number | undefined | undefined;
                                modhash?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                newModmailExists?: boolean | undefined | undefined;
                                numFriends?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                passwordSet?: boolean | undefined | undefined;
                                prefAutoplay?: boolean | undefined | undefined;
                                prefClickgadget?: number | undefined | undefined;
                                prefGeopopular?: string | undefined | undefined;
                                prefNightmode?: boolean | undefined | undefined;
                                prefNoProfanity?: boolean | undefined | undefined;
                                prefShowPresence?: boolean | undefined | undefined;
                                prefShowSnoovatar?: boolean | undefined | undefined;
                                prefShowTrending?: boolean | undefined | undefined;
                                prefShowTwitter?: boolean | undefined | undefined;
                                prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                prefVideoAutoplay?: boolean | undefined | undefined;
                                snoovatarImg?: string | undefined | undefined;
                                snoovatarSize?: number[];
                                subreddit?: {
                                    acceptFollowers?: boolean | undefined | undefined;
                                    accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                    accountsActive?: number | undefined | undefined;
                                    activeUserCount?: number | undefined | undefined;
                                    advertiserCategory?: string | undefined | undefined;
                                    allOriginalContent?: boolean | undefined | undefined;
                                    allowChatPostCreation?: boolean | undefined | undefined;
                                    allowDiscovery?: boolean | undefined | undefined;
                                    allowGalleries?: boolean | undefined | undefined;
                                    allowImages?: boolean | undefined | undefined;
                                    allowPolls?: boolean | undefined | undefined;
                                    allowPredictionContributors?: boolean | undefined | undefined;
                                    allowPredictionsTournament?: boolean | undefined | undefined;
                                    allowPredictions?: boolean | undefined | undefined;
                                    allowTalks?: boolean | undefined | undefined;
                                    allowVideogifs?: boolean | undefined | undefined;
                                    allowVideos?: boolean | undefined | undefined;
                                    allowedMediaInComments?: string[];
                                    bannerBackgroundColor?: string | undefined | undefined;
                                    bannerBackgroundImage?: string | undefined | undefined;
                                    bannerImg?: string | undefined | undefined;
                                    bannerSize?: number[];
                                    canAssignLinkFlair?: boolean | undefined | undefined;
                                    canAssignUserFlair?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    collapseDeletedComments?: boolean | undefined | undefined;
                                    commentContributionSettings?: {
                                        allowedMediaTypes?: string[];
                                    } | undefined;
                                    commentScoreHideMins?: number | undefined | undefined;
                                    communityIcon?: string | undefined | undefined;
                                    communityReviewed?: boolean | undefined | undefined;
                                    contentCategory?: string | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    defaultSet?: boolean | undefined | undefined;
                                    description?: string | undefined | undefined;
                                    descriptionHtml?: string | undefined | undefined;
                                    disableContributorRequests?: boolean | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    displayNamePrefixed?: string | undefined | undefined;
                                    emojisCustomSize?: number[];
                                    emojisEnabled?: boolean | undefined | undefined;
                                    freeFormReports?: boolean | undefined | undefined;
                                    hasMenuWidget?: boolean | undefined | undefined;
                                    headerImg?: string | undefined | undefined;
                                    headerSize?: number[];
                                    headerTitle?: string | undefined | undefined;
                                    hideAds?: boolean | undefined | undefined;
                                    iconColor?: string | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    iconSize?: number[];
                                    id?: string | undefined | undefined;
                                    isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                    isCrosspostableSubreddit?: boolean | undefined | undefined;
                                    isDefaultBanner?: boolean | undefined | undefined;
                                    isDefaultIcon?: boolean | undefined | undefined;
                                    isEnrolledInNewModmail?: boolean | undefined | undefined;
                                    keyColor?: string | undefined | undefined;
                                    lang?: string | undefined | undefined;
                                    linkFlairEnabled?: boolean | undefined | undefined;
                                    linkFlairPosition?: string | undefined | undefined;
                                    mobileBannerImage?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    notificationLevel?: string | undefined | undefined;
                                    originalContentTagEnabled?: string | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    predictionLeaderboardEntryType?: string | undefined | undefined;
                                    previousNames?: string[];
                                    primaryColor?: string | undefined | undefined;
                                    publicDescription?: string | undefined | undefined;
                                    publicDescriptionHtml?: string | undefined | undefined;
                                    publicTraffic?: boolean | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    restrictCommenting?: boolean | undefined | undefined;
                                    restrictPosting?: boolean | undefined | undefined;
                                    shouldArchivePosts?: boolean | undefined | undefined;
                                    shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                    showMedia?: boolean | undefined | undefined;
                                    showMediaPreview?: boolean | undefined | undefined;
                                    spoilersEnabled?: boolean | undefined | undefined;
                                    submissionType?: string | undefined | undefined;
                                    submitLinkLabel?: string | undefined | undefined;
                                    submitText?: string | undefined | undefined;
                                    submitTextHtml?: string | undefined | undefined;
                                    submitTextLabel?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    subscribers?: number | undefined | undefined;
                                    suggestedCommentSort?: string | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    userCanFlairInSr?: boolean | undefined | undefined;
                                    userFlairBackgroundColor?: string | undefined | undefined;
                                    userFlairCssClass?: string | undefined | undefined;
                                    userFlairEnabledInSr?: boolean | undefined | undefined;
                                    userFlairPosition?: string | undefined | undefined;
                                    userFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    userFlairTemplateId?: string | undefined | undefined;
                                    userFlairText?: string | undefined | undefined;
                                    userFlairTextColor?: string | undefined | undefined;
                                    userFlairType?: string | undefined | undefined;
                                    userHasFavorited?: boolean | undefined | undefined;
                                    userIsBanned?: boolean | undefined | undefined;
                                    userIsContributor?: boolean | undefined | undefined;
                                    userIsModerator?: boolean | undefined | undefined;
                                    userIsSubscriber?: boolean | undefined | undefined;
                                    userSrFlairEnabled?: boolean | undefined | undefined;
                                    userSrThemeEnabled?: boolean | undefined | undefined;
                                    videostreamLinksCount?: number | undefined | undefined;
                                    whitelistStatus?: string | undefined | undefined;
                                    wikiEnabled?: boolean | undefined | undefined;
                                    wls?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    postRequirements?: {
                                        bodyRestrictionPolicy?: string | undefined | undefined;
                                    } | undefined;
                                    userIsMuted?: boolean;
                                } | undefined;
                                suspensionExpirationUtc?: string | undefined | undefined;
                                totalKarma?: number | undefined | undefined;
                                verified?: boolean | undefined | undefined;
                                hasPhoneNumber?: boolean | undefined | undefined;
                                subredditsModerated?: number | undefined | undefined;
                                hasMetaSubscription?: boolean | undefined | undefined;
                                metaSubscriptionAge?: number | undefined | undefined;
                                metaPointsBalance?: string | undefined | undefined;
                                metaLockedPointsBalance?: string | undefined | undefined;
                                commentSubredditKarma?: number | undefined | undefined;
                                postSubredditKarma?: number | undefined | undefined;
                                markedSpam?: boolean | undefined | undefined;
                                isSubredditProxyAccount?: boolean | undefined | undefined;
                            } | undefined;
                        }[];
                        listed?: boolean;
                    } | undefined;
                }): WikiPageSettings;
                fromPartial(object: {
                    kind?: string;
                    data?: {
                        permLevel?: number;
                        editors?: {
                            id?: string | undefined | undefined;
                            data?: {
                                acceptChats?: boolean | undefined | undefined;
                                acceptFollowers?: boolean | undefined | undefined;
                                acceptPms?: boolean | undefined | undefined;
                                awardeeKarma?: number | undefined | undefined;
                                awarderKarma?: number | undefined | undefined;
                                canCreateSubreddit?: boolean | undefined | undefined;
                                canEditName?: boolean | undefined | undefined;
                                coins?: number | undefined | undefined;
                                commentKarma?: number | undefined | undefined;
                                created?: number | undefined | undefined;
                                createdUtc?: number | undefined | undefined;
                                features?: {
                                    awardsOnStreams?: boolean | undefined | undefined;
                                    canMakeMobileTestBuildPurchases?: boolean | undefined | undefined;
                                    chatGroupRollout?: boolean | undefined | undefined;
                                    chatSubreddit?: boolean | undefined | undefined;
                                    chatUserSettings?: boolean | undefined | undefined;
                                    chat?: boolean | undefined | undefined;
                                    cookieConsentBanner?: boolean | undefined | undefined;
                                    crosspostNotif?: boolean | undefined | undefined;
                                    crowdControlForPost?: boolean | undefined | undefined;
                                    customFeedImage?: boolean | undefined | undefined;
                                    doNotTrack?: boolean | undefined | undefined;
                                    expensiveCoinsPackage?: boolean | undefined | undefined;
                                    isEmailPermissionRequired?: boolean | undefined | undefined;
                                    liveComments?: boolean | undefined | undefined;
                                    liveOrangereds?: boolean | undefined | undefined;
                                    modAwards?: boolean | undefined | undefined;
                                    modServiceMuteReads?: boolean | undefined | undefined;
                                    modServiceMuteWrites?: boolean | undefined | undefined;
                                    modlogCopyrightRemoval?: boolean | undefined | undefined;
                                    mwebNsfwXpromo?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoInterstitialCommentsAndroid?: boolean | undefined | undefined;
                                    mwebXpromoInterstitialCommentsIos?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleAndroid?: boolean | undefined | undefined;
                                    mwebXpromoModalListingClickDailyDismissibleIos?: boolean | undefined | undefined;
                                    mwebXpromoRevampV2?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    mwebXpromoRevampV3?: {
                                        experimentId?: number | undefined | undefined;
                                        owner?: string | undefined | undefined;
                                        variant?: string | undefined | undefined;
                                    } | undefined;
                                    noreferrerToNoopener?: boolean | undefined | undefined;
                                    pollsMobile?: boolean | undefined | undefined;
                                    premiumSubscriptionsTable?: boolean | undefined | undefined;
                                    promotedTrendBlanks?: boolean | undefined | undefined;
                                    resizedStylesImages?: boolean | undefined | undefined;
                                    showAmpLink?: boolean | undefined | undefined;
                                    showNpsSurvey?: boolean | undefined | undefined;
                                    spezModal?: boolean | undefined | undefined;
                                    usePrefAccountDeployment?: boolean | undefined | undefined;
                                    userFlairMigrationTesting?: boolean | undefined | undefined;
                                    webhookConfig?: boolean | undefined | undefined;
                                } | undefined;
                                forcePasswordReset?: boolean | undefined | undefined;
                                goldCreddits?: number | undefined | undefined;
                                goldExpiration?: string | undefined | undefined;
                                hasAndroidSubscription?: boolean | undefined | undefined;
                                hasExternalAccount?: boolean | undefined | undefined;
                                hasGoldSubscription?: boolean | undefined | undefined;
                                hasIosSubscription?: boolean | undefined | undefined;
                                hasMail?: boolean | undefined | undefined;
                                hasModMail?: boolean | undefined | undefined;
                                hasPaypalSubscription?: boolean | undefined | undefined;
                                hasStripeSubscription?: boolean | undefined | undefined;
                                hasSubscribed?: boolean | undefined | undefined;
                                hasSubscribedToPremium?: boolean | undefined | undefined;
                                hasVerifiedEmail?: boolean | undefined | undefined;
                                hasVisitedNewProfile?: boolean | undefined | undefined;
                                hideFromRobots?: boolean | undefined | undefined;
                                iconImg?: string | undefined | undefined;
                                id?: string | undefined | undefined;
                                inBeta?: boolean | undefined | undefined;
                                inChat?: boolean | undefined | undefined;
                                inRedesignBeta?: boolean | undefined | undefined;
                                inboxCount?: number | undefined | undefined;
                                isBlocked?: boolean | undefined | undefined;
                                isEmployee?: boolean | undefined | undefined;
                                isFriend?: boolean | undefined | undefined;
                                isGold?: boolean | undefined | undefined;
                                isMod?: boolean | undefined | undefined;
                                isSponsor?: boolean | undefined | undefined;
                                isSuspended?: boolean | undefined | undefined;
                                linkKarma?: number | undefined | undefined;
                                modhash?: string | undefined | undefined;
                                name?: string | undefined | undefined;
                                newModmailExists?: boolean | undefined | undefined;
                                numFriends?: number | undefined | undefined;
                                over18?: boolean | undefined | undefined;
                                passwordSet?: boolean | undefined | undefined;
                                prefAutoplay?: boolean | undefined | undefined;
                                prefClickgadget?: number | undefined | undefined;
                                prefGeopopular?: string | undefined | undefined;
                                prefNightmode?: boolean | undefined | undefined;
                                prefNoProfanity?: boolean | undefined | undefined;
                                prefShowPresence?: boolean | undefined | undefined;
                                prefShowSnoovatar?: boolean | undefined | undefined;
                                prefShowTrending?: boolean | undefined | undefined;
                                prefShowTwitter?: boolean | undefined | undefined;
                                prefTopKarmaSubreddits?: boolean | undefined | undefined;
                                prefVideoAutoplay?: boolean | undefined | undefined;
                                snoovatarImg?: string | undefined | undefined;
                                snoovatarSize?: number[];
                                subreddit?: {
                                    acceptFollowers?: boolean | undefined | undefined;
                                    accountsActiveIsFuzzed?: boolean | undefined | undefined;
                                    accountsActive?: number | undefined | undefined;
                                    activeUserCount?: number | undefined | undefined;
                                    advertiserCategory?: string | undefined | undefined;
                                    allOriginalContent?: boolean | undefined | undefined;
                                    allowChatPostCreation?: boolean | undefined | undefined;
                                    allowDiscovery?: boolean | undefined | undefined;
                                    allowGalleries?: boolean | undefined | undefined;
                                    allowImages?: boolean | undefined | undefined;
                                    allowPolls?: boolean | undefined | undefined;
                                    allowPredictionContributors?: boolean | undefined | undefined;
                                    allowPredictionsTournament?: boolean | undefined | undefined;
                                    allowPredictions?: boolean | undefined | undefined;
                                    allowTalks?: boolean | undefined | undefined;
                                    allowVideogifs?: boolean | undefined | undefined;
                                    allowVideos?: boolean | undefined | undefined;
                                    allowedMediaInComments?: string[];
                                    bannerBackgroundColor?: string | undefined | undefined;
                                    bannerBackgroundImage?: string | undefined | undefined;
                                    bannerImg?: string | undefined | undefined;
                                    bannerSize?: number[];
                                    canAssignLinkFlair?: boolean | undefined | undefined;
                                    canAssignUserFlair?: boolean | undefined | undefined;
                                    coins?: number | undefined | undefined;
                                    collapseDeletedComments?: boolean | undefined | undefined;
                                    commentContributionSettings?: {
                                        allowedMediaTypes?: string[];
                                    } | undefined;
                                    commentScoreHideMins?: number | undefined | undefined;
                                    communityIcon?: string | undefined | undefined;
                                    communityReviewed?: boolean | undefined | undefined;
                                    contentCategory?: string | undefined | undefined;
                                    createdUtc?: number | undefined | undefined;
                                    created?: number | undefined | undefined;
                                    defaultSet?: boolean | undefined | undefined;
                                    description?: string | undefined | undefined;
                                    descriptionHtml?: string | undefined | undefined;
                                    disableContributorRequests?: boolean | undefined | undefined;
                                    displayName?: string | undefined | undefined;
                                    displayNamePrefixed?: string | undefined | undefined;
                                    emojisCustomSize?: number[];
                                    emojisEnabled?: boolean | undefined | undefined;
                                    freeFormReports?: boolean | undefined | undefined;
                                    hasMenuWidget?: boolean | undefined | undefined;
                                    headerImg?: string | undefined | undefined;
                                    headerSize?: number[];
                                    headerTitle?: string | undefined | undefined;
                                    hideAds?: boolean | undefined | undefined;
                                    iconColor?: string | undefined | undefined;
                                    iconImg?: string | undefined | undefined;
                                    iconSize?: number[];
                                    id?: string | undefined | undefined;
                                    isChatPostFeatureEnabled?: boolean | undefined | undefined;
                                    isCrosspostableSubreddit?: boolean | undefined | undefined;
                                    isDefaultBanner?: boolean | undefined | undefined;
                                    isDefaultIcon?: boolean | undefined | undefined;
                                    isEnrolledInNewModmail?: boolean | undefined | undefined;
                                    keyColor?: string | undefined | undefined;
                                    lang?: string | undefined | undefined;
                                    linkFlairEnabled?: boolean | undefined | undefined;
                                    linkFlairPosition?: string | undefined | undefined;
                                    mobileBannerImage?: string | undefined | undefined;
                                    name?: string | undefined | undefined;
                                    notificationLevel?: string | undefined | undefined;
                                    originalContentTagEnabled?: string | undefined | undefined;
                                    over18?: boolean | undefined | undefined;
                                    predictionLeaderboardEntryType?: string | undefined | undefined;
                                    previousNames?: string[];
                                    primaryColor?: string | undefined | undefined;
                                    publicDescription?: string | undefined | undefined;
                                    publicDescriptionHtml?: string | undefined | undefined;
                                    publicTraffic?: boolean | undefined | undefined;
                                    quarantine?: boolean | undefined | undefined;
                                    restrictCommenting?: boolean | undefined | undefined;
                                    restrictPosting?: boolean | undefined | undefined;
                                    shouldArchivePosts?: boolean | undefined | undefined;
                                    shouldShowMediaInCommentsSetting?: boolean | undefined | undefined;
                                    showMedia?: boolean | undefined | undefined;
                                    showMediaPreview?: boolean | undefined | undefined;
                                    spoilersEnabled?: boolean | undefined | undefined;
                                    submissionType?: string | undefined | undefined;
                                    submitLinkLabel?: string | undefined | undefined;
                                    submitText?: string | undefined | undefined;
                                    submitTextHtml?: string | undefined | undefined;
                                    submitTextLabel?: string | undefined | undefined;
                                    subredditType?: string | undefined | undefined;
                                    subscribers?: number | undefined | undefined;
                                    suggestedCommentSort?: string | undefined | undefined;
                                    title?: string | undefined | undefined;
                                    url?: string | undefined | undefined;
                                    userCanFlairInSr?: boolean | undefined | undefined;
                                    userFlairBackgroundColor?: string | undefined | undefined;
                                    userFlairCssClass?: string | undefined | undefined;
                                    userFlairEnabledInSr?: boolean | undefined | undefined;
                                    userFlairPosition?: string | undefined | undefined;
                                    userFlairRichtext?: {
                                        e?: string | undefined | undefined;
                                        t?: string | undefined | undefined;
                                    }[];
                                    userFlairTemplateId?: string | undefined | undefined;
                                    userFlairText?: string | undefined | undefined;
                                    userFlairTextColor?: string | undefined | undefined;
                                    userFlairType?: string | undefined | undefined;
                                    userHasFavorited?: boolean | undefined | undefined;
                                    userIsBanned?: boolean | undefined | undefined;
                                    userIsContributor?: boolean | undefined | undefined;
                                    userIsModerator?: boolean | undefined | undefined;
                                    userIsSubscriber?: boolean | undefined | undefined;
                                    userSrFlairEnabled?: boolean | undefined | undefined;
                                    userSrThemeEnabled?: boolean | undefined | undefined;
                                    videostreamLinksCount?: number | undefined | undefined;
                                    whitelistStatus?: string | undefined | undefined;
                                    wikiEnabled?: boolean | undefined | undefined;
                                    wls?: number | undefined | undefined;
                                    markedSpam?: boolean | undefined | undefined;
                                    postRequirements?: {
                                        bodyRestrictionPolicy?: string | undefined | undefined;
                                    } | undefined;
                                    userIsMuted?: boolean;
                                } | undefined;
                                suspensionExpirationUtc?: string | undefined | undefined;
                                totalKarma?: number | undefined | undefined;
                                verified?: boolean | undefined | undefined;
                                hasPhoneNumber?: boolean | undefined | undefined;
                                subredditsModerated?: number | undefined | undefined;
                                hasMetaSubscription?: boolean | undefined | undefined;
                                metaSubscriptionAge?: number | undefined | undefined;
                                metaPointsBalance?: string | undefined | undefined;
                                metaLockedPointsBalance?: string | undefined | undefined;
                                commentSubredditKarma?: number | undefined | undefined;
                                postSubredditKarma?: number | undefined | undefined;
                                markedSpam?: boolean | undefined | undefined;
                                isSubredditProxyAccount?: boolean | undefined | undefined;
                            } | undefined;
                        }[];
                        listed?: boolean;
                    } | undefined;
                }): WikiPageSettings;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
        /**
         * Allow/deny username to edit this wiki page
         * Note act must be either "add" or "del"
         *
         * @see {@link https://www.reddit.com/dev/api#POST_api_wiki_alloweditor_\{act\}}
         */
        readonly allowEditor: {
            readonly name: "AllowEditor";
            readonly requestType: {
                $type: "devvit.plugin.redditapi.wiki.AllowEditorRequest";
                encode(message: AllowEditorRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): AllowEditorRequest;
                fromJSON(object: any): AllowEditorRequest;
                toJSON(message: AllowEditorRequest): unknown;
                create(base?: {
                    subreddit?: string;
                    page?: string;
                    act?: string;
                    username?: string;
                }): AllowEditorRequest;
                fromPartial(object: {
                    subreddit?: string;
                    page?: string;
                    act?: string;
                    username?: string;
                }): AllowEditorRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {
                readonly _unknownFields: {
                    readonly 480010: readonly [Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>, Uint8Array<ArrayBuffer>];
                };
            };
        };
    };
};
interface Rpc {
    request(service: string, method: string, data: Uint8Array, metadata?: Metadata): Promise<Uint8Array>;
}
export {};
//# sourceMappingURL=wiki_svc.d.ts.map