/**
 * #triggers.ts
 *
 * @packageDocumentation
 */
import _m0 from "protobufjs/minimal.js";
import { Metadata } from "../../../../lib/Types.js";
import { Empty } from "../../../google/protobuf/empty.js";
import { InstallationInfo } from "../../dev_portal/installation/installation.js";
import { TriggerEvent } from "../../triggers/v1alpha/triggers.js";
export interface TriggerResponse {
    /** total number of apps invoked */
    total: number;
    /** successful installation ids */
    success: string[];
    /** map of installation ids to error message */
    errors: {
        [key: string]: string;
    };
}
export interface TriggerResponse_ErrorsEntry {
    key: string;
    value: string;
}
export interface TriggerFanOutResponse {
    /** installation id of apps to invoke */
    installationIds: string[];
}
export interface TriggerInvocation {
    installationId: string;
    evt?: TriggerEvent | undefined;
}
export declare const TriggerResponse: {
    $type: "devvit.gateway.v1alpha.TriggerResponse";
    encode(message: TriggerResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): TriggerResponse;
    fromJSON(object: any): TriggerResponse;
    toJSON(message: TriggerResponse): unknown;
    create(base?: DeepPartial<TriggerResponse>): TriggerResponse;
    fromPartial(object: DeepPartial<TriggerResponse>): TriggerResponse;
};
export declare const TriggerResponse_ErrorsEntry: {
    $type: "devvit.gateway.v1alpha.TriggerResponse.ErrorsEntry";
    encode(message: TriggerResponse_ErrorsEntry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): TriggerResponse_ErrorsEntry;
    fromJSON(object: any): TriggerResponse_ErrorsEntry;
    toJSON(message: TriggerResponse_ErrorsEntry): unknown;
    create(base?: DeepPartial<TriggerResponse_ErrorsEntry>): TriggerResponse_ErrorsEntry;
    fromPartial(object: DeepPartial<TriggerResponse_ErrorsEntry>): TriggerResponse_ErrorsEntry;
};
export declare const TriggerFanOutResponse: {
    $type: "devvit.gateway.v1alpha.TriggerFanOutResponse";
    encode(message: TriggerFanOutResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): TriggerFanOutResponse;
    fromJSON(object: any): TriggerFanOutResponse;
    toJSON(message: TriggerFanOutResponse): unknown;
    create(base?: DeepPartial<TriggerFanOutResponse>): TriggerFanOutResponse;
    fromPartial(object: DeepPartial<TriggerFanOutResponse>): TriggerFanOutResponse;
};
export declare const TriggerInvocation: {
    $type: "devvit.gateway.v1alpha.TriggerInvocation";
    encode(message: TriggerInvocation, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): TriggerInvocation;
    fromJSON(object: any): TriggerInvocation;
    toJSON(message: TriggerInvocation): unknown;
    create(base?: DeepPartial<TriggerInvocation>): TriggerInvocation;
    fromPartial(object: DeepPartial<TriggerInvocation>): TriggerInvocation;
};
export interface Triggers {
    OnTrigger(request: TriggerEvent, metadata?: Metadata): Promise<TriggerResponse>;
    OnFanOut(request: TriggerEvent, metadata?: Metadata): Promise<TriggerFanOutResponse>;
    OnInvoke(request: TriggerInvocation, metadata?: Metadata): Promise<Empty>;
    OnInstall(request: InstallationInfo, metadata?: Metadata): Promise<Empty>;
    OnUninstall(request: InstallationInfo, metadata?: Metadata): Promise<Empty>;
    OnInstallChanged(request: InstallationInfo, metadata?: Metadata): Promise<Empty>;
}
export declare const TriggersServiceName = "devvit.gateway.v1alpha.Triggers";
export declare class TriggersClientImpl implements Triggers {
    private readonly rpc;
    private readonly service;
    constructor(rpc: Rpc, opts?: {
        service?: string;
    });
    OnTrigger(request: TriggerEvent, metadata?: Metadata): Promise<TriggerResponse>;
    OnFanOut(request: TriggerEvent, metadata?: Metadata): Promise<TriggerFanOutResponse>;
    OnInvoke(request: TriggerInvocation, metadata?: Metadata): Promise<Empty>;
    OnInstall(request: InstallationInfo, metadata?: Metadata): Promise<Empty>;
    OnUninstall(request: InstallationInfo, metadata?: Metadata): Promise<Empty>;
    OnInstallChanged(request: InstallationInfo, metadata?: Metadata): Promise<Empty>;
}
export type TriggersDefinition = typeof TriggersDefinition;
export declare const TriggersDefinition: {
    readonly name: "Triggers";
    readonly fullName: "devvit.gateway.v1alpha.Triggers";
    readonly methods: {
        readonly onTrigger: {
            readonly name: "OnTrigger";
            readonly requestType: {
                $type: "devvit.data.triggers.v1alpha.TriggerEvent";
                encode(message: TriggerEvent, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): TriggerEvent;
                fromJSON(object: any): TriggerEvent;
                toJSON(message: TriggerEvent): unknown;
                create(base?: {
                    id?: string;
                    timestamp?: Date | undefined;
                    subreddit?: string;
                    postSubmit?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postCreate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postReport?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    postFlairUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postDelete?: {
                        postId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentSubmit?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentCreate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentUpdate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentReport?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    commentDelete?: {
                        commentId?: string;
                        postId?: string;
                        parentId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    subredditSubscribe?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        subscriber?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appInstall?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appUpgrade?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    modAction?: {
                        action?: string | undefined | undefined;
                        actionedAt?: Date | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        moderator?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetUser?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetComment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        targetPost?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                    } | undefined;
                    modMail?: {
                        messageAuthor?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        messageAuthorType?: string;
                        conversationState?: string;
                        conversationType?: string;
                        isAutoGenerated?: boolean;
                        conversationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        destinationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        conversationId?: string;
                        messageId?: string;
                    } | undefined;
                    accountDelete?: {
                        userId?: string;
                        deletedAt?: Date | undefined;
                        user?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    vote?: {
                        updatedAt?: Date | undefined;
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        upvoteRatio?: number;
                        score?: number;
                    } | undefined;
                    postApprove?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentApprove?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    nsfwPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isNsfw?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    spoilerPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isSpoiler?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterPost?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterComment?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                }): TriggerEvent;
                fromPartial(object: {
                    id?: string;
                    timestamp?: Date | undefined;
                    subreddit?: string;
                    postSubmit?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postCreate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postReport?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    postFlairUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postDelete?: {
                        postId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentSubmit?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentCreate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentUpdate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentReport?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    commentDelete?: {
                        commentId?: string;
                        postId?: string;
                        parentId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    subredditSubscribe?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        subscriber?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appInstall?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appUpgrade?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    modAction?: {
                        action?: string | undefined | undefined;
                        actionedAt?: Date | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        moderator?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetUser?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetComment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        targetPost?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                    } | undefined;
                    modMail?: {
                        messageAuthor?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        messageAuthorType?: string;
                        conversationState?: string;
                        conversationType?: string;
                        isAutoGenerated?: boolean;
                        conversationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        destinationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        conversationId?: string;
                        messageId?: string;
                    } | undefined;
                    accountDelete?: {
                        userId?: string;
                        deletedAt?: Date | undefined;
                        user?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    vote?: {
                        updatedAt?: Date | undefined;
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        upvoteRatio?: number;
                        score?: number;
                    } | undefined;
                    postApprove?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentApprove?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    nsfwPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isNsfw?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    spoilerPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isSpoiler?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterPost?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterComment?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                }): TriggerEvent;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.gateway.v1alpha.TriggerResponse";
                encode(message: TriggerResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): TriggerResponse;
                fromJSON(object: any): TriggerResponse;
                toJSON(message: TriggerResponse): unknown;
                create(base?: DeepPartial<TriggerResponse>): TriggerResponse;
                fromPartial(object: DeepPartial<TriggerResponse>): TriggerResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly onFanOut: {
            readonly name: "OnFanOut";
            readonly requestType: {
                $type: "devvit.data.triggers.v1alpha.TriggerEvent";
                encode(message: TriggerEvent, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): TriggerEvent;
                fromJSON(object: any): TriggerEvent;
                toJSON(message: TriggerEvent): unknown;
                create(base?: {
                    id?: string;
                    timestamp?: Date | undefined;
                    subreddit?: string;
                    postSubmit?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postCreate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postReport?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    postFlairUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postDelete?: {
                        postId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentSubmit?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentCreate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentUpdate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentReport?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    commentDelete?: {
                        commentId?: string;
                        postId?: string;
                        parentId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    subredditSubscribe?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        subscriber?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appInstall?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appUpgrade?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    modAction?: {
                        action?: string | undefined | undefined;
                        actionedAt?: Date | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        moderator?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetUser?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetComment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        targetPost?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                    } | undefined;
                    modMail?: {
                        messageAuthor?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        messageAuthorType?: string;
                        conversationState?: string;
                        conversationType?: string;
                        isAutoGenerated?: boolean;
                        conversationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        destinationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        conversationId?: string;
                        messageId?: string;
                    } | undefined;
                    accountDelete?: {
                        userId?: string;
                        deletedAt?: Date | undefined;
                        user?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    vote?: {
                        updatedAt?: Date | undefined;
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        upvoteRatio?: number;
                        score?: number;
                    } | undefined;
                    postApprove?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentApprove?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    nsfwPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isNsfw?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    spoilerPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isSpoiler?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterPost?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterComment?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                }): TriggerEvent;
                fromPartial(object: {
                    id?: string;
                    timestamp?: Date | undefined;
                    subreddit?: string;
                    postSubmit?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postCreate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postReport?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    postFlairUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    postDelete?: {
                        postId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentSubmit?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentCreate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentUpdate?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        previousBody?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentReport?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        reason?: string;
                    } | undefined;
                    commentDelete?: {
                        commentId?: string;
                        postId?: string;
                        parentId?: string;
                        deletedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        reason?: import("../../events/v1alpha/events.js").DeletionReason;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    subredditSubscribe?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        subscriber?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appInstall?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    appUpgrade?: {
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        installer?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    modAction?: {
                        action?: string | undefined | undefined;
                        actionedAt?: Date | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        moderator?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetUser?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        targetComment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        targetPost?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                    } | undefined;
                    modMail?: {
                        messageAuthor?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        createdAt?: Date | undefined;
                        messageAuthorType?: string;
                        conversationState?: string;
                        conversationType?: string;
                        isAutoGenerated?: boolean;
                        conversationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        destinationSubreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        conversationId?: string;
                        messageId?: string;
                    } | undefined;
                    accountDelete?: {
                        userId?: string;
                        deletedAt?: Date | undefined;
                        user?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                    } | undefined;
                    vote?: {
                        updatedAt?: Date | undefined;
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                        upvoteRatio?: number;
                        score?: number;
                    } | undefined;
                    postApprove?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    commentApprove?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        approvedAt?: Date | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        source?: import("../../events/v1alpha/events.js").EventSource;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    nsfwPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isNsfw?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    spoilerPostUpdate?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        author?: {
                            id?: string;
                            name?: string;
                            isGold?: boolean;
                            snoovatarImage?: string;
                            url?: string;
                            spam?: boolean;
                            banned?: boolean;
                            flair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            karma?: number;
                            iconImage?: string;
                            description?: string;
                            suspended?: boolean;
                        } | undefined;
                        isSpoiler?: boolean;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterPost?: {
                        post?: {
                            id?: string;
                            title?: string;
                            selftext?: string;
                            nsfw?: boolean;
                            authorId?: string;
                            crowdControlLevel?: import("../../reddit/v2alpha/postv2.js").CrowdControlLevel;
                            numReports?: number;
                            isGallery?: boolean;
                            isMeta?: boolean;
                            createdAt?: number;
                            isApproved?: boolean;
                            isArchived?: boolean;
                            distinguished?: import("../../reddit/v2alpha/postv2.js").DistinguishType;
                            ignoreReports?: boolean;
                            isSelf?: boolean;
                            isVideo?: boolean;
                            isLocked?: boolean;
                            isSpoiler?: boolean;
                            subredditId?: string;
                            upvotes?: number;
                            downvotes?: number;
                            url?: string;
                            isSticky?: boolean;
                            linkFlair?: {
                                text?: string;
                                cssClass?: string;
                                backgroundColor?: string;
                                templateId?: string;
                                textColor?: string;
                            } | undefined;
                            authorFlair?: {
                                userId?: string;
                                subredditId?: string;
                                text?: string;
                                cssClass?: string;
                                templateId?: string;
                                textColor?: string;
                                backgroundColor?: string;
                                enabled?: boolean;
                            } | undefined;
                            spam?: boolean;
                            deleted?: boolean;
                            languageCode?: string;
                            updatedAt?: number;
                            gildings?: number;
                            score?: number;
                            numComments?: number;
                            thumbnail?: string;
                            media?: {
                                type?: string;
                                oembed?: {
                                    type?: string;
                                    version?: string;
                                    title?: string;
                                    description?: string;
                                    authorName?: string;
                                    authorUrl?: string;
                                    providerName?: string;
                                    providerUrl?: string;
                                    thumbnailUrl?: string;
                                    thumbnailWidth?: number;
                                    thumbnailHeight?: number;
                                    html?: string;
                                    width?: number;
                                    height?: number;
                                } | undefined;
                                redditVideo?: {
                                    bitrateKbps?: number;
                                    fallbackUrl?: string;
                                    height?: number;
                                    width?: number;
                                    scrubberMediaUrl?: string;
                                    dashUrl?: string;
                                    duration?: number;
                                    hlsUrl?: string;
                                    isGif?: boolean;
                                    transcodingStatus?: string;
                                } | undefined;
                            } | undefined;
                            crosspostParentId?: string;
                            permalink?: string;
                            isPoll?: boolean;
                            isPromoted?: boolean;
                            isMultiMedia?: boolean;
                            type?: string;
                            unlisted?: boolean;
                            galleryImages?: string[];
                            isImage?: boolean;
                            mediaUrls?: string[];
                            isClubContent?: boolean;
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                    automoderatorFilterComment?: {
                        comment?: {
                            id?: string;
                            parentId?: string;
                            body?: string;
                            author?: string;
                            numReports?: number;
                            collapsedBecauseCrowdControl?: boolean;
                            spam?: boolean;
                            deleted?: boolean;
                            createdAt?: number;
                            upvotes?: number;
                            downvotes?: number;
                            languageCode?: string;
                            lastModifiedAt?: number;
                            gilded?: boolean;
                            score?: number;
                            permalink?: string;
                            hasMedia?: boolean;
                            postId?: string;
                            subredditId?: string;
                            elementTypes?: string[];
                            mediaUrls?: string[];
                        } | undefined;
                        removedAt?: Date | undefined;
                        reason?: string;
                        author?: string;
                        subreddit?: {
                            id?: string;
                            name?: string;
                            nsfw?: boolean;
                            type?: import("../../reddit/v2alpha/subredditv2.js").SubredditType;
                            spam?: boolean;
                            quarantined?: boolean;
                            topics?: string[];
                            rating?: import("../../reddit/v2alpha/subredditv2.js").SubredditRating;
                            subscribersCount?: number;
                            permalink?: string;
                        } | undefined;
                    } | undefined;
                }): TriggerEvent;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "devvit.gateway.v1alpha.TriggerFanOutResponse";
                encode(message: TriggerFanOutResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): TriggerFanOutResponse;
                fromJSON(object: any): TriggerFanOutResponse;
                toJSON(message: TriggerFanOutResponse): unknown;
                create(base?: DeepPartial<TriggerFanOutResponse>): TriggerFanOutResponse;
                fromPartial(object: DeepPartial<TriggerFanOutResponse>): TriggerFanOutResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly onInvoke: {
            readonly name: "OnInvoke";
            readonly requestType: {
                $type: "devvit.gateway.v1alpha.TriggerInvocation";
                encode(message: TriggerInvocation, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): TriggerInvocation;
                fromJSON(object: any): TriggerInvocation;
                toJSON(message: TriggerInvocation): unknown;
                create(base?: DeepPartial<TriggerInvocation>): TriggerInvocation;
                fromPartial(object: DeepPartial<TriggerInvocation>): TriggerInvocation;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly onInstall: {
            readonly name: "OnInstall";
            readonly requestType: {
                $type: "devvit.dev_portal.installation.InstallationInfo";
                encode(message: InstallationInfo, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): InstallationInfo;
                fromJSON(object: any): InstallationInfo;
                toJSON(message: InstallationInfo): unknown;
                create(base?: {
                    id?: string;
                    upgradeStrategy?: import("../../dev_portal/installation/installation.js").UpgradeStrategy;
                    upgradeStrategyConfig?: {
                        [x: string]: any;
                    } | undefined;
                    runAs?: string | undefined | undefined;
                    type?: import("../../../../community.js").InstallationType;
                    location?: {
                        id?: string;
                        name?: string;
                        type?: import("../../reddit/thing_type.js").ThingType;
                        icon?: string | undefined | undefined;
                        isNsfw?: boolean;
                        isUnavailable?: boolean;
                    } | undefined;
                    isEnabled?: boolean;
                }): InstallationInfo;
                fromPartial(object: {
                    id?: string;
                    upgradeStrategy?: import("../../dev_portal/installation/installation.js").UpgradeStrategy;
                    upgradeStrategyConfig?: {
                        [x: string]: any;
                    } | undefined;
                    runAs?: string | undefined | undefined;
                    type?: import("../../../../community.js").InstallationType;
                    location?: {
                        id?: string;
                        name?: string;
                        type?: import("../../reddit/thing_type.js").ThingType;
                        icon?: string | undefined | undefined;
                        isNsfw?: boolean;
                        isUnavailable?: boolean;
                    } | undefined;
                    isEnabled?: boolean;
                }): InstallationInfo;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly onUninstall: {
            readonly name: "OnUninstall";
            readonly requestType: {
                $type: "devvit.dev_portal.installation.InstallationInfo";
                encode(message: InstallationInfo, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): InstallationInfo;
                fromJSON(object: any): InstallationInfo;
                toJSON(message: InstallationInfo): unknown;
                create(base?: {
                    id?: string;
                    upgradeStrategy?: import("../../dev_portal/installation/installation.js").UpgradeStrategy;
                    upgradeStrategyConfig?: {
                        [x: string]: any;
                    } | undefined;
                    runAs?: string | undefined | undefined;
                    type?: import("../../../../community.js").InstallationType;
                    location?: {
                        id?: string;
                        name?: string;
                        type?: import("../../reddit/thing_type.js").ThingType;
                        icon?: string | undefined | undefined;
                        isNsfw?: boolean;
                        isUnavailable?: boolean;
                    } | undefined;
                    isEnabled?: boolean;
                }): InstallationInfo;
                fromPartial(object: {
                    id?: string;
                    upgradeStrategy?: import("../../dev_portal/installation/installation.js").UpgradeStrategy;
                    upgradeStrategyConfig?: {
                        [x: string]: any;
                    } | undefined;
                    runAs?: string | undefined | undefined;
                    type?: import("../../../../community.js").InstallationType;
                    location?: {
                        id?: string;
                        name?: string;
                        type?: import("../../reddit/thing_type.js").ThingType;
                        icon?: string | undefined | undefined;
                        isNsfw?: boolean;
                        isUnavailable?: boolean;
                    } | undefined;
                    isEnabled?: boolean;
                }): InstallationInfo;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly onInstallChanged: {
            readonly name: "OnInstallChanged";
            readonly requestType: {
                $type: "devvit.dev_portal.installation.InstallationInfo";
                encode(message: InstallationInfo, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): InstallationInfo;
                fromJSON(object: any): InstallationInfo;
                toJSON(message: InstallationInfo): unknown;
                create(base?: {
                    id?: string;
                    upgradeStrategy?: import("../../dev_portal/installation/installation.js").UpgradeStrategy;
                    upgradeStrategyConfig?: {
                        [x: string]: any;
                    } | undefined;
                    runAs?: string | undefined | undefined;
                    type?: import("../../../../community.js").InstallationType;
                    location?: {
                        id?: string;
                        name?: string;
                        type?: import("../../reddit/thing_type.js").ThingType;
                        icon?: string | undefined | undefined;
                        isNsfw?: boolean;
                        isUnavailable?: boolean;
                    } | undefined;
                    isEnabled?: boolean;
                }): InstallationInfo;
                fromPartial(object: {
                    id?: string;
                    upgradeStrategy?: import("../../dev_portal/installation/installation.js").UpgradeStrategy;
                    upgradeStrategyConfig?: {
                        [x: string]: any;
                    } | undefined;
                    runAs?: string | undefined | undefined;
                    type?: import("../../../../community.js").InstallationType;
                    location?: {
                        id?: string;
                        name?: string;
                        type?: import("../../reddit/thing_type.js").ThingType;
                        icon?: string | undefined | undefined;
                        isNsfw?: boolean;
                        isUnavailable?: boolean;
                    } | undefined;
                    isEnabled?: boolean;
                }): InstallationInfo;
            };
            readonly requestStream: false;
            readonly responseType: {
                $type: "google.protobuf.Empty";
                encode(_: Empty, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Empty;
                fromJSON(_: any): Empty;
                toJSON(_: Empty): unknown;
                create(base?: {}): Empty;
                fromPartial(_: {}): Empty;
            };
            readonly responseStream: false;
            readonly options: {};
        };
    };
};
interface Rpc {
    request(service: string, method: string, data: Uint8Array, metadata?: Metadata): Promise<Uint8Array>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
//# sourceMappingURL=triggers.d.ts.map